<?xml version="1.0" encoding="UTF-8"?>
<!--
   Copyright (C) 2008 Cognos ULC, an IBM Company. All rights reserved.
   Cognos (R) is a trademark of Cognos ULC, (formerly Cognos Incorporated).
-->
<xsl:stylesheet version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"  
	xmlns:out="dummy-uri"
	xmlns:xtsext="xalan://com.cognos.xts.ext.XTSExt" 
	xmlns:xts="http://developer.cognos.com/schemas/xts/" 
	xmlns:mt="http://developer.cognos.com/schemas/xts/logicsheets/presentation/main/mt"
	xmlns:cp="http://developer.cognos.com/schemas/xts/logicsheets/xslt/presentation/controls/presentation/"	
	exclude-result-prefixes="mt xtsext xts cp">
	
	<xsl:output method="xml" encoding="UTF-8" indent="no"/>
	<xsl:namespace-alias stylesheet-prefix="out" result-prefix="xsl"/>

	<!-- 		
		Toolbar options (buttons):
		========================================================================================================================
		mt:tool[not(@name)] - Speial toolbar options generated by toollogic.
		mt:tool[@name='new'] - New object.
		mt:tool[@name='import']
		mt:tool[@name='export']
		mt:tool[@name='cut']
		mt:tool[@name='copy']
		mt:tool[@name='paste']
		mt:tool[@name='delete']
		mt:tool[@name='refresh']
		mt:tool[@name='selectall']
		mt:tool[@name='deselectall']
		mt:tool[@name='detail'] - Toggles detail view in main navigation window
		mt:tool[@name='list'] - Toggles list view in main navigation window
		mt:tool[@name='properties'] - Invoks the properties dialog for the root folder currently in focus
		mt:tool[@name='order'] - Invoks the "order" dialog to rearrange entries within a folder
		mt:tool[@name='search']
		mt:tool[@name='configuration_properties'] - Invoks the properties dialog for the root configuration folder
		mt:tool[@name='page_sizes']
		mt:tool[@name='file_system_locations']
		mt:tool[@name='enable_sched']
		mt:tool[@name='disable_sched']
		mt:tool[@name='view_events']
		mt:tool[@name='new_page']
		mt:tool[@name='edit_pagelet'] - Edit Page.
		
		mt:detailedEntryView - produce a detailed view for an entry.
		mt:objectNoneFound - render the 'no entries' line on main pages.
		mt:action - generate template to produce the actions available for an entry.
		renderaction - produce an action for an entry.
	-->	

	<!-- 
	Template - mt:stylesheet:
		This template defines link elements for skin_style and skin_fonts.
		Operation:
			Defines link element.
	-->
	<xsl:template match="mt:stylesheet">		
		<out:choose>
			<out:when test="/root/env/param[@name='style']">
				<link rel="stylesheet" type="text/css" href="{'{key(&quot;env-param&quot;, &quot;style&quot;)}'}"/><!-- TODO: make sure CAF is OK with this. -->
			</out:when>
			<out:otherwise>
				<link rel="stylesheet" type="text/css" href="{'{$skin_style}'}"/>				
				<link rel="stylesheet" type="text/css" href="{'{$skin_fonts}'}"/>				
			</out:otherwise>
		</out:choose>	
	</xsl:template>

	<!-- 
	Template - mt:page:
		This template is used to render the body of the main pages.
		Operation:
			Render body.
	-->
	<xsl:template match="mt:page">
		<!-- temporary theme selector, this will go on all match thms to switch using a url parameter -->
		<body onload="if (window.init) init();">
			<xsl:attribute name="topmargin">
				<xsl:choose>
					<xsl:when test="@mode='noborders'">0</xsl:when>
					<xsl:otherwise>3</xsl:otherwise>
				</xsl:choose>
			</xsl:attribute>
			<xsl:attribute name="bottommargin">0</xsl:attribute>
			<xsl:attribute name="marginheight">
				<xsl:choose>
					<xsl:when test="@mode='noborders'">0</xsl:when>
					<xsl:otherwise>3</xsl:otherwise>
				</xsl:choose>
			</xsl:attribute>
			<xsl:attribute name="rightmargin">
				<xsl:choose>
					<xsl:when test="@mode='noborders'">0</xsl:when>
					<xsl:otherwise>5</xsl:otherwise>
				</xsl:choose>
			</xsl:attribute>
			<xsl:attribute name="leftmargin">
				<xsl:choose>
					<xsl:when test="@mode='noborders'">0</xsl:when>
					<xsl:otherwise>5</xsl:otherwise>
				</xsl:choose>
			</xsl:attribute>
			<xsl:attribute name="marginwidth">
				<xsl:choose>
					<xsl:when test="@mode='noborders'">0</xsl:when>
					<xsl:otherwise>3</xsl:otherwise>
				</xsl:choose>
			</xsl:attribute>
			<xsl:if test="string(@class)!=''">
				<xsl:attribute name="class"><xsl:value-of select="@class"/></xsl:attribute>
			</xsl:if>
			<out:if test="$browser = 'ie'">
				<out:attribute name="style">overflow:auto</out:attribute>	
			</out:if>

			<xsl:call-template name="bodyContent"/>

		</body>		
	</xsl:template>
		
	<xsl:template match="mt:customPage">
		<xsl:call-template name="bodyContent"/>
	</xsl:template>
		
	<xsl:template name="bodyContent">
		<!-- out:if test="string(/root/session/param[@name='useAccessibilityFeatures']) = 'true'" -->
		<out:if test="$browser != 'ie'">
			<div style="position:absolute;">
				<a href="#top" accessKey="0">
					<img width="1" height="1" border="0">
						<out:attribute name="src"><out:value-of select="$webcontent"/>/images/space.gif</out:attribute>
						<out:attribute name="alt"><xts:string id="IDS_SECTION508_TOP"/></out:attribute>
						<out:attribute name="title"><xts:string id="IDS_SECTION508_TOP"/></out:attribute>
					</img>
				</a>
			</div>
		</out:if>
		<out:choose>
			<out:when test="$browser = 'ie'">
				<div style="position:absolute;">
				<a href="#jumptocontent" tabindex="0" accesskey="0">
					<img width="1" height="1" border="0">
						<out:attribute name="src"><out:value-of select="$webcontent"/>/images/space.gif</out:attribute>
						<out:attribute name="alt"><xts:string id="IDS_SECTION508_TOP"/>&#160;<xts:string id="IDS_SECTION508_JUMP"/>&#160;<xts:string id="IDS_SECTION508_GONAV"/></out:attribute>
						<out:attribute name="title"><xts:string id="IDS_SECTION508_TOP"/>&#160;<xts:string id="IDS_SECTION508_JUMP"/>&#160;<xts:string id="IDS_SECTION508_GONAV"/></out:attribute>
					</img>
				</a>
				</div>
			</out:when>
			<out:otherwise>
				<div style="position:absolute;">
				<a href="#jumptocontent">
					<img width="1" height="1" border="0">
						<out:attribute name="src"><out:value-of select="$webcontent"/>/images/space.gif</out:attribute>
						<out:attribute name="alt"><xts:string id="IDS_SECTION508_JUMP"/></out:attribute>
						<out:attribute name="title"><xts:string id="IDS_SECTION508_JUMP"/></out:attribute>
					</img>
				</a>
				</div>
			</out:otherwise>
		</out:choose>
		
		<!-- Generate common script code here (main page only for now) -->
		<xsl:if test="@mode = 'main'">			
			<script language="JavaScript">
				function g_PS_getPageContext()
				{       
					return "<out:value-of select="$javascriptescapedPageID"/>";
				}
				
				function g_PS_getPageRemoveConfMsg()
				{
					var bPageFound = !(<out:value-of select="$pageNotFound"/>);
					
					if (bPageFound)
						return "<xts:string id='IDS_PAGE_MENU_REMOVE_CONF' encode="javascript"><xts:param name="pageName"><out:value-of select="xtsext:javascriptencode(string($pageName))"/></xts:param></xts:string>";
					else
					 return "";
				}					
			</script>			
		</xsl:if>

		<xsl:apply-templates select="*"/>
	</xsl:template>
	
	<!-- 
	Template - mt:h1:
		This template renders the first line of the main pages.
		Operation:
			Renders the OEM and/or username as well as links to mypages, and studios on the first line.
	-->
	
	<xsl:template match="mt:h1">
		<out:variable name="runTimeDisplayMode">
			<out:choose>
				<out:when test="/root/page/displayMode = 'viewer'">viewer</out:when>
				<out:when test="key('env-param', 'search')">search</out:when>
				<out:otherwise>default</out:otherwise>
			</out:choose>				
		</out:variable>
		
		<xsl:variable name="compileMode">
			<xsl:choose>
				<xsl:when test="@mode = 'main'">main</xsl:when>
				<xsl:when test="@mode = 'mainSearch'">mainSearch</xsl:when>
				<xsl:when test="@mode = 'subscriptions'">subscriptions</xsl:when>
				<xsl:when test="@mode = 'drillthrough'">drillthrough</xsl:when>
				<xsl:otherwise>basic</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<out:if test="not(contains($ui_black_list, ' CRN_HEADER '))">			
			<script language="javascript" src="{'{$webcontent}'}/{'{$app}'}/js/banner.js"></script>
			<table cellspacing="0" cellpadding="0" class="mainHeader1">				
				<tr>
					<!-- Component title -->
					<out:if test="not(contains($ui_black_list, ' CRN_HEADER_TITLE '))">									
						<out:choose>								
							<!-- Custom header is specified -->
							<out:when test="key('system-param', 'OEM')/customHeader/style[@styleFolderName = key('session-param', 'skin')]">
								<td class="headerTitle">
									<out:copy-of select="key('system-param', 'OEM')/customHeader/style[@styleFolderName = key('session-param', 'skin')]/child::node()"/>
									
								</td>
							</out:when>
							
							<!-- Insert the standard header -->
							<out:otherwise>
								<td class="logoContainer"><div class="logo"/></td>
								<td class="headerTitle" onclick="debug(event)">
									<xsl:choose>
										<xsl:when test="mt:title/child::node()">
											<xsl:apply-templates select="mt:title/child::node()"/>
										</xsl:when>							
										<xsl:otherwise>
											<xts:string id="IDS_PORTAL"/>
										</xsl:otherwise>
									</xsl:choose>					
								</td>												 
							</out:otherwise>
						</out:choose>						
					</out:if>
					
					<td class="mainHeader1Middle"/>
					<td class="mainHeaderOptions">
					<table cellspacing="0" cellpadding="0" class="mainHeaderOptionsTable">
					<tr>
					<td class="optionsPadding">
					</td>
					<out:if test=" not(contains($ui_black_list, ' CRN_HEADER_OPTIONS ')) ">
						<xsl:if test="$compileMode != 'basic'">
						
							<!-- User Name  -->	
							<out:if test=" $is-named = '1'">
								<td class="userNameContainer"><out:value-of select="key('session-param', 'e_user')"/></td>
							</out:if>
					
							<!-- Logon -->
							<out:if test="not(contains($ui_black_list, ' CRN_HEADER_AUTHENTICATION '))">	
								<td class="authOptionContainer">
									<out:variable name="logOnURL" select="xtsext:javascriptencode(string(concat($gateway, '?', key(&quot;system-param&quot;, &quot;COGNOSHome&quot;))))"/>					
									<out:variable name="reLogOnURL" select="xtsext:javascriptencode($back-url)"/>													
									<out:variable name="logOffURL" select="xtsext:javascriptencode(string(concat($gateway, '?b_action=xts.run&amp;m=', $app, '/logoff.xts&amp;h_CAM_action=logoff')))"/>
										
									<out:choose>
										<!-- If both log on and off options are available then show both in a drop-down control -->
										<out:when test="$is-named = '1' and key('session-param', 'show_logon') = 'true'">
											<out:variable name="authMenu">
												<flyout id="authMenu">
													<items>
														<out:if test="not(contains($ui_black_list, ' CC_HEADER_MENU_logon '))">
															<item id="logon">
																<text><xts:string id="IDS_TOOLS_LOGON"/></text>
																<action>authenticate('relogon','<out:value-of select="$reLogOnURL"/>')</action>
																<icon><out:value-of select="concat($brand_images, 'tools_logon.gif')"/></icon>
															</item>
														</out:if>
														<out:if test="not(contains($ui_black_list, ' CC_HEADER_MENU_logoff '))">
															<item id="logoff">
																<text><xts:string id="IDS_TOOLS_LOGOFF"/></text>
																<action>authenticate('logoff','<out:value-of select="$logOffURL"/>')</action>
																<icon><out:value-of select="concat($brand_images, 'tools_logoff.gif')"/></icon>
															</item>
														</out:if>
													</items>
												</flyout>
											</out:variable>										
											
											<out:if test="$authMenu/flyout/items/*">	
												<div id="authMenu_span" style="position:relative;z-index:12;">
													<table cellspacing="0" cellpadding="0">
														<tr>
															<td nowrap="true" accessKey="1" tabindex="0" style="padding-right:3px;"
																onkeypress="authenticate('logon', '{'{$reLogOnURL}'}')" 
																onclick="authenticate('logon', '{'{$reLogOnURL}'}')">
																<a class="bannerOptions" onmouseover="window.status='';return true;" onmouseout="window.status='';return true;">
																	<xts:string id="IDS_TOOLS_LOGON"/>
																</a>
															</td>
															<td class="bannerOptionsButtonNormal" tabindex="0" accessKey="1"  
																onmouseover="this.className='bannerOptionsButtonOver';" 
																onmouseout="this.className='bannerOptionsButtonNormal';" 
																onkeypress="return CCPopupMenu.dropDown(event,0,0,'authMenu');"														
																onclick="return CCPopupMenu.dropDown(event,0,0,'authMenu');">
																<img name="searchMenu_imgFlyControl" src="{'{$skin_shared_images}'}dropdown_arrow_banner.gif" >
																	<out:attribute name="alt"><xts:string id="IDS_LOGON_MENU_TOOLTIP"/></out:attribute>
																	<out:attribute name="title"><xts:string id="IDS_LOGON_MENU_TOOLTIP"/></out:attribute>
																</img>
															</td>
														</tr>
													</table>
												</div>
												
												<out:call-template name="renderPopup">
													<out:with-param name="flyoutXML">
														<out:copy-of select="$authMenu"/>
													</out:with-param>
													<out:with-param name="controlID">authMenu_span</out:with-param>
												</out:call-template>
											</out:if>											
										</out:when>
								
										<!-- Security is enabled but the user is not authenticated -->
										<out:when test="$is-secure = '1' and $is-named != '1' and not(contains($ui_black_list, ' CC_HEADER_MENU_logon '))">
											<!-- Show Log in -->										
											<div class="authOptionContainer">
												<a href="#" class="bannerOptions" tabindex="0" onclick="authenticate('logon', '{'{$logOnURL}'}')">								
													<xts:string id="IDS_TOOLS_LOGON"/>
												</a>
											</div>
										</out:when>
								
										<!-- User is authenticated into the only available namespace.  show loggoff only -->
										<out:when test="$is-named = '1' and not(contains($ui_black_list, ' CC_HEADER_MENU_logoff '))">
											<div class="authOptionContainer">
												<a href="#" class="bannerOptions" tabindex="0" onclick="authenticate('logoff', '{'{$logOffURL}'}')">
													<xts:string id="IDS_TOOLS_LOGOFF"/>
												</a>
											</div>
										</out:when>
										<out:otherwise>
											<!-- show nothing -->
										</out:otherwise>
									</out:choose>	
								</td>
							</out:if>
							
							<!-- Custom Banner options -->
							<out:if test="key('system-param', 'ui_add')/CC_HEADER_MENU/item">
								<td class="dividerContainer"><div class="bannerDivider"/></td>						
								<out:for-each select="key('system-param', 'ui_add')/CC_HEADER_MENU/item">
									<out:variable name="s" select="concat(' ', @show, ' ')"/>
									<out:if test="
											not(@show) or
			 								(contains($s , 'Administrators') and $isAdminUser)  or  
			 								(contains($s , 'QSUsers') and $userCanUseFullQS)   or  
			 								(contains($s , 'RSUsers') and $userCanUseFullRS) or  
			 								(contains($s , 'Consumers') and $is-named='1') or 
			 								(contains($s , 'Anonymous') and $is-named='0') or 
											(key('system-param', 'ui_groups')/group[contains($s, concat(' ', @id, ' ')) and contains(  key('session-param', 'uig'), concat(' ', @id, ' '))])
			 							">
										<td class="customBannerContainer">
											<a class="bannerOptions" tabindex="0" href="{'{url}'}">
												<out:if test="./onclick">
													<out:attribute name="onclick"><out:value-of select="onclick"/></out:attribute>
												</out:if>
												<out:if test="target">
													<out:attribute name="target"><out:value-of select="target"/></out:attribute>
												</out:if>
												<out:value-of select="label[lang($productLocale)]"/>
											</a>
										</td>																				
									</out:if>
								</out:for-each>
							</out:if>	
							
							<td class="dividerContainer"><div class="bannerDivider"/></td>						
																					 
							<!-- Refresh  -->
							<out:if test="not(contains($ui_black_list, ' CRN_HEADER_REFRESH '))">	
								<td class="refreshContainer">
									<div tabindex="0" accessKey="1" class="bannerOptionsButtonNormal" 
										onclick="refresh()"	onkeypress="if(event.keyCode==9)return true;refresh()"
										onmouseover="this.className='bannerOptionsButtonOver';" onmouseout="this.className='bannerOptionsButtonNormal';">
										<img border="0" src="{'{$image_root}'}action_refresh.gif"> 
											<out:attribute name="alt"><xts:string id="IDS_REFRESH"/></out:attribute>
											<out:attribute name="title"><xts:string id="IDS_REFRESH"/></out:attribute>
										</img>
									</div>							
								</td>
							</out:if>
						
							<out:if test="not(contains($ui_black_list, ' CRN_HEADER_SEARCH ') or contains($ui_black_list, ' CC_HEADER_MENU_search '))">	
								<!-- We don't show top search box when in: search mode, navigating upfront, outside of the portal -->
								<xsl:if test="$compileMode = 'main' ">						
									<!-- At run time, if we are running search or navigating Upf newsboxes then hide search -->
									<out:if test="not(/root/env/param[@name='search']) and not(/root/upfContent/*[local-name()='queryResponse'])">
										<td class="dividerContainer">							
											<div class="bannerDivider"/>
			  						</td>
									
										<td class="searchEditContainer">
											<out:variable name="method">
												<out:choose>
													<out:when test="$isXSSCheckingOn='true'">post</out:when>
													<out:otherwise>get</out:otherwise>
												</out:choose>
											</out:variable>
											<form action="{'{$gateway}'}/gosearch" name="mainISearchForm" method="{'{$method}'}" style="margin:0px">
												<input id="ps_banner_isearchfrm" type="hidden" name="csn.terms"/>
												<input type="hidden" name="backURL" value="{'{$back-url}'}"/>
											</form>
											<form name="mainSearchForm" method="{'{$method}'}" style="margin:0px">							
												<input class="mainSearchEdit" type="text" name="stext" id="stext" value="" onkeypress="return searchKeyHandler(event);">
													<out:attribute name="title"><xts:string id="IDS_SEARCH_STRING_ALT"/></out:attribute>
												</input>
												<input type="hidden" name="sfield" value=""/>
												<input type="hidden" name="backURL" value="{'{$back-url}'}"/>
												<input type="hidden" name="search" value=""/>
												<input type="hidden" name="b_action" value="xts.run"/>
												<input type="hidden" name="m" value="{'{$app}'}/cc.xts"/>
												<!-- m_folder is required for cm searches so that the context of the search is within the folder just navigated to -->
												<input type="hidden" name="m_folder" value="{'{$folderID}'}"/>
												<input type="hidden" name="sscope" value="fb"/>
												
												
  											</form>
										</td>
										<td class="searchIconContainer">
											<out:variable name="searchMenu">
												<flyout id="searchMenu">
													<items>
														<itemGroup id="findTextInMenuGroup">
															<xsl:if test="not(mt:fields) or mt:fields/mt:field='k'">
																<out:if test="$userCanUseIndexSearch">  
																	<item id="findTextInMenu_k" itemSelectedState="checked">
																		<text><xts:string id="IDS_KEYWORD"/></text>
																		<action>CCPopupMenu.activeMenu.setMenuItemChecked("findTextInMenu_k");document.mainSearchForm.sfield.value = 'k';</action>
																	</item>
																</out:if>
															</xsl:if>
				
															<xsl:if test="not(mt:fields) or mt:fields/mt:field='n'">
																<item id="findTextInMenu_n">
																	 <out:if test="not($userCanUseIndexSearch)">
																		<out:attribute name="itemSelectedState">checked</out:attribute>
																	</out:if> 
																	<text><xts:string id="IDS_NAME_FIELD"/></text>
																	<action>CCPopupMenu.activeMenu.setMenuItemChecked("findTextInMenu_n");document.mainSearchForm.sfield.value = 'n';</action>
																</item>
															</xsl:if>
				
															<xsl:if test="not(mt:fields) or mt:fields/mt:field='d'">
																<item id="findTextInMenu_d">
																	<text><xts:string id="IDS_DESC_FIELD"/></text>
																	<action>CCPopupMenu.activeMenu.setMenuItemChecked("findTextInMenu_d");document.mainSearchForm.sfield.value = 'd';</action>
																</item>
															</xsl:if>
				
															<xsl:if test="not(mt:fields) or mt:fields/mt:field='nd'">
																<item id="findTextInMenu_nd">
																	<text><xts:string id="IDS_NAME_DESC_FIELD"/></text>
																	<action>CCPopupMenu.activeMenu.setMenuItemChecked("findTextInMenu_nd");document.mainSearchForm.sfield.value = 'nd';</action>
																</item>
															</xsl:if>
														</itemGroup>
													</items>
												</flyout>
											</out:variable>
												
											<div id="searchflyout_span" style="position:relative; z-index:12;">
												<table cellspacing="0" cellpadding="0">
													<tr>
														<td nowrap="true" tabindex="0" accessKey="1" class="bannerOptionsButtonNormal" 
															onmouseover="this.className='bannerOptionsButtonOver';" onmouseout="this.className='bannerOptionsButtonNormal';" 
															onkeypress="if(event.keyCode==9)return true;search();" onclick="search()">
															<img id="bannerSearch" border="0" src="{'{$image_root}'}action_search.gif">
																<out:attribute name="alt"><xts:string id="IDS_SEARCH"/></out:attribute>
																<out:attribute name="title"><xts:string id="IDS_SEARCH"/></out:attribute>
															</img>
														</td>
														<td class="bannerOptionsButtonNormal" tabindex="0" accessKey="1"
															onmouseover="this.className='bannerOptionsButtonOver';" onmouseout="this.className='bannerOptionsButtonNormal';" 
															onkeypress="return CCPopupMenu.dropDown(event,0,0,'searchMenu');" onclick="return CCPopupMenu.dropDown(event,0,0,'searchMenu');">
															<img name="searchMenu_imgFlyControl" src="{'{$skin_shared_images}'}dropdown_arrow_banner.gif" >
																<out:attribute name="alt"><xts:string id="IDS_SEARCH_OPTIONS"/></out:attribute>
																<out:attribute name="title"><xts:string id="IDS_SEARCH_OPTIONS"/></out:attribute>
															</img>
														</td>
													</tr>
												</table>
											</div>								
												
											<out:call-template name="renderPopup">
												<out:with-param name="flyoutXML">
													<out:copy-of select="$searchMenu"/>
												</out:with-param>
												<out:with-param name="controlID">searchflyout_span</out:with-param>
											</out:call-template> 
										</td>								
									</out:if> 
								</xsl:if>					
							</out:if>
								
							<!-- separator -->
							<td class="dividerContainer"><div class="bannerDivider"/></td>
			
							<!-- Home -->			
							<out:if test="not(contains($ui_black_list, ' CRN_HEADER_HOME ') or contains($ui_black_list, ' CC_HEADER_MENU_home '))">
								<td class="homeContainer">									
									<xsl:choose>
										<!-- Decide if setting home is applicable -->
										<xsl:when test="$compileMode = 'main' ">
											<out:choose>
												<!-- At runtime, if we are running search or navigating Upfront Newsboxes or the user cannot write to their account then we don't allow home to be set -->
												<out:when test="$runTimeDisplayMode = 'default' and key('session-param', 'write') = 'true' and $nbid = ''">																				
													<out:variable name="homeMenu">
														<flyout id="HomeMenu">
															<items>
																<item id="goHome">
																	<text><xts:string id="IDS_PAGE_MENU_HOME"/></text>
																	<action>homeOptions('goHome');</action>
																</item>
																<out:if test="not(contains($ui_black_list, ' CRN_HEADER_HOME_setHome '))">
																	<item id="setHome">	
																		<text><xts:string id="IDS_PAGE_MENU_SET_AS_HOME"/></text>
																		<action>homeOptions('setHome');</action>
																	</item>
																</out:if>
															</items>
														</flyout>
													</out:variable>
													
													<div id="homeflyout_span" style="position: relative; z-index:12;">
														<script language="JavaScript">			
															var g_CC_basicCCQueryString = "<out:value-of select="xtsext:javascriptencode(string($baseCCQS))"/>";
															var g_CC_homeQueryStringContext = "<out:value-of select="xtsext:javascriptencode(string($home-query-url))"/>";					
														</script>
														<table cellspacing="0" cellpadding="0">
															<tr>
																<td	tabindex="0" accessKey="1" class="bannerOptionsButtonNormal" 
																	onmouseover="this.className='bannerOptionsButtonOver';" onmouseout="this.className='bannerOptionsButtonNormal';" 
																	onkeypress="if(event.keyCode==9)return true;homeOptions('goHome');" onclick="homeOptions('goHome')">
																	<img border="0" src="{'{$skin_shared_images}'}action_home.gif">
																		<out:attribute name="alt"><xts:string id="IDS_HOME"/></out:attribute>
																		<out:attribute name="title"><xts:string id="IDS_HOME"/></out:attribute>
																	</img>
																</td>
																<td class="bannerOptionsButtonNormal" tabindex="0" accessKey="1"
																	onmouseover="this.className='bannerOptionsButtonOver';" onmouseout="this.className='bannerOptionsButtonNormal';" 															 
																	onkeypress="return CCPopupMenu.dropDown(event,0,0,'HomeMenu');" onclick="return CCPopupMenu.dropDown(event,0,0,'HomeMenu');">
																	<img name="homeMenu_imgFlyControl" src="{'{$skin_shared_images}'}dropdown_arrow_banner.gif"  >
																		<out:attribute name="alt"><xts:string id="IDS_PAGE_MENU_HOME_OPTIONS"/></out:attribute>
																		<out:attribute name="title"><xts:string id="IDS_PAGE_MENU_HOME_OPTIONS"/></out:attribute>
																	</img>
																</td>
															</tr>
														</table>
													</div>								
													<out:call-template name="renderPopup">
														<out:with-param name="flyoutXML">
															<out:copy-of select="$homeMenu"/>
														</out:with-param>
														<out:with-param name="controlID">homeflyout_span</out:with-param>
													</out:call-template> 
												</out:when>	
												
												<out:otherwise>
													<div onclick="goHome();" class="bannerOptionsButtonNormal"  
														onmouseover="this.className='bannerOptionsButtonOver';" onmouseout="this.className='bannerOptionsButtonNormal';">
														<img border="0" src="{'{$skin_shared_images}'}action_home.gif" > 
															<out:attribute name="alt"><xts:string id="IDS_HOME"/></out:attribute>
															<out:attribute name="title"><xts:string id="IDS_HOME"/></out:attribute>
														</img> 
													</div>
												</out:otherwise>
											</out:choose>
										</xsl:when>
							
										<xsl:otherwise>
											<div onclick="goHome()" class="bannerOptionsButtonNormal"  
												onmouseover="this.className='bannerOptionsButtonOver';" 
												onmouseout="this.className='bannerOptionsButtonNormal';">
												<img border="0" src="{'{$skin_shared_images}'}action_home.gif" > 
													<out:attribute name="alt"><xts:string id="IDS_HOME"/></out:attribute>
													<out:attribute name="title"><xts:string id="IDS_HOME"/></out:attribute>
												</img> 
											</div>
										</xsl:otherwise>
									</xsl:choose>																					
								</td>
							</out:if>	
							
							
							<!-- Return -->							
							<out:if test=" key('env-param', 'backURL') != '' and  not(contains($ui_black_list, ' CC_HEADER_MENU_return '))">	
								<td class="returnContainer">		
									<div onclick="doReturn()" 
										class="bannerOptionsButtonNormal"  
										onmouseover="this.className='bannerOptionsButtonOver';" 
										onmouseout="this.className='bannerOptionsButtonNormal';">
										<img border="0" src="{'{$skin_shared_images}'}action_return.gif" > 
											<out:attribute name="alt"><xts:string id="IDS_RETURN"/></out:attribute>
											<out:attribute name="title"><xts:string id="IDS_RETURN"/></out:attribute>
										</img> 
									</div>						
								</td>
							</out:if>
											
								
							<!-- Personal Options -->
							<out:if test="not(contains($ui_black_list, ' CRN_HEADER_PERSONAL '))">
								<td class="personalOptionsContainer">																					
									<out:variable name="personalOptions">
										<flyout id="personalOptions">															
											<items>									
												<!-- subscriptions -->
												<xsl:if test="$compileMode != 'subscriptions'">
													<out:if test="not(contains($ui_black_list, ' CRN_HEADER_PERSONAL_subscriptions '))">
														<item id="subscriptions">
															<text><xts:string id="IDS_MYSUB_MYSUBSCRIPTIONS"/></text>	
															<action>personalOptions('subscriptions')</action>
														</item>
													</out:if>		
												</xsl:if>
												
												<!-- prefs -->
												<out:if test="not(contains($ui_black_list, ' CRN_HEADER_PERSONAL_preferences ') or contains($ui_black_list, ' CC_HEADER_MENU_preferences '))">
													<item id="preferences">
														<text><xts:string id="IDS_TOOLS_PREFERENCES"/></text>													
														<action>personalOptions('preferences')</action>
													</item>
												</out:if>					
												
												<!-- run activities / schedule -->
												<out:if test="not(contains($ui_black_list, ' CRN_HEADER_PERSONAL_activities ')) and  ($userCanUseSched or $userCanUseMonitorActivity)">
													<item id="runactivities">
														<text><xts:string id="IDS_TOOLS_MY_RUN_ACTIVITIES"/></text>													
														<action>personalOptions('admin')</action>
													</item>
												</out:if>													
											</items>
										</flyout>							
									</out:variable>	
										
									<!-- If there are personal options to show then show them -->
									<out:if test="$personalOptions/flyout/items/*">
										<div id="personalOptions_span" style="position:relative;z-index:12">										
											<div tabindex="0" accessKey="1" class="bannerOptionsButtonNormal" 
												onmouseover="this.className='bannerOptionsButtonOver';" onmouseout="this.className='bannerOptionsButtonNormal';"
												onkeypress="return CCPopupMenu.dropDown(event,0,0,'personalOptions');" onclick="return CCPopupMenu.dropDown(event,0,0,'personalOptions');">
												<out:attribute name="alt"><xts:string id="IDS_MY_AREA"/></out:attribute>
												<out:attribute name="title"><xts:string id="IDS_MY_AREA"/></out:attribute>
												<table cellspacing="0" cellpadding="0">
													<tr>
														<td style="padding-right:4px;">
															<img src="{'{$skin_shared_images}'}icon_my_area.gif"> 
																<out:attribute name="alt"><xts:string id="IDS_MY_AREA"/></out:attribute>
															</img>
														</td>		
														<td style="padding-right:4px;">
															<img name="toolsMenu_imgFlyControl" src="{'{$skin_shared_images}'}dropdown_arrow_banner.gif"/>
														</td>									
													</tr>
												</table>
											</div>
										</div>
										
										<out:call-template name="renderPopup">
											<out:with-param name="flyoutXML">
												<out:copy-of select="$personalOptions"/>
											</out:with-param>
											<out:with-param name="controlID">personalOptions_span</out:with-param>
										</out:call-template>
									</out:if>
								</td>
							</out:if>
					
							<!-- Launch -->
							<out:if test="not(contains($ui_black_list, ' CRN_HEADER_LAUNCH '))">							
								<!-- build the apps list -->
								<out:variable name="WebApps">
									<!-- Planning Contributor -->			
									<out:if test="not(contains($ui_black_list, ' CRN_HEADER_OPTIONS_pc ')) and $userCanUsePlanningContributor"> 
										<item id="pc">
											<text><xts:string id="IDS_TOOLS_CONTRIBUTOR"/></text>
											<action>launchApp('PlanningContributor')</action>
											<icon><out:value-of select="concat($brand_images, 'tools_contributor.gif')"/></icon>
										</item>									
									</out:if>
									<!-- Controller Studio -->			
									<out:if test="not(contains($ui_black_list, ' CRN_HEADER_OPTIONS_cs ')) and $userCanUseControllerStudio"> 
										<item id="cs">
											<text><xts:string id="IDS_TOOLS_CONTROLLER"/></text>
											<action>launchApp('Controller')</action>
											<icon><out:value-of select="concat($brand_images, 'tools_controller.gif')"/></icon>
										</item>									
									</out:if>
									<!-- MetricsManager Studio -->
									<out:if test="not(contains($ui_black_list, ' CRN_HEADER_OPTIONS_mm ')) and $userCanUseMetricsManager"> 
										<item id="mm">
											<text><xts:string id="IDS_TOOLS_METRICSMANAGER"/></text>
											<action>launchApp('MetricsManager')</action>
											<icon><out:value-of select="concat($brand_images, 'tools_metrics_manager.gif')"/></icon>
										</item>									
									</out:if>									
								</out:variable>									
								
								<out:variable name="StudioApps">
									<!-- Adaptive Analytics -->			
									<out:if test="not(contains($ui_black_list, ' CRN_HEADER_OPTIONS_aa ')) and $userCanUseAdaptiveAnalyticsAdministration">
										<item id="aa">
											<text><xts:string id="IDS_TOOLS_ANALYTICS"/></text>
											<action>launchApp('AdaptiveAnalytics')</action>
											<icon><out:value-of select="concat($brand_images, 'tools_adaptive_analytics.gif')"/></icon>
										</item>									
									</out:if>
									<!-- Query Studio -->			
									<out:if test="not(contains($ui_black_list, ' CRN_HEADER_OPTIONS_qs ')) and $userCanUseFullQS"> 
										<item id="qs">
											<text><xts:string id="IDS_TOOLS_QUERY"/></text>
											<action>launchApp('QueryStudio')</action>
											<icon><out:value-of select="concat($brand_images, 'tools_query_studio.gif')"/></icon>
										</item>									
									</out:if>
									<!-- PowerPlay Studio -->			
									<out:if test="$userCanUsePPS and not(contains($ui_black_list, ' CRN_HEADER_OPTIONS_pps '))"> 
										<item id="pps">
											<text><xts:string id="IDS_TOOLS_POWERPLAY"/></text>
											<action>launchApp('PowerPlayStudio')</action>
											<icon><out:value-of select="concat($brand_images, 'tools_powerplay_studio.gif')"/></icon>
										</item>									
									</out:if>
									<!-- Analysis Studio -->			
									<out:if test="$userCanUseANS and not(contains($ui_black_list, ' CRN_HEADER_OPTIONS_as '))">
										<item id="as">
											<text><xts:string id="IDS_TOOLS_ANALYSIS"/></text>
											<action>launchApp('AnalysisStudio')</action>
											<icon><out:value-of select="concat($brand_images, 'tools_analysis_studio.gif')"/></icon>
										</item>									
									</out:if>												
									<!-- Report Studio -->			
									<out:if test="$userCanUseFullRS and not(contains($ui_black_list, ' CRN_HEADER_OPTIONS_rs '))"> 
										<item id="rs">
											<text><xts:string id="IDS_TOOLS_REPORT"/></text>
											<action>launchApp('ReportStudio')</action>
											<icon><out:value-of select="concat($brand_images, 'tools_report_studio.gif')"/></icon>
										</item>									
									</out:if>		
									<!-- Event Studio -->			
									<out:if test="not(contains($ui_black_list, ' CRN_HEADER_OPTIONS_es ')) and $userCanUseAGS"> 
										<item id="es">
											<text><xts:string id="IDS_TOOLS_AGENT"/></text>
											<action>launchApp('EventStudio')</action>
											<icon><out:value-of select="concat($brand_images, 'tools_agent_studio.gif')"/></icon>
										</item>									
									</out:if>
									<!-- Drill-through Definitions -->
									<xsl:if test="$compileMode != 'drillthrough'">
										<out:if test="not(contains($ui_black_list, ' CRN_HEADER_OPTIONS_dt '))">
											<item id="dt">
												<text><xts:string id="IDS_TOOLS_DRILLPATH"/></text>									
												<action>launchApp('DrillThrough')</action>											
												<icon><out:value-of select="concat($brand_images, 'tools_drill_through.gif')"/></icon>
											</item>
										</out:if>
									</xsl:if>
								</out:variable>
	
								<out:variable name="CustomApps">
									
									<!-- Support ReportNet and Cognos 8.1, 8.2 header customization in this menu -->
									
									<!-- Custom Apps -->
									<out:for-each select="key('system-param', 'ui_add')/CRN_HEADER_OPTIONS/item">
										<out:variable name="s" select="concat(' ', @show, ' ')"/>
										<out:if test="
												not(@show) or
				 								(contains($s , 'Administrators') and $isAdminUser)  or  
				 								(contains($s , 'QSUsers') and $userCanUseFullQS)   or  
				 								(contains($s , 'RSUsers') and $userCanUseFullRS) or  
				 								(contains($s , 'Consumers') and $is-named='1') or 
				 								(contains($s , 'Anonymous') and $is-named='0') or 
												(key('system-param', 'ui_groups')/group[contains($s, concat(' ', @id, ' ')) and contains(  key('session-param', 'uig'), concat(' ', @id, ' '))])
				 							">
											<item id="custom_tool1{'{position()}'}">
												<text><out:value-of select="label[lang($productLocale)]"/></text>
												<action>openURL('<out:value-of select="xtsext:javascriptencode(url)"/>', '<out:value-of select="target"/>');<out:value-of select="onclick"/></action>
												<icon><out:value-of select="concat($image_root, string(icon))"/></icon>
											</item>																				
										</out:if>
									</out:for-each>
									
								</out:variable>
								
								<out:variable name="AdminApps">
									<xsl:if test="$compileMode != 'main'">
										<!-- Cognos Connection -->
										<out:if test="not(contains($ui_black_list, ' CRN_HEADER_OPTIONS_cc '))">
											<item id="cc">
												<text><xts:string id="IDS_PORTAL"/></text>									
												<action>launchApp('Portal')</action>
												<icon><out:value-of select="concat($brand_images, 'tools_portal.gif')"/></icon>
											</item>
										</out:if>								
									</xsl:if>
									
									<!-- Cognos Administration -->
									<out:if test="not(contains($ui_black_list, ' CRN_HEADER_OPTIONS_ac ')) and $hasAdminCapability">
										<item id="ac">
											<text><xts:string id="IDS_TOOLS_CA"/></text>									
											<action>launchApp('Administration')</action>
											<icon><out:value-of select="concat($brand_images, 'tools_cognos_administration.gif')"/></icon>
										</item>
									</out:if>	
									
									
									<!-- Backwards compatibility only!! - Support custom tools (Cognos 8.1, 8.2) near the administration consol. -->
									<out:for-each select="key('system-param', 'ui_add')/CC_VIEW_TOOLS/item">
										<out:variable name="s" select="concat(' ', @show, ' ')"/>
										<out:if test="
											not(@show) or
											(contains($s , 'Administrators') and $isAdminUser)  or  
											(contains($s , 'QSUsers') and $userCanUseFullQS)   or  
											(contains($s , 'RSUsers') and $userCanUseFullRS) or  
											(contains($s , 'Consumers') and $is-named='1') or 
											(contains($s , 'Anonymous') and $is-named='0') or 
											(key('system-param', 'ui_groups')/group[contains($s, concat(' ', @id, ' ')) and contains(  key('session-param', 'uig'), concat(' ', @id, ' '))])
											">
											<item id="custom_tool2{'{position()}'}">
													<text><out:value-of select="label[lang($productLocale)]"/></text>
													<action>openURL('<out:value-of select="xtsext:javascriptencode(url)"/>','<out:value-of select="target"/>');<out:value-of select="onclick"/></action>
													<out:if test="icon">
														<icon><out:value-of select="concat($image_root, string(icon))"/></icon>
													</out:if>
											</item>
										</out:if>
									</out:for-each>													
								</out:variable>
								
								
								<!-- Assemble the goto menu manifest -->
								<out:variable name="goto">
									<flyout id="goto">															
										<items>
											<out:copy-of select="$WebApps"/>												
											<out:if test="$WebApps/* and ($StudioApps/* or $AdminApps/* or $CustomApps/*)">
												<item type="separator"/>
											</out:if>
											<out:copy-of select="$StudioApps"/>												
											<out:if test="$AdminApps/* and ($WebApps/* or $StudioApps/*)">
												<item type="separator"/>
											</out:if>
											<out:copy-of select="$AdminApps"/>	
											<out:if test="$CustomApps/* and ($WebApps/* or $StudioApps/* or $AdminApps/*)">
												<item type="separator"/>
											</out:if>				
											<out:copy-of select="$CustomApps"/>
										</items>
									</flyout>							
								</out:variable>		
									
								<!-- Render apps menu options in flyout control (if there is at least one) -->
								<out:if test="$goto/flyout/items/*">
									<td class="appOptionsContainer">
										<div id="goto_span" style="position:relative; z-index:12">
											<div tabindex="0" accessKey="1"	class="bannerOptionsButtonNormal"  
												onmouseover="this.className='bannerOptionsButtonOver';" onmouseout="this.className='bannerOptionsButtonNormal';"
												onkeypress="return CCPopupMenu.dropDown(event,0,0,'goto');" onclick="return CCPopupMenu.dropDown(event,0,0,'goto');">
												<table cellspacing="0" cellpadding="0" >
													<tr>
														<td nowrap="true" style="padding-left:4px;">
															<a class="bannerOptions" onmouseover="window.status='';return true;" onmouseout="window.status='';return true;"><xts:string id="IDS_GOTO"/></a>
														</td>
														<td style="padding-right:4px;padding-left:4px;">
															<img name="toolsMenu_imgFlyControl" src="{'{$skin_shared_images}'}dropdown_arrow_banner.gif">
																<out:attribute name="alt"><xts:string id="IDS_GOTO_OPTIONS"/></out:attribute>
															</img>
														</td>
													</tr>
												</table>
											</div>
										</div>
									
										<out:call-template name="renderPopup">
											<out:with-param name="flyoutXML">
												<out:copy-of select="$goto"/>
											</out:with-param>
											<out:with-param name="controlID">goto_span</out:with-param>
										</out:call-template>
									</td>
								</out:if>							
							</out:if>
						</xsl:if>			
				
						<!-- help -->
						<out:if test="not(contains($ui_black_list, ' CRN_HEADER_HELP ') or contains($ui_black_list, ' CC_HEADER_MENU_help '))">
							<out:variable name="helpMenuSet1">
								<item id="help">
									<text><xts:string id="IDS_RI_HELP"/></text>
									<action>bannerHelp('helpRI');</action>
								</item>
								<item id="pmp">
									<text><xts:string id="IDS_RI_PMP"/></text>
									<action>bannerHelp('pmpRI');</action>
								</item>
								<item id="moreDocs">
									<text><xts:string id="IDS_COGNOS_HELP"/></text>
									<action>bannerHelp('moreDocs');</action>
								</item>
							</out:variable>
									
							<out:variable name="helpMenuSet2">
								<out:if test="not(contains($ui_black_list, ' CRN_HEADER_HELP_welcome '))">
									<item id="welcome">
										<text><xts:string id="IDS_GO_WELCOME"/></text>
										<action>bannerHelp('welcome');</action>
									</item>	
								</out:if>
							</out:variable>
									
							<out:variable name="helpMenuSet3">
								<out:if test="not(contains($ui_black_list, ' CRN_HEADER_HELP_about ') or contains($ui_black_list, ' CC_HEADER_MENU_about '))">
									<item id="about">
										<text><xts:string id="IDS_ABOUT_RI"></xts:string></text>
										<action>bannerHelp('about');</action>
									</item>	
								</out:if>
							</out:variable>
							<!-- Assemble the help menu manifest -->
							<out:variable name="helpMenu">
								<flyout id="helpMenu">
									<items>																					
										<out:copy-of select="$helpMenuSet1"/>											
										<out:if test="$helpMenuSet1/* and ($helpMenuSet2/* or $helpMenuSet3/*)">
											<item type="separator"/>
										</out:if>											
										<out:copy-of select="$helpMenuSet2"/>											
										<out:if test="$helpMenuSet2/* and $helpMenuSet3/*">
											<item type="separator"/>
										</out:if>											
										<out:copy-of select="$helpMenuSet3"/>											
									</items>
								</flyout>
							</out:variable>
							
							<td class="helpContainer">
								<div id="helpMenu_span" style="position: relative;z-index:12;">					
									<table cellspacing="0" cellpadding="0">
										<tr>
											<td tabindex="0" accessKey="1" class="bannerOptionsButtonNormal" 											
												onmouseover="this.className='bannerOptionsButtonOver';" onmouseout="this.className='bannerOptionsButtonNormal';" 
												onkeypress="if(event.keyCode==9)return true;bannerHelp('help');" onclick="bannerHelp('help')">
												<img src="{'{$skin_shared_images}'}action_help.gif">
													<out:attribute name="alt"><xts:string id="IDS_HELP"/></out:attribute>
													<out:attribute name="title"><xts:string id="IDS_HELP"/></out:attribute>
												</img>
											</td>
											<td class="bannerOptionsButtonNormal" tabindex="0" accessKey="1" 
												onmouseover="this.className='bannerOptionsButtonOver';" onmouseout="this.className='bannerOptionsButtonNormal';" 						
												onkeypress="return CCPopupMenu.dropDown(event,0,0,'helpMenu');" onclick="return CCPopupMenu.dropDown(event,0,0,'helpMenu');">
												<img name="searchMenu_imgFlyControl" src="{'{$skin_shared_images}'}dropdown_arrow_banner.gif" >
													<out:attribute name="alt"><xts:string id="IDS_HELP_OPTIONS"/></out:attribute>
													<out:attribute name="title"><xts:string id="IDS_HELP_OPTIONS"/></out:attribute>
												</img>
											</td>
										</tr>
									</table>	
								</div>
			
								<out:call-template name="renderPopup">
									<out:with-param name="flyoutXML">
										<out:copy-of select="$helpMenu"/>
									</out:with-param>
									<out:with-param name="controlID">helpMenu_span</out:with-param>
								</out:call-template>
							</td>
						</out:if>		
					
					</out:if>
					</tr>
					</table>
					</td>
				</tr>
			</table>
		</out:if>
	</xsl:template>
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	



	
	
	
	
	
	<!-- 
	Template - mt:h3:
		This template renders the third line of the main pages.
		Operation:
			Renders each of the tabs for main portal pages (Welcome,Public Folders,My Folders for main page) along with the tools 
			available to the user (Directory,Capabilities,Schedule Management,Server Administration and Deployment) on the third line.
	-->

	<xsl:template match="mt:h3">
		<out:if test="not(contains($ui_black_list, ' CC_VIEW '))">
			<table class="mainHeader3" cellspacing="0" cellpadding="0" border="0" width="100%">
				<tr>
					<!-- Tab bar -->
					<out:choose>
						<!-- Skip showing the tab bar if it is supposed to be hidden -->
						<out:when test="not(contains($ui_black_list, ' CC_VIEW_TABS '))">							
							<xsl:choose>
								<!-- Consumer UI tab bar - We handle this here instead of the source morphlet -->
								<xsl:when test="@mode = 'main'">							
									
									<!-- Tab menu options -->
									<!-- Hide portal page options from users that cannot update their account (e.g. anonymous) -->	
									<out:if test="key('session-param', 'write') = 'true' and not(contains($ui_black_list, ' CC_VIEW_TABS_OPTIONS '))">													
										<td style="padding-left:2px;">
											<xsl:call-template name="buildTabMenuOptions"/>
										</td>				
									</out:if>				
								
									<out:choose>
										<!-- Single tab mode -->
										<out:when test="$isSingleTabRequest and not(/root/search)">	
											<xsl:call-template name="renderSinglePageTab"/>
										</out:when>										
										<!-- Normal tab mode -->
										<out:otherwise>						
											<!-- Show Portal Tabs -->
											<xsl:call-template name="renderPersonalTabBar"/>									
										</out:otherwise>
									</out:choose>							
								</xsl:when>
							
								<!-- Administration -->
								<xsl:otherwise>	
									<td valign="bottom">							
										<xsl:apply-templates select="mt:tabs/child::node()"/>		
									</td>									
								</xsl:otherwise>
								</xsl:choose>
							</out:when>
							
							<!-- Tab bar is supposed to be hidden.  Draw a line instead. -->			
							<out:otherwise>
								<td width="100%" class="tabTail">&#160;</td>
							</out:otherwise>
						</out:choose>					
				</tr>
			</table>
		</out:if>
	</xsl:template>
	

	
	
	
	
	<!-- 
	Template - mt:h4:
		This template renders the fourth line of the main pages.  The path and the toolbar buttons.
	-->
	<xsl:template match="mt:h4">
		<out:if test="not(contains($ui_black_list, ' CC_TOOLBAR '))">
			
			<xsl:choose>			
				<xsl:when test="@cogadmin='true'">
					<table width="100%" cellspacing="0" style="padding-right:3px; padding-left:3px;">
						<tbody>
							<tr>
								<!-- Path -->
								<out:if test="not(contains($ui_black_list, ' CC_TOOLBAR_PATH '))">
									<td width="100%" nowrap="" style="padding-left: 10px;" class="dialogHeaderText">
										<xsl:apply-templates select="mt:path/child::node()"/>				
									</td>
								</out:if>					
								
								<!-- Toolbar buttons -->	
								<out:if test="not(contains($ui_black_list, ' CC_TOOLBAR_BUTTONS '))">
									<td valign="middle" nowrap="">
										<xsl:apply-templates select="mt:toolbar"/>
									</td>
								</out:if>
							</tr>
						</tbody>
					</table>
				</xsl:when>
				<xsl:otherwise>
					<table width="100%" border="0" cellpadding="0" cellspacing="3">
						<tr>
							<!-- Path -->
							<out:if test="not(contains($ui_black_list, ' CC_TOOLBAR_PATH '))">
								<td valign="middle" width="100%" class="dialogHeaderText">
									<xsl:apply-templates select="mt:path/child::node()"/>				
								</td>
							</out:if>					
											
							<td width="100%">
								<img height="30" width="1" src="{'{$webcontent}'}/images/space.gif"/>
							</td>
							
							<!-- Toolbar buttons -->	
							<out:if test="not(contains($ui_black_list, ' CC_TOOLBAR_BUTTONS '))">
								<td valign="top">
									<table width="100%" border="0" cellpadding="0" cellspacing="3">
										<tr>				
											<xsl:apply-templates select="mt:toolbar"/>
										</tr>
									</table>
								</td>
							</out:if>
						</tr>
					</table>
				</xsl:otherwise>
			</xsl:choose>
		</out:if>		
		<!-- out:if test="string(/root/session/param[@name='useAccessibilityFeatures']) = 'true'" -->
			<a id="jumptocontent" tabindex="0">
				<img src="{'{$webcontent}'}/images/space.gif" width="1" height="1" border="0">
					<out:attribute name="alt"><xts:string id="IDS_SECTION508_CONTENT"/></out:attribute>
					<out:attribute name="title"><xts:string id="IDS_SECTION508_CONTENT"/></out:attribute>
				</img>
			</a>
		<!-- /out:if -->
	</xsl:template>
	
	
	<!-- Consumer portal tab menu options -->
	<xsl:template name="buildTabMenuOptions">
		<out:variable name="pageMenu">
			<flyout id="TabsMenu">
				<items>
					<out:if test="not($isSingleTabRequest)">
						<item id="addTab">
							<text><xts:string id="IDS_PAGE_MENU_ADD_PAGE"/></text>
							<action>pageCmd('add');</action>
						</item>
					</out:if>
					<out:if test="$canAddPageToPortal">
						<item id="addToMyPages">
							<text><xts:string id="IDS_PAGE_MENU_ADD_TO_PAGES"/></text>
							<action>pageCmd('addToMyPages');</action>
						</item>											
					</out:if>
					<out:if test="$isPersonalPortalPage">
						<item id="removeTab">
							<text><xts:string id="IDS_PAGE_MENU_REMOVE_PAGE"/></text>
							<action>pageCmd('remove');</action>
						</item>																							
					</out:if>
					<out:if test="count($portalPages/*) > 1 and not($isSingleTabRequest)">
						<item id="resequenceTabs">
							<text><xts:string id="IDS_PAGE_MENU_MODIFY_SEQUENCE"/></text>
							<action>pageCmd('resequence');</action>
						</item>																																			
					</out:if>
					<out:if test="$canEditPage">
						<item id="editPage">
							<text><xts:string id="IDS_PAGE_MENU_EDIT_PAGE"/></text>
							<action>pageCmd('edit');</action>
						</item>													
					</out:if>
					<out:if test="$isSingleTabRequest">
						<item id="myPortal">
							<text><xts:string id="IDS_PAGE_MENU_MY_PAGES"/></text>
							<action>pageCmd('myPortal');</action>
						</item>												
					</out:if>
				</items>
			</flyout>
		</out:variable>
	
		<out:call-template name="renderPopup">
			<out:with-param name="flyoutXML">
				<out:copy-of select="$pageMenu"/>
			</out:with-param>
			<out:with-param name="controlID">tabscontroldiv</out:with-param>
		</out:call-template> 
		
		<div id="tabscontroldiv" class="tabMenuButtonNormal" style="position: relative; cursor:pointer;z-index:15;" onmouseover="this.className='tabMenuButtonOver'"	onmouseout="this.className='tabMenuButtonNormal'">
			<div tabindex="0" accessKey="1" onkeypress="return CCPopupMenu.dropDown(event,0,0,'TabsMenu');" onclick="return CCPopupMenu.dropDown(event,0,0,'TabsMenu');">
				<span style="cursor:pointer; position:relative;">
					<img style="vertical-align: absmiddle; " name="pageMenu_imgFlyControl" src="{'{$skin_images}'}page_menu.gif" >
						<out:attribute name="alt"><xts:string id="IDS_PAGE_MENU_TOOLTIP"/></out:attribute>
						<out:attribute name="title"><xts:string id="IDS_PAGE_MENU_TOOLTIP"/></out:attribute>
					</img>
				</span>
			</div>
		</div>
	</xsl:template>

	<!-- Single tab view -->
	<xsl:template name="renderSinglePageTab">
		<td style="padding-left:3px;"><img src="{'{$skin_images}'}icon_collapsed_tabs.gif"/></td>
		<td style="padding-left:10px;padding-right:10px;">							
			<div style="height:15px;" class="ccOptionsDivider"/>
		</td>		
		<td valign="bottom" width="100%" style="padding-right:5px;padding-left:2px;">
			<table style="padding-bottom:2px;" border="0" width="100%" cellpadding="0" cellspacing="0" class="singlePageDisplayHeader">
				<tr>
					<td align="left" nowrap="nowrap" class="singlePageName">
						<out:call-template name="genWarningSigns">	
							<out:with-param name="pageProp" select="$pageProperties/*"/>
						</out:call-template>		
						<out:call-template name="genTabLable">	
							<out:with-param name="CMClass" select="$pageClass"/>
							<out:with-param name="CMName" select="$pageName"/>
						</out:call-template>
					</td>
					<td width="100%" class="formText" nowrap="nowrap" style="text-align:right;">									
						<out:if test="$canAddPageToPortal">
							<a href="javascript:pageCmd('addToMyPages')"><xts:string id="IDS_PAGE_MENU_ADD_TO_PAGES"/></a>
						</out:if>									
						&#160;&#160;
						<out:choose>
							<out:when test="key('env-param', 'backURL') != ''">
								<a href="{'{key(&quot;env-param&quot;, &quot;backURL&quot;)}'}"><xts:string id="IDS_PAGE_MENU_MY_PAGES"/></a>
							</out:when>
							<out:otherwise>
								<a href="javascript:defaultPortalView()"><xts:string id="IDS_PAGE_MENU_MY_PAGES"/></a>
							</out:otherwise>
						</out:choose>									
					</td>
				</tr>
			</table>	
		</td>
	</xsl:template>
	
	<!-- Personal tab bar -->
	<xsl:template name="renderPersonalTabBar">		
		<!-- build the tab XML -->
		<out:variable name="tabs">				
			<out:for-each select="$portalPages/*">														
				<!-- Build the tab label -->	
				<out:variable name="tabLabel">
					<out:call-template name="genTabLable">	
						<out:with-param name="CMClass" select="cm:objectClass"/>
						<out:with-param name="CMName" select="cm:defaultName"/>
					</out:call-template>
				</out:variable>		
				
				<!-- Build warning if there is any -->	
				<out:variable name="warning">
					<out:call-template name="genWarningSigns">	
						<out:with-param name="pageProp" select="."/>
					</out:call-template>
				</out:variable>		
							
				<tab>
					<out:choose>
						<out:when test="cm:storeID = $pageID">
							<out:attribute name="selected">true</out:attribute>
							<out:copy-of select="$warning"/>
							<out:value-of select="$tabLabel"/>								 
						</out:when>					
						<out:otherwise>
							<!-- Show any warnings -->						
							<out:copy-of select="$warning"/>			
							<!-- Render the link -->						
							<a class="tabAnchor">
								<out:attribute name="href">
									<out:call-template name="genTabURL">	
										<out:with-param name="pageID" select="cm:storeID"/>
										<out:with-param name="pageClass" select="cm:objectClass"/>										
									</out:call-template>					
								</out:attribute>
								<out:value-of select="$tabLabel"/>
							</a>
						</out:otherwise>
					</out:choose>
				</tab>						
			</out:for-each>			
		</out:variable>		
		
		<!-- Render the tab bar -->
		<td valign="bottom" width="100%" style="padding-left:2px;">
			<out:call-template name="renderTabs">
				<out:with-param name="tabs" select="$tabs"/>
				<out:with-param name="scroll" select="true()"/>
			</out:call-template>	
		</td>
	</xsl:template>

	
	
	<!-- 
		Template - mt:toolbar:
	-->
	<xsl:template match="mt:toolbar">
		<script language="javascript">
			var frmCmdForm = "<out:value-of select="$cmd-form"/>";
			var frmEditForm = "<out:value-of select="$edit-form"/>";
			var defaultPrefix = "checkbox_";
				
			<!-- common functions for "Edit" tools -->				
			var sDelimiter = "<out:value-of select="xtsext:javascriptencode(string(key('system-param', 'delimiters')/@d1))"/>"; <!-- used to delimit entries -->
			
			<xsl:choose>
				<xsl:when test="@cogadmin='true'">
					var toolbarImageNormal = "toolbarImageNormal2";
				</xsl:when>
				<xsl:otherwise>
					var toolbarImageNormal = "toolbarImageNormal";
				</xsl:otherwise>
			</xsl:choose>
			
			<![CDATA[
			
			//<!-- change the images for the toolbar during a mouseover -->
			function mouseoverImage(item)
			{	
				if (item.className == toolbarImageNormal)
					item.className = 'toolbarImageOver';
				if (item.className == 'toolbarImagePressed')
					item.className = 'toolbarImageOverPressed';
			}
			//<!-- change the images for the toolbar during a mouseout	-->	
			function mouseoutImage(item)
			{	
				if (item.className == 'toolbarImageOver')
					item.className = toolbarImageNormal;
				if (item.className == 'toolbarImageOverPressed')
					item.className = 'toolbarImagePressed';
			}
			
			//<!-- Determines if the total number of selected entries exceeds a given limit. Returns true if the limit is exceeded, false if it is not. -->
			function isOverItemsLimit(limit)
			{   
				//<!-- Don't bother doing any check if the limit passed in is bogus (none integer)-->
				if (isNaN(limit)  ||  (limit < 0)  ||  (Math.floor(limit) < limit) )
					return false;
				
				var bLimitExceeded = false;
				var items = document.forms[frmEditForm].elements.length;
				var counter = 0;
				for (var i=0; i<items; i++)
				{
					if (document.forms[frmEditForm].elements[i].name.substring(0,9) == "checkbox_" && document.forms[frmEditForm].elements[i].checked)
					{	
						counter++;
						if (counter > limit)
						{
							bLimitExceeded = true;
							break;							
						}
					}						
				}
				return bLimitExceeded;
			}
			]]>
			
			function doNew(newClass)
			{
				if (newClass == 'dashboard')
				{
					window.location.href = "<out:value-of select="/root/gatewayURI/configuration/property[@name='WEB.GATEWAY_URI']"/>"
					return;
				}
				
			
				if (newClass == 'pagelet' &amp;&amp; document.forms[frmCmdForm].m_path.value == '')
				{
					document.forms[frmCmdForm].m_path.value = "<out:value-of select="xtsext:javascriptencode(key('session-param', 'e_mrootpath'))"/>";
				}
					
				document.forms[frmCmdForm].m.value = "<out:value-of select="$app"/>/new_general.xts";
				document.forms[frmCmdForm].m_new_class.value = newClass;
				document.forms[frmCmdForm].backURL.value= "<out:value-of select="xtsext:javascriptencode(string($back-url))"/>";
				document.forms[frmCmdForm].submit();
			}			
		</script>
		<script language="javascript" src="{'{$webcontent}'}/{'{$app}'}/js/list.js"></script>	
		<xsl:apply-templates />
	</xsl:template>
	
	<xsl:template match="mt:tool-group">
		<xsl:variable name="hideDivider"><xsl:value-of select="string(@hideDivider)"/></xsl:variable>
		<xsl:choose>
			<xsl:when test="@cogadmin='true'">
					<style>
					.toolbarImageNormal2 {
						padding: 3px;
						cursor: pointer;
					}
					
					.toolbarImageUnavailable2 {
						padding: 3px; 
					}
					</style>
				<xsl:apply-templates />
				<xsl:if test="@lastgroup != 'true'">
					<td valign="middle"><img style="padding-left: 3px; padding-right: 3px;" src="{'{$webcontent}/cogadmin/images/divider.gif'}" /></td>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="$hideDivider='true'">
						<td style="padding-left:5px;"/>
					</xsl:when>
					<xsl:otherwise>
						<td class="toolbarDividerContainer"><div class="toolbarDivider"/></td>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:apply-templates/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<!-- Toolbar buttons	-->
	<xsl:template match="mt:tool[not(@name)]">
		<td onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
		<xsl:apply-templates/>
		</td>
	</xsl:template>

	<!--	New	-->
	<xsl:template match="mt:tool[@name='new']">
		<xsl:variable name="image">
			<xsl:choose>				
				<xsl:when test="@new-class = 'folder' or @new-class='subscriptionFolder'">
					<xsl:choose>
						<xsl:when test="not(string(@disable) = 'true')">action_new_folder.gif</xsl:when>
						<xsl:otherwise>action_new_folder_dis.gif</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="@new-class = 'pagelet'">action_new_page.gif</xsl:when>
				<xsl:when test="@new-class = 'namespaceFolder'">
					<xsl:choose>
						<xsl:when test="string(@disable) = 'true'">action_new_folder_dis.gif</xsl:when>
						<xsl:otherwise>action_new_folder.gif</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="@new-class = 'adminFolder'">
					<xsl:choose>
						<xsl:when test="string(@disable) = 'true'">action_new_folder_dis.gif</xsl:when>
						<xsl:otherwise>action_new_folder.gif</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="@new-class = 'portletFolder'">
					<xsl:choose>
						<xsl:when test="string(@disable) = 'true'">action_new_folder_dis.gif</xsl:when>
						<xsl:otherwise>action_new_folder_dis.gif</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="@new-class = 'contentTask'">
					<xsl:choose>
						<xsl:when test="string(@disable) = 'true'">action_new_content_task_drop_arrow_dis.gif</xsl:when>
						<xsl:otherwise>action_new_content_task_drop_arrow.gif</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="@new-class = 'indexUpdateTask'">
					<xsl:choose>
						<xsl:when test="string(@disable) = 'true'">action_new_index_update_dis.gif</xsl:when>
						<xsl:otherwise>action_new_index_update.gif</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="@new-class = 'URL'">action_new_url.gif</xsl:when>
				<xsl:when test="@new-class = 'dataSource'">
					<xsl:choose>
						<xsl:when test="string(@disable) = 'true'">action_new_datasource_dis.gif</xsl:when>
						<xsl:otherwise>action_new_data_source.gif</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="@new-class = 'dataSourceConnection'">
					<xsl:choose>
						<xsl:when test="string(@disable) = 'true'">action_new_connection_dis.gif</xsl:when>
						<xsl:otherwise>action_new_connection.gif</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="@new-class = 'dataSourceSignon'">
					<xsl:choose>
						<xsl:when test="string(@disable) = 'true'">action_new_signon_dis.gif</xsl:when>
						<xsl:otherwise>action_new_signon.gif</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="@new-class = 'role'">
					<xsl:choose>
						<xsl:when test="string(@disable) = 'true'">action_new_role_dis.gif</xsl:when>
						<xsl:otherwise>action_new_role.gif</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="@new-class = 'group'">
					<xsl:choose>
						<xsl:when test="string(@disable) = 'true'">action_new_group_dis.gif</xsl:when>
						<xsl:otherwise>action_new_group.gif</xsl:otherwise>
					</xsl:choose>
				</xsl:when>				
				<xsl:when test="@new-class = 'jobDefinition'">
					<xsl:choose>
						<xsl:when test="string(@disable) = 'true'">action_new_job_dis.gif</xsl:when>
						<xsl:otherwise>action_new_job.gif</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="@new-class = 'configurationFolder'">
					<xsl:choose>
						<xsl:when test="string(@disable) = 'true'">action_new_configuration_folder_dis.gif</xsl:when>
						<xsl:otherwise>action_new_folder.gif</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="@new-class = 'contact'">
					<xsl:choose>
						<xsl:when test="string(@disable) = 'true'">action_new_contact_dis.gif</xsl:when>
						<xsl:otherwise>action_new_contact.gif</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="@new-class = 'distributionList'">
					<xsl:choose>
						<xsl:when test="string(@disable) = 'true'">action_new_distribution_list_dis.gif</xsl:when>
						<xsl:otherwise>action_new_distribution_list.gif</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="@new-class = 'printer'">
					<xsl:choose>
						<xsl:when test="string(@disable) = 'true'">action_new_printer_dis.gif</xsl:when>
						<xsl:otherwise>action_new_printer.gif</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="@new-class = 'metricsIntegrationTaskGroup'">action_new_data_integration_drop_arrow.gif</xsl:when>
				<xsl:when test="@new-class = 'metricsPackage'">
					<xsl:choose>
						<xsl:when test="string(@disable) = 'true'">action_new_metrics_package_dis.gif</xsl:when>
						<xsl:otherwise>action_new_metrics_package.gif</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="@new-class = 'drillPath'">
					<xsl:choose>
						<xsl:when test="string(@disable) = 'true'">action_new_drill_through_dis.gif</xsl:when>
						<xsl:otherwise>action_new_drill_through.gif</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="@new-class = 'portalSkin'">
					<xsl:choose>
						<xsl:when test="string(@disable) = 'true'">action_new_style_wizard_dis.gif</xsl:when>
						<xsl:otherwise>action_new_style_wizard.gif</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="@new-class = 'dashboard'">
					<xsl:choose>
						<xsl:when test="string(@disable) = 'true'">action_new_dashboard_dis.gif</xsl:when>
						<xsl:otherwise>action_new_dashboard.gif</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="alt-id">
			<xsl:choose>
				<xsl:when test="@new-class = 'adminFolder' or  @new-class = 'folder' or @new-class = 'namespaceFolder' or @new-class = 'portletFolder' or @new-class = 'subscriptionFolder'">IDS_NEW_FOLDER</xsl:when>
				<xsl:when test="@new-class = 'pagelet'">IDS_NEW_PAGELET</xsl:when>
				<xsl:when test="@new-class = 'printer'">IDS_NEW_PRINTER_TIP</xsl:when>
				<xsl:when test="@new-class = 'contentTask'">IDS_MAIN_NEW_CONTENT_TASK</xsl:when>
				<xsl:when test="@new-class = 'indexUpdateTask'">IDS_MAIN_NEW_INDEX_UPDATE_TASK</xsl:when>
				<xsl:when test="@new-class = 'URL'">IDS_NEW_SHORTCUT_TO_URL</xsl:when>
				<xsl:when test="@new-class = 'dataSource'">IDS_NEW_DATA_SOURCE</xsl:when>
				<xsl:when test="@new-class = 'dataSourceConnection'">IDS_NEW_CONNECTION</xsl:when>
				<xsl:when test="@new-class = 'dataSourceSignon'">IDS_NEW_SIGNON</xsl:when>
				<xsl:when test="@new-class = 'role'">IDS_NEW_COGNOS_ROLE</xsl:when>
				<xsl:when test="@new-class = 'group'">IDS_NEW_COGNOS_GROUP</xsl:when>
				<xsl:when test="@new-class = 'jobDefinition'">IDS_NEW_JOB</xsl:when>
				<xsl:when test="@new-class = 'configurationFolder'">IDS_NEW_CONFIGURATION_FOLDER</xsl:when>
				<xsl:when test="@new-class = 'contact'">IDS_NEW_CONTACT</xsl:when>
				<xsl:when test="@new-class = 'distributionList'">IDS_NEW_DISTRIBUTION_LIST</xsl:when>
				<xsl:when test="@new-class = 'metricsIntegrationTaskGroup'">IDS_METRICS_INTEGRATION_TASK_GROUP_TIP</xsl:when>
				<xsl:when test="@new-class = 'metricsPackage'">IDS_NEW_METRICS_PACKAGE_TIP</xsl:when>
				<xsl:when test="@new-class = 'drillPath'">IDS_NEW_DRILLPATH</xsl:when>
				<xsl:when test="@new-class = 'portalSkin'">IDS_NEW_PORTALSKIN</xsl:when>
				<xsl:when test="@new-class = 'dashboard'">IDS_NEW_DASHBOARD</xsl:when>
			</xsl:choose>
		</xsl:variable>		
		
		<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_new{@new-class}'))"> 
			<xsl:choose>
				<xsl:when test="@new-class='contentTask' and @disable!='true'">
					<script language="JavaScript">
						function newContentTask(cmd)
						{
							document.forms[frmCmdForm].contentTaskType.value = cmd;
							doNew('contentTask');
						}
					</script>
					<out:variable name="contentTaskMenu">
						<flyout id="contentTask">
							<items>
								<item id="consistency">
									<text><xts:string id="IDS_CONTENT_TASK_NEW_CONSISTENCY"/></text>
									<action>newContentTask("consistency");</action>
								</item>
								<item id="reportUpgrade">
									<text><xts:string id="IDS_CONTENT_TASK_NEW_REPORT_UPGRADE"/></text>
									<action>newContentTask("reportUpgrade");</action>
								</item>
							</items>
						</flyout>
					</out:variable>
					<out:call-template name="renderPopup">
						<out:with-param name="flyoutXML">
							<out:copy-of select="$contentTaskMenu"/>
						</out:with-param>
						<out:with-param name="controlID">contentTaskMenu_td</out:with-param>
					</out:call-template>
					<out:variable name="altText"><xts:string id="{$alt-id}"/></out:variable>
					<td class="toolbarFlyoutNormal" onmouseover="this.className='toolbarFlyoutOver'" onmouseout="this.className='toolbarFlyoutNormal'" height="20">
						<div style="position: relative; cursor:pointer;z-index:9;" id="contentTaskMenu_td">
							<div tabindex="0" accessKey="1" onkeypress="return CCPopupMenu.dropDown(event,0,0,'contentTask');" onclick="return CCPopupMenu.dropDown(event,0,0,'contentTask');">
								<span style="cursor:pointer; position:relative;">
									<img style="vertical-align: absmiddle; " name="contentTaskMenu_imgFlyControl" src="{'{$image_root}'}{$image}" title="{'{$altText}'}" alt="{'{$altText}'}"/>
								</span>
							</div>
						</div>					
					</td>
				</xsl:when>
				<xsl:when test="@new-class='metricsIntegrationTaskGroup'">					 
					<script language="javascript">
						<out:attribute name="src"><out:value-of select="$webcontent"/><out:value-of select="concat('/',$app)"/><xsl:value-of select="'/js/utilities.js'"/></out:attribute>
					</script>
					<script language="JavaScript">
						function createMetricTask(sReportType, location, pkg)
						{
							if(sReportType!='metricsFileImportTask' &amp;&amp; sReportType!='metricsMaintenanceTask' &amp;&amp; sReportType!='metricsExportTask')
								return;
								
							var curDoc = document.<out:value-of select="$cmd-form"/>;
							if (curDoc)
							{
								setFormInputElement('so.select','newmetricstaskspackage','hidden','<out:value-of select="$cmd-form"/>');
								setFormInputElement('so.backURL',sBackURL,'hidden','<out:value-of select="$cmd-form"/>');
								setFormInputElement('backURL',sBackURL,'hidden','<out:value-of select="$cmd-form"/>');
								setFormInputElement('so.return.m','<out:value-of select="$app"/>/new_general.xts','hidden','<out:value-of select="$cmd-form"/>');
								setFormInputElement('so.defaultObject',pkg,'hidden','<out:value-of select="$cmd-form"/>');
								setFormInputElement('so.defaultLocation',location,'hidden','<out:value-of select="$cmd-form"/>');
								setFormInputElement('m_new_class',sReportType,'hidden','<out:value-of select="$cmd-form"/>');
								curDoc.m.value = "<out:value-of select="$app"/>/newMetricsTasks/processNewTasks.xts";
								<out:variable name="javatarget2">
									<out:choose>
										<out:when test="/root/env/param[@name='wtarget'] = 'top'">_top</out:when>
										<out:when test="/root/env/param[@name='wtarget'] = 'parent'">_parent</out:when>
										<out:when test="/root/env/param[@name='wtarget'] = 'blank'">_blank</out:when>
										<out:when test="/root/env/param[@name='wtarget'] = 'self'">_self</out:when>
									</out:choose>
								</out:variable>
								<out:if test="$javatarget2 != ''">
								curDoc.target= "<out:value-of select="$javatarget2"/>";
								</out:if>
								window.setTimeout( "document.<out:value-of select="$cmd-form"/>.submit();" , 1 );
							}
						}

						function newMetricsTask(cmd)
						{
							switch (cmd)
							{
								case 'NewMetricsFileImport':
									createMetricTask('metricsFileImportTask', '<out:value-of select="xtsext:javascriptencode(string($location))"/>', '<out:value-of select="xtsext:javascriptencode(string($pkg))"/>');
								break;
								case 'NewMetricsMaintenance':
									createMetricTask('metricsMaintenanceTask', '<out:value-of select="xtsext:javascriptencode(string($location))"/>', '<out:value-of select="xtsext:javascriptencode(string($pkg))"/>');
								break;
								case 'NewMetricsExport':
									createMetricTask('metricsExportTask', '<out:value-of select="xtsext:javascriptencode(string($location))"/>', '<out:value-of select="xtsext:javascriptencode(string($pkg))"/>');
								break;
							}
						}
					</script>
					<out:variable name="metricsIntegrationTaskMenu">
						<flyout id="metricsIntegrationTaskMenu">
							<items>
								<item id="NewMetricsFileImport">
									<text><xts:string id="IDS_NEW_METRICS_MENU_FILE_IMPORT"/></text>
									<action>newMetricsTask("NewMetricsFileImport");</action>
								</item>
								<item id="NewMetricsMaintenance">
									<text><xts:string id="IDS_NEW_METRICS_MENU_MAINTENANCE"/></text>
									<action>newMetricsTask("NewMetricsMaintenance");</action>
								</item>
								<item id="NewMetricsExport">
									<text><xts:string id="IDS_NEW_METRICS_MENU_EXPORT"/></text>
									<action>newMetricsTask("NewMetricsExport");</action>
								</item>									
							</items>
						</flyout>
					</out:variable>
					<out:call-template name="renderPopup">
						<out:with-param name="flyoutXML">
							<out:copy-of select="$metricsIntegrationTaskMenu"/>
						</out:with-param>
						<out:with-param name="controlID">metricsIntegrationTaskHomeMenu_span</out:with-param>
					</out:call-template>
					<out:variable name="altText"><xts:string id="{$alt-id}"/></out:variable>
					<td class="toolbarFlyoutNormal" onmouseover="this.className='toolbarFlyoutOver'" onmouseout="this.className='toolbarFlyoutNormal'">
						<div style="position: relative; cursor:pointer;z-index:10;" id="metricsIntegrationTaskHomeMenu_span">	
							<div tabindex="0" accessKey="1" onkeypress="return CCPopupMenu.dropDown(event,0,0,'metricsIntegrationTaskMenu');" onclick="return CCPopupMenu.dropDown(event,0,0,'metricsIntegrationTaskMenu');">
								<span style="cursor:pointer; position:relative;">
									<img style="vertical-align: absmiddle; " name="metricsIntegrationTaskHomeMenu_imgFlyControl" src="{'{$image_root}'}{$image}" title="{'{$altText}'}" alt="{'{$altText}'}"/>
								</span>
							</div>
						</div>
					</td>					
				</xsl:when>
				<xsl:otherwise>
					<td onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
						<xsl:choose>
							<xsl:when test="@cogadmin='true'"><xsl:attribute name="class">toolbarImageNormal2</xsl:attribute></xsl:when>
							<xsl:otherwise><xsl:attribute name="class">toolbarImageNormal</xsl:attribute></xsl:otherwise>
						</xsl:choose>
						<xsl:choose>
							<xsl:when test="@new-class='metricsPackage' and @disable != 'true'">
								<a>
									<out:attribute name="href">
										<out:value-of select="$gateway"/>
										<out:text/>?b_action=mms.run&amp;pid=new_mpwizard_start<out:text/>
										<out:text/>&amp;ui.backURL=<out:value-of select="$encoded-back-url"/><out:text/>
									</out:attribute>
									<img height="16" width="16" border="0" src="{'{$image_root}'}{$image}">
										<out:attribute name="alt"><xts:string id="{$alt-id}"/></out:attribute>
									</img>
								</a>	
							</xsl:when>
							<xsl:otherwise>
								<xsl:choose>
									<xsl:when test="@disable = 'true' and contains('portalSkin metricsPackage contentTask indexUpdateTask adminFolder jobDefinition dataSourceConnection dataSource group role printer namespaceFolder contact distributionList drillPath configurationFolder', string(@new-class))">
									<td class="toolbarImageUnavailable" onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
										<img height="16" width="16" border="0" src="{'{$image_root}'}{$image}">
											<out:attribute name="alt"><xts:string id="{$alt-id}"/></out:attribute>
										</img>	
									</td>							
									</xsl:when>
									<xsl:otherwise>		
										<a href="javascript:doNew('{@new-class}')">
											<img height="16" width="16" border="0" src="{'{$image_root}'}{$image}">
												<out:attribute name="alt"><xts:string id="{$alt-id}"/></out:attribute>
											</img>
										</a>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:otherwise>
						</xsl:choose>
					</td>
				</xsl:otherwise>
			</xsl:choose>
		</out:if>
	</xsl:template>
	
	<!-- New Import (Special case.  Does not use the common "New" template) -->
	<xsl:template match="mt:tool[@name='import']">
		<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_{@name}'))">
				<xsl:choose>
					<xsl:when test="@disable ='true'">
						<td class="toolbarImageUnavailable" onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
						<img height="16" width="16" border="0" src="{'{$image_root}'}action_new_import_dis.gif">
							<out:attribute name="alt"><xts:string id="IDS_MAIN_NEW_IMPORT"/></out:attribute>
						</img>
						</td>
					</xsl:when>
					<xsl:otherwise>
						<td onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
						<xsl:choose>
							<xsl:when test="@cogadmin='true'"><xsl:attribute name="class">toolbarImageNormal2</xsl:attribute></xsl:when>
							<xsl:otherwise><xsl:attribute name="class">toolbarImageNormal</xsl:attribute></xsl:otherwise>
						</xsl:choose>
						<xsl:choose>
							<xsl:when test="@cogadmin='true'"><xsl:attribute name="class">toolbarImageNormal2</xsl:attribute></xsl:when>
							<xsl:otherwise><xsl:attribute name="class">toolbarImageNormal</xsl:attribute></xsl:otherwise>
						</xsl:choose>
						<a>
							<out:attribute name="href">
								<out:value-of select="$gateway"/>?b_action=xts.run&amp;m=<out:value-of select="$app"/><out:value-of select="'/new_deployment2.xts'"/>
								<out:text/>&amp;m_class=importDeployment&amp;m_setArchiveChanged=false&amp;m_selectArchivePageVisited=false&amp;m_deploymentWizardPage=select-archive&amp;m_path=<out:value-of select="xtsext:protect(xtsext:urlencode(string($m_path)),'url','searchPath','getdata')"/>
								<out:text/>&amp;backURL=<out:value-of select="$encoded-back-url"/>				
								<out:text/>&amp;from_tool=true<out:text/>
							</out:attribute>				
							<img height="16" width="16" border="0" src="{'{$image_root}'}action_new_import.gif">
								<out:attribute name="alt"><xts:string id="IDS_MAIN_NEW_IMPORT"/></out:attribute>
							</img>
						</a>
						</td>
					</xsl:otherwise>
				</xsl:choose>
		</out:if>
	</xsl:template>
	
	
	<!-- New Export (Special case.  Does not use the common "New" template) -->
	<xsl:template match=" mt:tool[@name='export'] ">
		<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_{@name}'))">
				<xsl:choose>
					<xsl:when test="@disable ='true'">
						<td class="toolbarImageUnavailable" onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
						<img height="16" width="16" border="0" src="{'{$image_root}'}action_new_export_dis.gif">
							<out:attribute name="alt"><xts:string id="IDS_MAIN_NEW_EXPORT"/></out:attribute>
						</img>
						</td>
					</xsl:when>
					<xsl:otherwise>
						<td onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
						<xsl:choose>
							<xsl:when test="@cogadmin='true'"><xsl:attribute name="class">toolbarImageNormal2</xsl:attribute></xsl:when>
							<xsl:otherwise><xsl:attribute name="class">toolbarImageNormal</xsl:attribute></xsl:otherwise>
						</xsl:choose>
						<a>
							<out:attribute name="href">
								<out:value-of select="$gateway"/>?b_action=xts.run&amp;m=<out:value-of select="$app"/><out:value-of select="'/new_general.xts'"/>
							<out:text/>&amp;m_new_class=exportDeployment&amp;m_deploymentWizardPage=method&amp;m_setArchiveChanged=true&amp;m_archive&amp;m_class=exportDeployment&amp;m_path=<out:value-of select="xtsext:protect(xtsext:urlencode(string($m_path)),'url','searchPath','getdata')"/>
						<out:text/>&amp;backURL=<out:value-of select="$encoded-back-url"/>		
						<out:text/>&amp;from_tool=true<out:text/>
						</out:attribute>
						<img height="16" width="16" border="0" src="{'{$image_root}'}action_new_export.gif">
							<out:attribute name="alt"><xts:string id="IDS_MAIN_NEW_EXPORT"/></out:attribute>
						</img>
						</a>
						</td>
					</xsl:otherwise>
				</xsl:choose>
		</out:if>
	</xsl:template>

	
	<!-- Cut	-->
	<xsl:template match=" mt:tool[@name='cut'] ">
		<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_{@name}'))">
			<out:variable name="cutContext"><xsl:call-template name="mt:contentcontext"/></out:variable>
			<td id="cut" onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
				<out:choose>
					<out:when test="'{@disable}'='true' or $cutContext = 'unknown'">
						<out:attribute name="class">toolbarImageUnavailable</out:attribute>
						<a>
							<img height="16" width="16" border="0" src="{'{$image_root}'}action_cut_dis.gif">
								<out:attribute name="alt"><xts:string id="IDS_CUT"/></out:attribute>
							</img>
						</a>
					</out:when>
					<out:otherwise>
						<out:choose>
							<out:when test="starts-with(key('session-param', 'edit'),'move')">
								<out:attribute name="class">toolbarImagePressed</out:attribute>
							</out:when>
							<out:otherwise>
								<xsl:choose>
									<xsl:when test="@cogadmin='true'"><out:attribute name="class">toolbarImageNormal2</out:attribute></xsl:when>
									<xsl:otherwise><out:attribute name="class">toolbarImageNormal</out:attribute></xsl:otherwise>
								</xsl:choose>
							</out:otherwise>
						</out:choose>
						<a href="javascript:doCut()">
							<img height="16" width="16" border="0" src="{'{$image_root}'}action_cut.gif">
								<out:attribute name="alt"><xts:string id="IDS_CUT"/></out:attribute>
							</img>
						</a>
						<script language="javascript">
							function switchCut(state) 
							{
								if ("<out:value-of select="$browser"/>" == "ie") 
								{					
									if (state == "on")
										document.all["cut"].className="toolbarImagePressed";				
									else
										document.all["cut"].className="toolbarImageNormal";	
								}
							}				
										
							function doCut()
							{
								var sContext = '<out:value-of select="$cutContext"/>';
								var s1 = "<xts:string id="IDS_ERR_CUT_NO_SELECTION" encode="javascript"/>";
				
								if (isEmptySelection(frmEditForm, defaultPrefix))
								{
									alert( s1 );
									return;
								}
								
								<out:if test="key('system-param', 'maxEditEntries') and key('system-param', 'maxEditEntries') != ''">
									var s2 = "<xts:string id="IDS_ERR_LIMIT_EXCEEDED" encode="javascript"><xts:param name="limit"><out:value-of select="key('system-param', 'maxEditEntries')"/></xts:param></xts:string>";
					
									if (isOverItemsLimit("<out:value-of select="key('system-param', 'maxEditEntries')"/>"))
									{
										alert( s2 );
										return;
									}						
								</out:if>				
								
								<!-- Flag a cut operation -->
								setStateValue("edit", "move_" + sContext);
								switchCut("on");
								if (document.all &amp;&amp; document.all["copy"] &amp;&amp; document.switchCopy)
									switchCopy("off");
								
								document.forms[frmEditForm].m.value = "<out:value-of select="$app"/>/<out:value-of select="$mname"/>";
								document.forms[frmEditForm].submit();
								if (document.body) 
									document.body.style.cursor = "wait";
							}				
						</script>
					</out:otherwise>
				</out:choose>
			</td>
		</out:if>
	</xsl:template>
	
	
	<!-- Copy	-->
	<xsl:template match=" mt:tool[@name='copy'] ">
		<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_{@name}'))">
			<out:variable name="copyContext"><xsl:call-template name="mt:contentcontext"/></out:variable>
			<td onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
				<out:choose>
					<out:when test="'{@disable}'='true' or $copyContext = 'unknown'">
						<!-- <out:attribute name="class">toolbarImageUnavailable</out:attribute> -->
						<xsl:choose>
							<xsl:when test="@cogadmin='true'"><out:attribute name="class">toolbarImageUnavailable2</out:attribute></xsl:when>
							<xsl:otherwise><out:attribute name="class">toolbarImageUnavailable</out:attribute></xsl:otherwise>
						</xsl:choose>
						<a>
							<img height="16" width="16" border="0" src="{'{$image_root}'}action_copy_dis.gif">
								<out:attribute name="alt"><xts:string id="IDS_COPY"/></out:attribute>
							</img>
						</a>
					</out:when>
					<out:otherwise>
						<out:attribute name="id">copy</out:attribute>
						<out:choose>
							<out:when test="starts-with(key('session-param', 'edit'),'copy')">
								<out:attribute name="class">toolbarImagePressed</out:attribute>
							</out:when>
							<out:otherwise>
								<xsl:choose>
									<xsl:when test="@cogadmin='true'"><out:attribute name="class">toolbarImageNormal2</out:attribute></xsl:when>
									<xsl:otherwise><out:attribute name="class">toolbarImageNormal</out:attribute></xsl:otherwise>
								</xsl:choose>
							</out:otherwise>
						</out:choose>
						<a href="javascript:doCopy()">
							<img height="16" width="16" border="0">
								<xsl:attribute name="src"><xsl:value-of select="'{$image_root}'"/>action_copy.gif</xsl:attribute>
								<out:attribute name="alt"><xts:string id="IDS_COPY"/></out:attribute>
							</img>
						</a>
						<script language="javascript">			
							//<!-- apply changes to the classes-->
							function switchCopy(state) 
							{
								if ("<out:value-of select="$browser"/>" == "ie") 
								{											
									if (state == "on")
										document.all["copy"].className="toolbarImagePressed";				
									else 
										document.all["copy"].className="toolbarImageNormal";	
								}
							}				
						
							function doCopy()
							{	
								var sContext = '<out:value-of select="$copyContext"/>';
								var s1 = "<xts:string id="IDS_ERR_COPY_NO_SELECTION" encode="javascript"/>";
								
								if (isEmptySelection(frmEditForm, defaultPrefix))
								{
									alert( s1 );
									return;
								}
								
								<out:if test="key('system-param', 'maxEditEntries') and key('system-param', 'maxEditEntries') != ''">
									var s2 = "<xts:string id="IDS_ERR_LIMIT_EXCEEDED" encode="javascript"><xts:param name="limit"><out:value-of select="key('system-param', 'maxEditEntries')"/></xts:param></xts:string>";
									if (isOverItemsLimit("<out:value-of select="key('system-param', 'maxEditEntries')"/>"))
									{
										alert( s2 );
										return;
									}						
								</out:if>				
			
								if (document.all &amp;&amp; document.all["cut"] &amp;&amp; document.switchCut)
									switchCut("off");
								<!-- flag a copy operation -->
								setStateValue("edit", "copy_" + sContext);
								switchCopy("on");
	
								document.forms[frmEditForm].m.value = "<out:value-of select="$app"/>/<out:value-of select="$mname"/>";

								document.forms[frmEditForm].submit();									
								if (document.body) 
									document.body.style.cursor = "wait";			
							}				
						</script>
					</out:otherwise>
				</out:choose>
			</td>
		</out:if>
	</xsl:template>
	
	
	<!-- Paste	-->
	<xsl:template match=" mt:tool[@name='paste'] ">
		<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_{@name}'))">
			<out:variable name="pasteContext"><xsl:call-template name="mt:contentcontext"/></out:variable>
			<td id="paste" onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
				<out:choose>
					<out:when test="(starts-with(key('session-param', 'edit'),'copy') or starts-with(key('session-param', 'edit'),'move')) and contains(key('session-param', 'edit'), $pasteContext) and not($pasteContext = 'unknown') and '{@disable}' != 'true'">
						<xsl:choose>
							<xsl:when test="@cogadmin='true'"><out:attribute name="class">toolbarImageNormal2</out:attribute></xsl:when>
							<xsl:otherwise><out:attribute name="class">toolbarImageNormal</out:attribute></xsl:otherwise>
						</xsl:choose>
						<a href="javascript:doPaste()" name="paste-link">
							<img height="16" width="16" border="0" name="paste-img" src="{'{$image_root}'}action_paste.gif">
								<out:attribute name="alt"><xts:string id="IDS_PASTE"/></out:attribute>
							</img>
						</a>
					</out:when>
					<out:otherwise>
						<xsl:choose>
							<xsl:when test="@cogadmin='true'"><out:attribute name="class">toolbarImageUnavailable2</out:attribute></xsl:when>
							<xsl:otherwise><out:attribute name="class">toolbarImageUnavailable</out:attribute></xsl:otherwise>
						</xsl:choose>
						<img height="16" width="16" border="0" name="paste-img" src="{'{$image_root}'}action_paste_dis.gif">
							<out:attribute name="alt"><xts:string id="IDS_PASTE"/></out:attribute>
						</img>
					</out:otherwise>
				</out:choose>
				<script language="javascript">
					//define the two paste images				
					var pasteImg = new Image();
					pasteImg.src = "<out:value-of select="$image_root"/>action_paste.gif";
					var pasteDisabledImg = new Image();
					pasteDisabledImg.src = "<out:value-of select="$image_root"/>action_paste_dis.gif";
	
					//<!-- this will switch the paste icon and class -->
					function switchPaste(state) 
					{
						if (state == "on") 
						{
							document.images["paste-img"].src = pasteImg.src;	
							if ("<out:value-of select="$browser"/>" == "ie") 
							{											
								document.all["paste-link"].className  = "";								
								document.all["paste"].className = "toolbarImageNormal";						
							}	
						} 
						else 
						{
							document.images["paste-img"].src = pasteDisabledImg.src;	
							if ("<out:value-of select="$browser"/>" == "ie") 
							{											
								document.all["paste-link"].className  = "toolbarImageDefaultCursor";															
								document.all["paste"].className = "toolbarImageUnavailable";		
							}	
						}
					}

					function doPaste()
					{
						var sContext = '<out:value-of select="$pasteContext"/>';
						var s1 = "<xts:string id="IDS_ERR_PASTE_NO_SELECTION" encode="javascript"/>";
						var s5 = "<xts:string id="IDS_ERR_PASTE_CONFIG" encode="javascript"/>";
	
						var sEditCommand = getSessionValue("edit");
						var aEditCommand = sEditCommand.split("_");
						
						//<!-- If entries have not been "coppied" or "cut" then there is no point of being here -->
						if ( !((aEditCommand[0] == "move" || aEditCommand[0] == "copy") &amp;&amp; (aEditCommand[1] == sContext) ) )
						{
							alert( s1 );
							return;
						}
	
						<xsl:if test="@type and @type = 'config'">
							if (!confirm ( s5 ))
								return;
						</xsl:if>				

						if (aEditCommand[0] == "move")
							resetStateParam('edit');	<!-- Reset any pending edit operation -->
						
						<!-- Save full page state -->
						document.forms[frmEditForm].backURL.value = "<out:value-of select="xtsext:javascriptencode(string($back-url))"/>";

						document.forms[frmEditForm].m.value = "<out:value-of select="$app"/>/submit.xts";
						document.forms[frmEditForm].ifrmcmd.value = aEditCommand[0];
						document.forms[frmEditForm].submit();

						if (document.body) 
							document.body.style.cursor = "wait";				
					}			
				</script>	
			</td>
		</out:if>
	</xsl:template>
	
	
	<!-- Delete	-->
	<xsl:template match=" mt:tool[@name='delete'] ">
		<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_{@name}'))">
			<td onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
				<xsl:choose>
					<xsl:when test="@disable='true'">
						<out:attribute name="class"></out:attribute>
						<xsl:choose>
							<xsl:when test="@cogadmin='true'"><out:attribute name="class">toolbarImageUnavailable2</out:attribute></xsl:when>
							<xsl:otherwise><out:attribute name="class">toolbarImageUnavailable</out:attribute></xsl:otherwise>
						</xsl:choose>
						<a>
							<img height="16" width="16" border="0" src="{'{$image_root}'}action_delete_dis.gif">
								<out:attribute name="alt"><xts:string id="IDS_DELETE"/></out:attribute>
							</img>
						</a>	
					</xsl:when>
					<xsl:otherwise>
						<xsl:choose>
							<xsl:when test="@cogadmin='true'"><out:attribute name="class">toolbarImageNormal2</out:attribute></xsl:when>
							<xsl:otherwise><out:attribute name="class">toolbarImageNormal</out:attribute></xsl:otherwise>
						</xsl:choose>
						<a href="javascript:doDelete()">
							<img height="16" width="16" border="0">
								<xsl:attribute name="src"><xsl:value-of select="'{$image_root}'"/>action_delete.gif</xsl:attribute>
								<out:attribute name="alt"><xts:string id="IDS_DELETE"/></out:attribute>
							</img>
						</a>	
						<script language="javascript">
						<xsl:choose>
							<!-- Config Delete : Delete action in server admin configure tab. User can only delete configuration folder without any contents, and can't delete dispatcher. -->
							<xsl:when test="@type and @type = 'config'">
							function doDelete()
							{
								var s1 = "<xts:string id="IDS_ERR_DELETE_NO_SELECTION" encode="javascript"/>";
								var s2 = "<xts:string id="IDS_ERR_DELETE_CONFIG" encode="javascript"/>";
								var s3 = "<xts:string id="IDS_CONF_DELETE_MULTI" encode="javascript"/>";
								var s4 = "<xts:string id="IDS_ERR_DELETE_CONFIG_DISP" encode="javascript"/>";
								var s5 = "<xts:string id="IDS_ERR_DELETE_CONFIG_FOLDER" encode="javascript"/>";
																
								var isInvalidDisp = false;
								var isInvalidFolder = false;
								var len = 0;
								
								var items = document.forms[frmEditForm].length;
								for (var i=0; i &lt; items; i++)
								{
									if (document.forms[frmEditForm].elements[i].name.indexOf(defaultPrefix) == 0 &amp;&amp; document.forms[frmEditForm].elements[i].checked)
									{
										if (document.forms[frmEditForm].elements[i].name.indexOf("checkbox_dispatcher_") == 0)
										{
											isInvalidDisp = true;
										}
										else 
										{
											if (document.forms[frmEditForm].elements[i].name.indexOf("checkbox_configurationFolder_true_") == 0)
											{
												isInvalidFolder = true;
											}
											else
											{
												len = len +1;	
											}
										}
									}	
								}
								
								<!-- check for no selection -->
								if (len == 0 &amp;&amp; !isInvalidDisp &amp;&amp; !isInvalidFolder)
								{
									alert( s1 );
									return;
								}
			
								<!-- check if user try to delete the dispatchers and configuration folders with contents. -->
								if ( isInvalidDisp &amp;&amp; isInvalidFolder)
								{
									 alert( s2 );
								}
								else
								{
									<!-- check if user try to delete a configuration folders with contents. -->					
									if (isInvalidFolder)
										 alert( s5 );
	
									<!-- check if user try to delete a dispatchers with contents. -->
									if (isInvalidDisp)
										 alert( s4 );
								}
								
			
								if ( len &gt; 0 )
								{	
									<!--Perform the delete after confirmation -->
									if ( confirm( s3 ) )
									{
										if( window.preDelete )
											preDelete(frmEditForm, defaultPrefix);
										document.forms[frmEditForm].ifrmcmd.value = "delete";   <!--set the operation, and submit it.	-->
										document.forms[frmEditForm].backURL.value = "<out:value-of select="xtsext:javascriptencode(string($back-url))"/>";
										document.forms[frmEditForm].m.value = "<out:value-of select="$app"/>/submit.xts";
										resetStateParam("edit");	<!-- Reset any pending edit operation -->
										document.forms[frmEditForm].submit();
									}
								}
							}	
							</xsl:when>
							<xsl:otherwise>
							
							function doDelete()
							{
								var s1 = "<xts:string id="IDS_ERR_DELETE_NO_SELECTION" encode="javascript"/>";
								var s2 = "<xts:string id="IDS_CONF_DELETE_BROKEN_LINKS" encode="javascript"/>";
								
								if ( isEmptySelection(frmEditForm, defaultPrefix))
								{
									alert( s1 );
									return;
								}

															
								<!-- Perform the delete after confirmation -->
								if ( confirm( s2 ) )
								{
									if( window.preDelete )
										preDelete(frmEditForm, defaultPrefix);
									document.forms[frmEditForm].ifrmcmd.value = "delete";   <!--set the operation, and submit it.	-->
									<!-- Add full page state -->
									document.forms[frmEditForm].backURL.value = "<out:value-of select="xtsext:javascriptencode(string($back-url))"/>";
									document.forms[frmEditForm].m.value = "<out:value-of select="$app"/>/submit.xts";
									document.forms[frmEditForm].errURL.value = document.forms[frmEditForm].backURL.value;
									resetStateParam("edit");	<!-- Reset any pending edit operation -->
									document.forms[frmEditForm].submit();
								}
							
							}			
							</xsl:otherwise>
						</xsl:choose>
						</script>
					</xsl:otherwise>
				</xsl:choose>			
			</td>
		</out:if>
	</xsl:template>	
	
	
	<!-- Refresh 	-->
	<xsl:template match=" mt:tool[@name='refresh'] ">
		<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_{@name}'))">
			<td onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
				<xsl:choose>
					<xsl:when test="not(string(@disable) = 'true')">
						<xsl:choose>
							<xsl:when test="@cogadmin='true'"><out:attribute name="class">toolbarImageNormal2</out:attribute></xsl:when>
							<xsl:otherwise><out:attribute name="class">toolbarImageNormal</out:attribute></xsl:otherwise>
						</xsl:choose>
						<a href="javascript:window.location.reload(true)">
							<img height="16" width="16" border="0" src="{'{$image_root}'}action_refresh.gif">
								<out:attribute name="alt"><xts:string id="IDS_REFRESH"/></out:attribute>
							</img>
						</a>
					</xsl:when>
					<xsl:otherwise>
						<xsl:choose>
							<xsl:when test="@cogadmin='true'"><out:attribute name="class">toolbarImageUnavailable2</out:attribute></xsl:when>
							<xsl:otherwise><out:attribute name="class">toolbarImageUnavailable</out:attribute></xsl:otherwise>
						</xsl:choose>
							<img height="16" width="16" border="0" src="{'{$image_root}'}action_refresh_dis.gif">
								<out:attribute name="alt"><xts:string id="IDS_REFRESH"/></out:attribute>
							</img>					
					</xsl:otherwise>
				</xsl:choose>
			</td>
		</out:if>
	</xsl:template>
	
	<!-- Refresh using GET	-->
	<xsl:template match=" mt:tool[@name='refreshUsingGet'] ">
		<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_{@name}'))">
			<td onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
				<xsl:choose>
					<xsl:when test="not(string(@disable) = 'true')">
						<out:attribute name="class">toolbarImageNormal</out:attribute>
						<a>
							<xsl:attribute name="href"><xsl:value-of select="'{$back-url}'"/>&amp;refresh=</xsl:attribute>
							<img height="16" width="16" border="0" src="{'{$image_root}'}action_refresh.gif">
								<out:attribute name="alt"><xts:string id="IDS_REFRESH"/></out:attribute>
							</img>
						</a>
					</xsl:when>
					<xsl:otherwise>
						<out:attribute name="class">toolbarImageUnavailable</out:attribute>					
							<img height="16" width="16" border="0" src="{'{$image_root}'}action_refresh_dis.gif">
								<out:attribute name="alt"><xts:string id="IDS_REFRESH"/></out:attribute>
							</img>					
					</xsl:otherwise>
				</xsl:choose>
			</td>
		</out:if>
	</xsl:template>

	<!-- Select all -->
	<xsl:template match=" mt:tool[@name='selectall'] ">
		<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_{@name}'))">
			<td onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
				<xsl:choose>
					<xsl:when test="string(@disable)='true'">
						<out:attribute name="class">toolbarImageUnavailable</out:attribute>
						<img height="16" width="16" border="0" src="{'{$image_root}'}action_selectall_dis.gif">
							<out:attribute name="alt"><xts:string id="IDS_SELECT_PAGE_TIP"/></out:attribute>
						</img>
					</xsl:when>
					<xsl:otherwise>
						<out:attribute name="class">toolbarImageNormal</out:attribute>
						<a href="javascript:setCheck(true,'{'{$edit-form}'}','checkbox_')">
							<img height="16" width="16" border="0" src="{'{$image_root}'}action_selectall.gif">
								<out:attribute name="alt"><xts:string id="IDS_SELECT_PAGE_TIP"/></out:attribute>
							</img>
						</a>
					</xsl:otherwise>
				</xsl:choose>
			</td>
		</out:if>
	</xsl:template>
	
	
	<!-- Deselect all -->
	<xsl:template match=" mt:tool[@name='deselectall'] ">
		<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_{@name}'))">
			<td onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
				<xsl:choose>
					<xsl:when test="string(@disable)='true'">
						<out:attribute name="class">toolbarImageUnavailable</out:attribute>
						<img height="16" width="16" border="0" src="{'{$image_root}'}action_deselectall_dis.gif">
							<out:attribute name="alt"><xts:string id="IDS_DESELECT_PAGE_TIP"/></out:attribute>
						</img>
					</xsl:when>
					<xsl:otherwise>
						<out:attribute name="class">toolbarImageNormal</out:attribute>
						<a href="javascript:setCheck(false,'{'{$edit-form}'}','checkbox_')">
							<img height="16" width="16" border="0" src="{'{$image_root}'}action_deselectall.gif">
								<out:attribute name="alt"><xts:string id="IDS_DESELECT_PAGE_TIP"/></out:attribute>
							</img>
						</a>
					</xsl:otherwise>
				</xsl:choose>
			</td>
		</out:if>
	</xsl:template>
	
	
	<!-- Detail view	-->
	<xsl:template match=" mt:tool[@name='detail'] ">
		<out:if test="key('session-param', 'write') = 'true' or $is-named = '0'">
			<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_{@name}'))">
				<td>
					<out:choose>
 						<out:when test="key('session-param', 'displayMode') = 'detail'">
							<out:attribute name="class">toolbarImagePressed</out:attribute>
							<out:attribute name="onmouseover">this.className = 'toolbarImageOverPressed'</out:attribute>
							<out:attribute name="onmouseout">this.className = 'toolbarImagePressed'</out:attribute>
						</out:when>
						<out:otherwise>
							<out:attribute name="class">toolbarImageNormal</out:attribute>
							<out:attribute name="onmouseover">this.className = 'toolbarImageOver'</out:attribute>
							<out:attribute name="onmouseout">this.className = 'toolbarImageNormal'</out:attribute>
						</out:otherwise>
					</out:choose>
					<a href="javascript:doDetailView()">
						<img height="16" width="16" border="0" src="{'{$image_root}'}action_detailview.gif">
							<out:attribute name="alt"><xts:string id="IDS_DETAILS_VIEW"/></out:attribute>
						</img>
					</a>
					<script language="javascript">
						function doDetailView()
						{
							var cmdForm = document.<out:value-of select="$cmd-form"/>;
							cmdForm.m.value = "<out:value-of select="$app"/>/submit.xts";
							cmdForm.ifrmcmd.value = "save";
							cmdForm.m_obj.value = "~";
							cmdForm.m_class.value = "account";
							cmdForm.backURL.value = "<out:value-of select="xtsext:javascriptencode(string($back-url))"/>";

							var homePageElement = document.createElement("input");
							homePageElement.setAttribute("type","hidden");
							homePageElement.setAttribute("name","m_po_displayMode");
							homePageElement.setAttribute("value","detail");
							cmdForm.appendChild(homePageElement);

							cmdForm.submit();
						}
					</script>
				</td>
			</out:if>
		</out:if>
	</xsl:template>
	
	
	<!-- List view	-->
	<xsl:template match=" mt:tool[@name='list'] ">
		<out:if test="key('session-param', 'write') = 'true' or $is-named = '0'">
			<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_{@name}'))">
				<td>
					<out:choose>
						<out:when test="key('session-param', 'displayMode') = 'list'">
							<out:attribute name="class">toolbarImagePressed</out:attribute>
							<out:attribute name="onmouseover">this.className = 'toolbarImageOverPressed'</out:attribute>
							<out:attribute name="onmouseout">this.className = 'toolbarImagePressed'</out:attribute>
						</out:when>
						<out:otherwise>
							<out:attribute name="class">toolbarImageNormal</out:attribute>
							<out:attribute name="onmouseover">this.className = 'toolbarImageOver'</out:attribute>
							<out:attribute name="onmouseout">this.className = 'toolbarImageNormal'</out:attribute>
						</out:otherwise>
					</out:choose>
									
					<a href="javascript:doListView()">
						<img height="16" width="16" border="0" src="{'{$image_root}'}action_listview.gif">
							<out:attribute name="alt"><xts:string id="IDS_LIST_VIEW"/></out:attribute>					
						</img>
					</a>				
					<script language="javascript">
						function doListView()
						{
							var cmdForm = document.<out:value-of select="$cmd-form"/>;
							cmdForm.m.value = "<out:value-of select="$app"/>/submit.xts";
							cmdForm.ifrmcmd.value = "save";
							cmdForm.m_obj.value = "~";
							cmdForm.m_class.value = "account";
							cmdForm.backURL.value = "<out:value-of select="xtsext:javascriptencode(string($back-url))"/>";

							var homePageElement = document.createElement("input");
							homePageElement.setAttribute("type","hidden");
							homePageElement.setAttribute("name","m_po_displayMode");
							homePageElement.setAttribute("value","list");
							cmdForm.appendChild(homePageElement);

							cmdForm.submit();
						}
					</script>
				</td>
			</out:if>
		</out:if>
	</xsl:template>
	
	<!-- Order -->
	<xsl:template match=" mt:tool[@name='order'] ">
		<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_{@name}'))">
			<out:variable name="mp-permissions" select="count($childReply/*[cm:usage != 'subObject' and not(contains(cm:permissions, 'read') and contains(cm:permissions, 'write'))])"/>
			<out:choose>
				<out:when test="$childReply/*[cm:usage != 'subObject'] and $mp-permissions = 0">
					<td onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
						<xsl:choose>
							<xsl:when test="@cogadmin='true'"><xsl:attribute name="class">toolbarImageNormal2</xsl:attribute></xsl:when>
							<xsl:otherwise><xsl:attribute name="class">toolbarImageNormal</xsl:attribute></xsl:otherwise>
						</xsl:choose>
						<a>
							<out:attribute name="href">
								<out:value-of select="$gateway"/>?b_action=xts.run&amp;m=<out:value-of select="$app"/>/sort.xts&amp;m_path=<out:value-of select="xtsext:protect(xtsext:urlencode(string($m_path)),'url','searchPath','getdata')"/>&amp;backURL=<out:value-of select="xtsext:protect(xtsext:urlencode(string($back-url)),'url','url','getdata')"/>
							</out:attribute>				
							<img height="16" width="16" border="0" src="{'{$image_root}'}action_order.gif">
								<out:attribute name="alt"><xts:string id="IDS_ORDER"/></out:attribute>
							</img>	
						</a>
					</td>
				</out:when>	
				<out:otherwise>
					<td class="toolbarImageUnavailable" onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
						<img height="16" width="16" border="0" src="{'{$image_root}'}action_order_dis.gif">
							<out:attribute name="alt"><xts:string id="IDS_ORDER"/></out:attribute>
						</img>
					</td>	
				</out:otherwise>
			</out:choose>
		</out:if>
	</xsl:template>
	
	
	<!-- Edit Pagelet -->
	<xsl:template match=" mt:tool[@name='edit_pagelet'] ">
		<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_{@name}'))">
			
				<td onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
						<xsl:choose>
							<xsl:when test="@cogadmin='true'"><xsl:attribute name="class">toolbarImageNormal2</xsl:attribute></xsl:when>
							<xsl:otherwise><xsl:attribute name="class">toolbarImageNormal</xsl:attribute></xsl:otherwise>
						</xsl:choose>
					<a href="#" onclick="editPage('{'{$pageID}'}')">
						<img height="16" width="16" border="0" src="{'{$image_root}'}action_edit_page.gif">
							<out:attribute name="alt"><xts:string id="IDS_EDIT"/></out:attribute>
						</img>
					</a>
				</td>
				
		</out:if>
	</xsl:template>
	
	
	<!-- Search	-->
	<xsl:template match=" mt:tool[@name='search']">
			<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_{@name}'))">
				<out:choose>
				<!-- Disable the search feature for schedule tool,  and directory tool when current path is root /directory-->
				<out:when test="'{string(@disable)}' = 'true' or $mname = 'tools_activity.xts' or /root/env/param[@name='m_path'] = '/directory' ">
					<td onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
						<xsl:choose>
							<xsl:when test="@cogadmin='true'"><xsl:attribute name="class">toolbarImageUnavailable2</xsl:attribute></xsl:when>
							<xsl:otherwise><xsl:attribute name="class">toolbarImageUnavailable</xsl:attribute></xsl:otherwise>
						</xsl:choose>
						<img height="16" width="16" border="0" src="{'{$image_root}'}action_search_basic_dis.gif">
							<out:attribute name="alt"><xts:string id="IDS_SEARCH"/></out:attribute>
						</img>
					</td>
				</out:when>
				<out:otherwise>
					<td onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
						<xsl:choose>
							<xsl:when test="@cogadmin='true'"><xsl:attribute name="class">toolbarImageNormal2</xsl:attribute></xsl:when>
							<xsl:otherwise><xsl:attribute name="class">toolbarImageNormal</xsl:attribute></xsl:otherwise>
						</xsl:choose>
						<a href="{'{$back-url}'}&amp;search=">			
							<img height="16" width="16" border="0" src="{'{$image_root}'}action_search_basic.gif">
								<out:attribute name="alt"><xts:string id="IDS_SEARCH"/></out:attribute>
							</img>
						</a>
					</td>
				</out:otherwise>
				</out:choose>
			</out:if>
	</xsl:template>

	
	<!-- Root properties -->
	<xsl:template match=" mt:tool[@name='properties'] ">
		<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_{@name}'))">
			<!-- need to disable the properties button if there was no root response -->
			<!-- this can occurr if viewing a pf or mf page but the container being view is not accessible -->
			<!-- because of security or it does not exist -->
			<out:choose>
				<out:when test="$rootReply and ($rootReply  != '')">
					<td onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
						<xsl:choose>
							<xsl:when test="@cogadmin='true'"><xsl:attribute name="class">toolbarImageNormal2</xsl:attribute></xsl:when>
							<xsl:otherwise><xsl:attribute name="class">toolbarImageNormal</xsl:attribute></xsl:otherwise>
						</xsl:choose>
						<a href="#">
							<out:attribute name="onclick">
								<out:text/>rootProperties('<out:value-of select="xtsext:javascriptencode(string($rootReply/*/cm:defaultName))"/>', '<out:value-of select="$rootReply/*/cm:objectClass"/>', '<out:value-of select="xtsext:javascriptencode(string($rootReply/*/cm:searchPath))"/>', '<out:value-of select="xtsext:javascriptencode(string($rootReply/*/cm:storeID))"/>');<out:text/>
							</out:attribute>				
							<img height="16" width="16" border="0" src="{'{$image_root}'}action_properties_path.gif">
								<out:attribute name="alt"><xts:string id="IDS_PROPERTIES"/><out:value-of select="' - '"/><out:value-of select="$rootReply/*/cm:defaultName"/></out:attribute>
							</img>	
						</a>
					</td>
				</out:when>
				<out:otherwise>
					<td class="toolbarImageUnavailable" onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
						<img height="16" width="16" border="0" src="{'{$image_root}'}action_properties_path_dis.gif">
								<out:attribute name="alt"><xts:string id="IDS_PROPERTIES"/><out:value-of select="' - '"/><out:value-of select="$rootReply/*/cm:defaultName"/></out:attribute>
						</img>	
					</td>
				</out:otherwise>
			</out:choose>
		</out:if>
	</xsl:template>
	
	<xsl:template match=" mt:tool[@name='routingRules'] ">
		<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_{@name}'))">
			<td onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
						<xsl:choose>
							<xsl:when test="@cogadmin='true'"><xsl:attribute name="class">toolbarImageNormal2</xsl:attribute></xsl:when>
							<xsl:otherwise><xsl:attribute name="class">toolbarImageNormal</xsl:attribute></xsl:otherwise>
						</xsl:choose>
				<a>
					<out:attribute name="href">
						<out:value-of select="$gateway"/>?b_action=xts.run&amp;m=<out:value-of select="$app"/><out:value-of select="'/specify_routing_rules.xts'"/>
						<out:text/>&amp;m_class=configuration&amp;m_obj=/configuration&amp;backURL=<out:value-of select="$encoded-back-url"/>		
					</out:attribute>
					<img height="16" width="16" border="0" src="{'{$image_root}'}action_define_routing_rules.gif">
						<out:attribute name="alt"><xts:string id="IDS_EDIT_ROUTING_RULE"/></out:attribute>
					</img>
				</a>
			</td>
		</out:if>
	</xsl:template>
	
	<xsl:template match=" mt:tool[@name='defaultUserProfile'] ">
		<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_{@name}'))">
			<td onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
						<xsl:choose>
							<xsl:when test="@cogadmin='true'"><xsl:attribute name="class">toolbarImageNormal2</xsl:attribute></xsl:when>
							<xsl:otherwise><xsl:attribute name="class">toolbarImageNormal</xsl:attribute></xsl:otherwise>
						</xsl:choose>
				<a>
					<out:attribute name="href">
						<out:value-of select="$gateway"/>?b_action=xts.run&amp;m=<out:value-of select="$app"/><out:value-of select="'/properties_general.xts'"/>
						<out:text/>&amp;m_class=account&amp;m_obj=/configuration/account&amp;backURL=<out:value-of select="$encoded-back-url"/>		
					</out:attribute>
					<img height="16" width="16" border="0" src="{'{$image_root}'}action_edit_user_profile.gif">
						<out:attribute name="alt"><xts:string id="IDS_EDIT_DEFAULT_USER_PROFILE"/></out:attribute>
					</img>
				</a>
			</td>
		</out:if>
	</xsl:template>

	
	<xsl:template match=" mt:tool[@name='removeMeAlert']">
		<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_{@name}'))">
			<td onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
				<xsl:choose>
					<xsl:when test="@disable='true'">
						<out:attribute name="class"></out:attribute>
						<out:attribute name="class">toolbarImageUnavailable</out:attribute>
						<a>
							<img height="16" width="16" border="0" src="{'{$image_root}'}action_remove_from_list.gif">
								<out:attribute name="alt"><xts:string id="IDS_ACT_REMOVE_NOTIFICATION"/></out:attribute>
							</img>
						</a>	
					</xsl:when>
					<xsl:otherwise>
						<out:attribute name="class">toolbarImageNormal</out:attribute>
						<a href="javascript:doRemoveMe()">
							<img height="16" width="16" border="0">
								<xsl:attribute name="src"><xsl:value-of select="'{$image_root}'"/>action_remove_from_list.gif</xsl:attribute>
								<out:attribute name="alt"><xts:string id="IDS_ACT_REMOVE_NOTIFICATION"/></out:attribute>
							</img>
						</a>	
						<script language="javascript">
						function doRemoveMe()
							{
								var s1 = "<xts:string id="IDS_ERR_DELETE_NO_SELECTION" encode="javascript"/>";
								
								if ( isEmptySelection(frmEditForm, defaultPrefix))
								{
									alert( s1 );
									return;
								}
								
								if ( confirm("<xts:string id="IDS_MYSUB_TOOL_CONFIRM" encode="javascript"/>") )
								{ 
									action("submit.xts", "removeMultiObjNotification");
								}
							}
							
							function action(sTarget, sAction)
							{	
								if (sAction != null &amp;&amp; sAction != "" )
									document.pform.ifrmcmd.value = sAction;
	
								document.pform.m.value = "<out:value-of select="$app"/>/" + sTarget;
								document.pform.backURL.value = "<out:value-of select="xtsext:javascriptencode(string($back-url))"/>";
								document.pform.submit();
							} 					
						</script>
					</xsl:otherwise>
				</xsl:choose>			
			</td>
		</out:if>
	</xsl:template>
	
	
	<!-- Can be used by any UI that requries an action to edit the parent object's properties
		  Supported Sub-elements include
		 		- tool-name: Used to generate UI black list entry name. This allows each tool to be configured uniquely
				- default-name: Used as part of the the tooltip text
				- object-class:  Class of the parent object
				- search-path:	  SearchPath of the parent object
	-->
	<xsl:template match="mt:tool[@name='parent_properties']">
		<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_{tool-name}'))">
			<td onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
						<xsl:choose>
							<xsl:when test="@cogadmin='true'"><xsl:attribute name="class">toolbarImageNormal2</xsl:attribute></xsl:when>
							<xsl:otherwise><xsl:attribute name="class">toolbarImageNormal</xsl:attribute></xsl:otherwise>
						</xsl:choose>
				<a href="#">
					<out:attribute name="onclick">
						<out:choose>
							<out:when test="string({request-path}/cm:storeID) != ''">
								<out:text/>parentProperties('<out:value-of select="xtsext:javascriptencode(string({request-path}/cm:defaultName))"/>', '<out:value-of select="{request-path}/cm:objectClass"/>', '<out:value-of select="xtsext:javascriptencode(string({request-path}/cm:searchPath))"/>','storeID("<out:value-of select="xtsext:javascriptencode(string({request-path}/cm:storeID))"/>")');<out:text/>
							</out:when>
							<out:otherwise>
								<out:text/>parentProperties('<out:value-of select="xtsext:javascriptencode(string({request-path}/cm:defaultName))"/>', '<out:value-of select="{request-path}/cm:objectClass"/>', '<out:value-of select="xtsext:javascriptencode(string({request-path}/cm:searchPath))"/>','');<out:text/>
							</out:otherwise>
						</out:choose>
					</out:attribute>				
					<img height="16" width="16" border="0" src="{'{$image_root}'}action_properties_path.gif">
						<out:attribute name="alt"><xts:string id="IDS_PROPERTIES"/><out:value-of select="' - '"/><out:value-of select="{request-path}/cm:defaultName"/></out:attribute>
					</img>	
				</a>
			</td>
		</out:if>
	</xsl:template>


	<!-- Page sizes -->
	<xsl:template match=" mt:tool[@name='page_sizes'] ">
		<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_{@name}'))">
			<td onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
						<xsl:choose>
							<xsl:when test="@cogadmin='true'"><xsl:attribute name="class">toolbarImageNormal2</xsl:attribute></xsl:when>
							<xsl:otherwise><xsl:attribute name="class">toolbarImageNormal</xsl:attribute></xsl:otherwise>
						</xsl:choose>
				<a>
					<out:attribute name="href">
						<out:value-of select="$gateway"/>?b_action=xts.run&amp;m=<out:value-of select="$app"/>/edit_page_sizes.xts&amp;backURL=<out:value-of select="xtsext:protect(xtsext:urlencode(string($back-url)),'url','url','getdata')"/>
					</out:attribute>
					<img height="16" width="16" border="0" src="{'{$image_root}'}action_define_paper_sizes.gif">
						<out:attribute name="alt"><xts:string id="IDS_PAGE_SIZES"/></out:attribute>
					</img>
				</a>				
			</td>
		</out:if>
	</xsl:template>
	
	<!-- File system locations -->
	<xsl:template match=" mt:tool[@name='file_system_locations'] ">
		<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_{@name}'))">
			<td onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
						<xsl:choose>
							<xsl:when test="@cogadmin='true'"><xsl:attribute name="class">toolbarImageNormal2</xsl:attribute></xsl:when>
							<xsl:otherwise><xsl:attribute name="class">toolbarImageNormal</xsl:attribute></xsl:otherwise>
						</xsl:choose>
				<a>
					<out:attribute name="href">
						<out:value-of select="$gateway"/>?b_action=xts.run&amp;m=<out:value-of select="$app"/>/edit_file_system_locations.xts&amp;backURL=<out:value-of select="xtsext:protect(xtsext:urlencode(string($back-url)),'url','url','getdata')"/>
					</out:attribute>
					<img height="16" width="16" border="0" src="{'{$image_root}'}action_define_file_system_locations.gif">
						<out:attribute name="alt"><xts:string id="IDS_FILE_SYSTEM_LOCATIONS"/></out:attribute>
					</img>
				</a>				
			</td>
		</out:if>
	</xsl:template>
	
	<!-- Enable sched	-->
	<xsl:template match=" mt:tool[@name='enable_sched'] ">
		<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_{@name}'))">
			<td onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
						<xsl:choose>
							<xsl:when test="@cogadmin='true'"><xsl:attribute name="class">toolbarImageNormal2</xsl:attribute></xsl:when>
							<xsl:otherwise><xsl:attribute name="class">toolbarImageNormal</xsl:attribute></xsl:otherwise>
						</xsl:choose>
				<a href="javascript:doEnableSched()">
					<img height="16" width="16" border="0" src="{'{$image_root}'}action_enable_schedule.gif">
						<out:attribute name="alt"><xts:string id="IDS_ENABLE_SCHEDULE_TIP"/></out:attribute>
					</img>
				</a>	
				<script language="javascript">
					function doEnableSched()
					{
						var s1 = "<xts:string id="IDS_ERR_ENABLE_SCHED_NO_SELECTION" encode="javascript"/>";
						var s2 = "<xts:string id="IDS_CONF_ENABLE_SCHED_MULTI" encode="javascript"/>";
						
						<!-- check for no selection -->
						if (isEmptySelection(frmEditForm, defaultPrefix))
						{
							alert( s1 );
							return;
						}
						
						<!-- if enabling/disabling a reportDataServiceAgentDefinition we need to make sure a subscriptionFolder isn't checked by mistake	-->
						var items = document.forms[frmEditForm].length;
						for (var i=0; i &lt; items; i++)
						{
									if (document.forms[frmEditForm].elements[i].name.indexOf(defaultPrefix) == 0 &amp;&amp;  document.forms[frmEditForm].elements[i].checked)
									{
										if (document.forms[frmEditForm].elements[i].name.indexOf('subscriptionFolder') &gt;= 0)
										{
											alert("<xts:string id="IDS_ERR_NO_SCHED" encode="javascript"/>") ;
											return;
										}
								}	
						}

						<!--Perform the delete after confirmation -->
						if ( confirm( s2 ) )
						{
							document.forms[frmEditForm].ifrmcmd.value = 'enable';   <!--set the operation, and submit it.	-->
							document.forms[frmEditForm].m.value = "<out:value-of select="$app"/>/submit.xts";
							document.forms[frmEditForm].backURL.value = "<out:value-of select="xtsext:javascriptencode(string($back-url))"/>";						
							document.forms[frmEditForm].submit();
						
						}  
					}
				</script>
			</td>
		</out:if>
	</xsl:template>
	

	<!-- Disable sched 	-->
	<xsl:template match=" mt:tool[@name='disable_sched'] ">
		<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_{@name}'))">
			<td onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
						<xsl:choose>
							<xsl:when test="@cogadmin='true'"><xsl:attribute name="class">toolbarImageNormal2</xsl:attribute></xsl:when>
							<xsl:otherwise><xsl:attribute name="class">toolbarImageNormal</xsl:attribute></xsl:otherwise>
						</xsl:choose>
				<a href="javascript:doDisableSched()">
					<img height="16" width="16" border="0" src="{'{$image_root}'}action_disable_schedule.gif">
						<out:attribute name="alt"><xts:string id="IDS_DISABLE_SCHEDULE_TIP"/></out:attribute>
					</img>
				</a>	
				<script language="javascript">
					function doDisableSched()
					{
						var s1 = "<xts:string id="IDS_ERR_DISABLE_SCHED_NO_SELECTION" encode="javascript"/>";
						var s2 = "<xts:string id="IDS_CONF_DISABLE_SCHED_MULTI" encode="javascript"/>";
						
						<!-- check for no selection -->
						if (isEmptySelection(frmEditForm, defaultPrefix))
						{
							alert( s1 );
							return;
						}

						<!-- if enabling/disabling a reportDataServiceAgentDefinition we need to make sure a subscriptionFolder isn't checked by mistake	-->
						var items = document.forms[frmEditForm].length;
						for (var i=0; i &lt; items; i++)
						{
									if (document.forms[frmEditForm].elements[i].name.indexOf(defaultPrefix) == 0 &amp;&amp;  document.forms[frmEditForm].elements[i].checked)
									{
										if (document.forms[frmEditForm].elements[i].name.indexOf('subscriptionFolder') &gt;= 0)
										{
											alert("<xts:string id="IDS_ERR_NO_SCHED" encode="javascript"/>") ;
											return;
										}
								}	
						}
					
						<!--Perform the delete after confirmation -->
						if ( confirm( s2 ) )
						{
							document.forms[frmEditForm].ifrmcmd.value = 'disable';   <!--set the operation, and submit it.	-->
							document.forms[frmEditForm].m.value = "<out:value-of select="$app"/>/submit.xts";	
							document.forms[frmEditForm].backURL.value = "<out:value-of select="xtsext:javascriptencode(string($back-url))"/>";
							document.forms[frmEditForm].submit();
						}
					}
				</script>
			</td>
		</out:if>
	</xsl:template>
	
	<xsl:template match=" mt:doScheduleActionScripts">
		<script language="javascript">
			function doScheduleAction( action )
			{
						
				<!-- check for no selection -->
				if (isEmptySelection(frmEditForm, defaultPrefix))
				{
					alert("<xts:string id="IDS_ERR_DISABLE_SCHED_NO_SELECTION" encode="javascript"/>");
					return;
				}
																
				<!-- Perform the action -->	
				document.forms[frmEditForm].action.value = action;
				document.forms[frmEditForm].ifrmcmd.value = "doScheduleAction";
				document.forms[frmEditForm].m.value = "<out:value-of select="$app"/>/submit.xts";	
				document.forms[frmEditForm].backURL.value = "<out:value-of select="xtsext:javascriptencode(string($back-url))"/>";
				document.forms[frmEditForm].submit();
			}
		</script>
	</xsl:template>
	
<!-- Cancel sched 	-->
	<xsl:template match=" mt:tool[@name='cancel'] ">
		<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_{@name}'))">
			<td onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
						<xsl:choose>
							<xsl:when test="@cogadmin='true'"><xsl:attribute name="class">toolbarImageNormal2</xsl:attribute></xsl:when>
							<xsl:otherwise><xsl:attribute name="class">toolbarImageNormal</xsl:attribute></xsl:otherwise>
						</xsl:choose>
				<a href="javascript:doScheduleAction('cancel')">
					<img height="16" width="16" border="0" src="{'{$image_root}'}action_cancel_execution.gif">
						<out:attribute name="alt"><xts:string id="IDS_CANCEL"/></out:attribute>
					</img>
				</a>	
			</td>
		</out:if>
	</xsl:template>
	
	<xsl:template match=" mt:tool[@name='suspend'] ">
		<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_{@name}'))">
			<td onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
						<xsl:choose>
							<xsl:when test="@cogadmin='true'"><xsl:attribute name="class">toolbarImageNormal2</xsl:attribute></xsl:when>
							<xsl:otherwise><xsl:attribute name="class">toolbarImageNormal</xsl:attribute></xsl:otherwise>
						</xsl:choose>
				<a href="javascript:doScheduleAction('suspend')">
					<img height="16" width="16" border="0" src="{'{$image_root}'}action_suspend_execution.gif">
						<out:attribute name="alt"><xts:string id="IDS_SCHED_SUSPEND_TOOLTIP"/></out:attribute>
					</img>
				</a>	
			</td>
		</out:if>
	</xsl:template>
	
	<xsl:template match=" mt:tool[@name='release'] ">
		<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_{@name}'))">
			<td onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
						<xsl:choose>
							<xsl:when test="@cogadmin='true'"><xsl:attribute name="class">toolbarImageNormal2</xsl:attribute></xsl:when>
							<xsl:otherwise><xsl:attribute name="class">toolbarImageNormal</xsl:attribute></xsl:otherwise>
						</xsl:choose>
				<a href="javascript:doScheduleAction('release')">
					<img height="16" width="16" border="0" src="{'{$image_root}'}action_release_execution.gif">
						<out:attribute name="alt"><xts:string id="IDS_SCHED_RELEASE_TOOLTIP"/></out:attribute>
					</img>
				</a>	
			</td>
		</out:if>
	</xsl:template>

	
	<!-- View events	-->
	<xsl:template match=" mt:tool[@name='view_events'] ">
		<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_{@name}'))">
			<td onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
						<xsl:choose>
							<xsl:when test="@cogadmin='true'"><xsl:attribute name="class">toolbarImageNormal2</xsl:attribute></xsl:when>
							<xsl:otherwise><xsl:attribute name="class">toolbarImageNormal</xsl:attribute></xsl:otherwise>
						</xsl:choose>
				<a href="#" onclick="actions('', '','','view_events.xts');">
					<img height="16" width="16" border="0" src="{'{$image_root}'}action_plan_activity.gif">
						<out:attribute name="alt"><xts:string id="IDS_VPA_ACTION_TIP"/></out:attribute>
					</img>
				</a>				
			</td>
		</out:if>
	</xsl:template>

	<!-- Refresh data source connections	-->
	<xsl:template match="mt:tool[@name='refresh_connections'] ">
		<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_{@name}'))">
			<script language="javascript">
				function refreshConnections()
				{
					document.cfrmEntryAdmin.ifrmcmd.value = 'refreshConnections';
					document.cfrmEntryAdmin.m.value = "<out:value-of select="$app"/>/submit.xts";
					document.cfrmEntryAdmin.m_class.value = "<out:value-of select="{request-path}/cm:objectClass"/>";										
					document.cfrmEntryAdmin.m_obj.value = "<out:value-of select="xtsext:javascriptencode(string({request-path}/cm:searchPath))"/>";					
					document.cfrmEntryAdmin.backURL.value = "<out:value-of select="xtsext:javascriptencode(string($back-url))"/>";
					document.cfrmEntryAdmin.submit();
				}
			</script>
			<td onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
						<xsl:choose>
							<xsl:when test="@cogadmin='true'"><xsl:attribute name="class">toolbarImageNormal2</xsl:attribute></xsl:when>
							<xsl:otherwise><xsl:attribute name="class">toolbarImageNormal</xsl:attribute></xsl:otherwise>
						</xsl:choose>
				<a href="#" onclick="refreshConnections()">
					<img height="16" width="16" border="0" src="{'{$image_root}'}action_refresh_server_connection.gif">
						<out:attribute name="alt">
							<xts:string id="IDS_ACTION_REFRESH_CONNECTIONS">
								<xts:param name="objectName"><out:value-of select="{request-path}/cm:defaultName"/></xts:param>
							</xts:string>
						</out:attribute>
					</img>
				</a>			
			</td>
		</out:if>
	</xsl:template>
	
	<!-- Adds the page to the portal tabs.	-->
	<xsl:template match=" mt:tool[@name='add_page']">
		<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_{@name}'))">
			<script language="javascript">
				function addPageToPortal()
				{
					pageCmd("addToMyPages");
				}
			</script>
			<td onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
				<xsl:choose>
					<xsl:when test="not(string(@disable) = 'true')">
						<xsl:choose>
							<xsl:when test="@cogadmin='true'"><xsl:attribute name="class">toolbarImageNormal2</xsl:attribute></xsl:when>
							<xsl:otherwise><xsl:attribute name="class">toolbarImageNormal</xsl:attribute></xsl:otherwise>
						</xsl:choose>
						
						<a href="javascript:addPageToPortal()">
							<img height="16" width="16" border="0" src="{'{$image_root}'}action_add_page_toportal.gif">
								<out:attribute name="alt"><xts:string id="IDS_ACT_ADD_PAGE_TO_PORTAL_VIEW"/></out:attribute>
							</img>
						</a>
					</xsl:when>
					<xsl:otherwise>
						<out:attribute name="class">toolbarImageUnavailable</out:attribute>					
						<img height="16" width="16" border="0" src="{'{$image_root}'}action_add_page_toportal_dis.gif">
							<out:attribute name="alt"><xts:string id="IDS_ACT_ADD_PAGE_TO_PORTAL_VIEW"/></out:attribute>
						</img>					
					</xsl:otherwise>
				</xsl:choose>	
			</td>
		</out:if>
	</xsl:template>	

	
	<!-- Import portlets -->
	<xsl:template match=" mt:tool[@name='import_portlets'] ">
		<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_{@name}'))">
			<xsl:choose>
				<xsl:when test="@disable ='true'">
					<td class="toolbarImageUnavailable" onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
						<img height="16" width="16" border="0" src="{'{$image_root}'}action_import_portlet_dis.gif">
							<out:attribute name="alt"><xts:string id="IDS_IMPORT_PORTLETS"/></out:attribute>
						</img>
					</td>
				</xsl:when>
				<xsl:otherwise>
					<td onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
						<xsl:choose>
							<xsl:when test="@cogadmin='true'"><xsl:attribute name="class">toolbarImageNormal2</xsl:attribute></xsl:when>
							<xsl:otherwise><xsl:attribute name="class">toolbarImageNormal</xsl:attribute></xsl:otherwise>
						</xsl:choose>
						<a>
							<out:attribute name="href">
								<out:value-of select="$gateway"/>?b_action=xts.run&amp;m=<out:value-of select="$app"/>/cc.xts&amp;m_portlet=/admin/portlet:import&amp;rui=hh&amp;m_pagemode=view&amp;backURL=<out:value-of select="xtsext:protect(xtsext:urlencode(string($back-url)),'url','url','getdata')"/>
							</out:attribute>
							<img height="16" width="16" border="0" src="{'{$image_root}'}action_import_portlet.gif">
								<out:attribute name="alt"><xts:string id="IDS_IMPORT_PORTLETS"/></out:attribute>
							</img>
						</a>
					</td>
				</xsl:otherwise>
			</xsl:choose>
		</out:if>
	</xsl:template>

	<!-- New portlets -->
	<xsl:template match=" mt:tool[@name='new_portlets'] ">
		<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_{@name}'))">
			<out:choose>
				<out:when test="'{string(@disable)}' ='true'">
						<td class="toolbarImageUnavailable" onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
							<img height="16" width="16" border="0" src="{'{$image_root}'}action_add_portlet_frm_producer_dis.gif">
								<out:attribute name="alt"><xts:string id="IDS_ACT_NEW_PORTLET_ALT"/></out:attribute>
							</img>
						</td>
				</out:when>
				<out:otherwise>
					<out:variable name="url-encoded-path" select="xtsext:protect(xtsext:urlencode(string(/root/content/cm:queryResponse/cm:queryReply[1]/*/cm:searchPath)),'url','searchPath','getdata')"/>
		
					<td onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
						<xsl:choose>
							<xsl:when test="@cogadmin='true'"><xsl:attribute name="class">toolbarImageNormal2</xsl:attribute></xsl:when>
							<xsl:otherwise><xsl:attribute name="class">toolbarImageNormal</xsl:attribute></xsl:otherwise>
						</xsl:choose>
						<a>
							<out:attribute name="href">
							<out:value-of select="$gateway"/>?b_action=xts.run&amp;m=<out:value-of select="$app"/>/cc.xts&amp;m_portlet=/admin/portlet:newportlet&amp;rui=hh&amp;m_pagemode=view&amp;wsrp-urlType=blockingAction&amp;cps-portlet=PORTLETID&amp;producer=/connection/path:<out:value-of select="$url-encoded-path"/>&amp;backURL=<out:value-of select="xtsext:protect(xtsext:urlencode($back-url),'url','url','getdata')"/>					
							</out:attribute>
							<img height="16" width="16" border="0" src="{'{$image_root}'}action_add_portlet_frm_producer.gif">
								<out:attribute name="alt"><xts:string id="IDS_ACT_NEW_PORTLET_ALT"/></out:attribute>
							</img>
						</a>				
					</td>
				</out:otherwise>
			</out:choose>
		</out:if>
	</xsl:template>
	
	<!-- New migration -->
	<xsl:template match=" mt:tool[@name='new_migration'] ">
		<out:if test="not(contains($ui_black_list, 'CC_TOOLBAR_BUTTONS_{@name}'))">
			<out:choose>
				<out:when test="'{string(@disable)}' ='true'">
						<td class="toolbarImageUnavailable" onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
							<img height="16" width="16" border="0" src="{'{$image_root}'}action_new_migration_dis.gif">
								<out:attribute name="alt"><xts:string id="IDS_ACT_NEW_MIGRATION_ALT"/></out:attribute>
							</img>
						</td>
				</out:when>
				<out:otherwise>
					<td onmouseover="mouseoverImage(this)" onmouseout="mouseoutImage(this)">
						<xsl:choose>
							<xsl:when test="@cogadmin='true'"><xsl:attribute name="class">toolbarImageNormal2</xsl:attribute></xsl:when>
							<xsl:otherwise><xsl:attribute name="class">toolbarImageNormal</xsl:attribute></xsl:otherwise>
						</xsl:choose>
						<a>
							<out:attribute name="href">
								<out:value-of select="$gateway"/>?b_action=xts.run&amp;m=<out:value-of select="$app"/>/new_general.xts&amp;m_new_class=migrationTask&amp;backURL=<out:value-of select="xtsext:protect(xtsext:urlencode($back-url),'url','url','getdata')"/>&amp;m_path=<out:value-of select="xtsext:protect(xtsext:urlencode(string($m_path)),'url','searchPath','getdata')"/>					
							</out:attribute>
							<img height="16" width="16" border="0" src="{'{$image_root}'}action_new_migration.gif">
								<out:attribute name="alt"><xts:string id="IDS_ACT_NEW_MIGRATION_ALT"/></out:attribute>
							</img>
						</a>				
					</td>
				</out:otherwise>
			</out:choose>
		</out:if>
	</xsl:template>
	<!-- 
	Template - mt:detailedEntryView:
		This template renders the detailed view of an  individual entry.
		Operation:
			Outputs the detailed view of an entry.
	-->
	<xsl:template match="mt:detailedEntryView">
		<!-- If this is the beginning of a row then open a <table> tag -->
		<out:if test="position() mod $columns = 1">
			<out:text disable-output-escaping="yes">&lt;table width="100%" border="0" cellpadding="0" cellspacing="0" class="horizSpaceDetailView"&gt;&lt;tr&gt;</out:text>	
		</out:if>		
		<td valign="top" align="left" width="{'{$width}'}%">
			<!-- Drop common rendering variables here to get the proper scope for generating name, icon, actions .. for the current entry -->
			<xsl:copy-of select="mt:object-variables/*"/>
			<table width="100%" cellpadding="0" cellspacing="0">				
				<tr>	
					<td valign="top" rowspan="4" align="left" width="20">
						<out:choose>
							<out:when test="cm:nbid or cm:nid">
								<img src="{'{$webcontent}/images/space.gif'}" alt="" width="20"/>
							</out:when>
							<out:otherwise>
								<input type="checkbox" value="{'{xtsext:urlencode(string(cm:searchPath))}'}" name="checkbox_{'{position()}'}">
									<out:if test="key('env-param',concat('checkbox_' , position()))">
										<out:attribute name="checked">checked</out:attribute>
									</out:if>
								</input>
							</out:otherwise>
						</out:choose>
					</td>
					<td valign="top" align="left" rowspan="4" width="20" style="padding-top:2px;padding-right:1px;">						
						<table cellpadding="0" cellspacing="0">
							<tr><td nowrap="nowrap">
								<out:call-template name="gen-icon">
									<out:with-param name="class" select="$class"/>
									<out:with-param name="canWrite" select="$canWrite"/>
									<out:with-param name="canExecute" select="$canExecute"/>
									<out:with-param name="canTraverse" select="$canTraverse"/>
									<out:with-param name="userInterfaces" select="$userInterfaces"/>
									<out:with-param name="isDangling" select="$isDangling"/>
									<out:with-param name="output_format" select="$output_format"/>
									<out:with-param name="action" select="$action"/>
									<out:with-param name="executionFormat" select="$executionFormat"/>
									<out:with-param name="hiddenObject" select="$hiddenObject"/>
									<out:with-param name="effectiveUserCapabilities" select="$effectiveUserCapabilities"/>
								</out:call-template>							
							</td></tr>
						</table>						
					</td>
					<td class="objectName">
						<xsl:copy-of select="mt:object-name/*"/>
					</td>
				</tr>
				<tr>
					<td class="objectOptions">
						<out:value-of select="cm:defaultDescription"/>
					</td>
				</tr>
				<tr>
					<td class="objectOptions">
						<out:choose>
							<out:when test="cm:updateDate"><out:value-of select="cm:updateDate"/></out:when>
							<out:otherwise>
								<!-- this will give us the time formatted with the java long(2) date and medium(3) time using the locale date and time patterns provided by java -->
								<out:value-of select="xtsext:formatDateFromUTC( string( cm:modificationTime ), number( '2' ), number( '3' ),  string( $timeZone ),  string( $contentLocale ) )"/>
							</out:otherwise>
						</out:choose>
					</td>
				</tr>
				<tr>
					<td>
						<!-- 
						The call to action-properties does not pass the userCanUseFullRS/QS since the user is allowed to edit
						existing reports, just not allowed to create new reports (e.g. doing a Save as...)
						-->
						<out:call-template name="action-properties">
							<out:with-param name="supportRunOptionsAction" select="true()"/>
							<out:with-param name="supportScheduleAction" select="true()"/>
							<out:with-param name="canRead" select="$canRead"/>
							<out:with-param name="canWrite" select="$canWrite"/>
							<out:with-param name="canExecute" select="$canExecute"/>
							<out:with-param name="canTraverse" select="$canTraverse"/>
							<out:with-param name="class" select="$class"/>
							<out:with-param name="output_format" select="$output_format"/>
							<out:with-param name="isDangling" select="$isDangling"/>
							<out:with-param name="effectiveUserCapabilities" select="$effectiveUserCapabilities"/>
						</out:call-template>						
					</td>
				</tr>
			</table>
		</td>	
		<td valign="top" width="2%">&#160;</td>	
		
		<!--	After the last entry, add empty (dummy) cells for each remaining column to fill out the row and leave no gaps. -->
		<out:if test="position() = last()">
			<!-- Count odd (empty) cells -->
			<out:variable name="oddCells">		
				<out:choose>
					<out:when test="(position() mod $columns) = 0"><out:value-of select="number('0')"/></out:when>
					<out:otherwise><out:value-of select="$columns - (position() mod $columns)"/></out:otherwise>
				</out:choose>
			</out:variable>	
			<out:if test=" $oddCells > 0">
				<xsl:variable name="dummyCells">		
					<td width="{'{$width}'}%">&#160;</td>
					<td width="2%">&#160;</td>	
				</xsl:variable>
				<out:choose>
					<out:when test="$oddCells = 1">
						<xsl:copy-of select="$dummyCells"/>			
					</out:when>	
					<out:when test="$oddCells = 2">
						<xsl:copy-of select="$dummyCells"/>
						<xsl:copy-of select="$dummyCells"/>		
					</out:when>
					<out:when test="$oddCells = 3">
						<xsl:copy-of select="$dummyCells"/>
						<xsl:copy-of select="$dummyCells"/>
						<xsl:copy-of select="$dummyCells"/>
					</out:when>
					<out:when test="$oddCells = 4">
						<xsl:copy-of select="$dummyCells"/>
						<xsl:copy-of select="$dummyCells"/>
						<xsl:copy-of select="$dummyCells"/>
						<xsl:copy-of select="$dummyCells"/>
					</out:when>
				</out:choose>			
			</out:if>
		</out:if>
		
		<!-- If we just had enough entries to fill a row or we have just finished rendering the last entry then close the current row / table -->
		<out:if test="(position() mod $columns) = 0 or position() = last()">
			<out:text disable-output-escaping="yes">&lt;/tr&gt;&lt;/table&gt;</out:text>
		</out:if>				
	</xsl:template>
	

	
<!-- 
	Template - mt:objectNoneFound:
		This template renders the No entries message on the main pages view.
		Operation:
			Outputs the No entries message.
	-->
	<xsl:template match="mt:objectNoneFound">
		<p class="objectNoneFound">
			<xsl:choose>
				<xsl:when test="@id">
					<xts:string id="{@id}"/>
				</xsl:when>
				<xsl:otherwise>
					<xts:string id="IDS_NO_ITEMS_FOUND"/>
				</xsl:otherwise>
			</xsl:choose>
		</p>
	</xsl:template>		
	
	<!-- 
	Template - mt:containerNoAccess:
		This template renders the message letting the user know he doesn't have access to the page or it was deleted
	-->
	<xsl:template match="mt:containerNoAccess">
		<out:variable name="homeLink">
			<xts:string id="IDS_HOME"/>
		</out:variable>
		<p class="objectNoneFound">
			<xts:string id="IDS_NO_ACCESS_CONTAINER">
				<xts:param name="homeLink">
					<a href="{'{$gateway}?{key(&quot;system-param&quot;, &quot;COGNOSHome&quot;)}'}">
						<out:value-of select="$homeLink"/>
					</a>
				</xts:param>
			</xts:string>					
		</p>
	</xsl:template>	
	
	<xsl:template match="mt:errorMessage">
		<p class="objectNoneFound">
			<xsl:apply-templates/>
		</p>
	</xsl:template>	
	
	<!-- 
	Template - mt:actions:
		This template generates the template action-properties which renders hyperlinked images for each action available for an entry.
		Operation:
			Generates the template to produce hyperlinked action images for an entry.  The action images are for:
				properties
				report outputs
				run options
				edit with Studios
				create a custom view
				deployment:
					properties
					update export
					update import
					view deployment
				tools:
					properties
					test connection
					run once
					view history
					view outputs
					view steps
					cancel operation
				schedule
				more
			
	-->
	<xsl:template match="mt:actions">
		
		<!-- 	action-properties - this will be called to show the actions and properties links for each item	-->		
		<out:template name="action-properties">
			<out:param name="obj-name" select="cm:defaultName"/>
			<out:param name="obj-path" select="cm:searchPath"/>
			<out:param name="obj-id" select="cm:storeID"/>
			<out:param name="obj-class" select="cm:objectClass"/>
			<out:param name="userInterfaces" select="''"/>
			<out:param name="history-path" select="''"/>
			
			<out:param name="canRead" select="true()"/>
			<out:param name="canWrite" select="true()"/>
			<out:param name="canExecute" select="true()"/>
			<out:param name="canTraverse" select="true()"/>
			<out:param name="class" select="cm:objectClass"/><!-- this is the effective class.  i.e. it is the class of the target object in case of a shortcut. -->
			<out:param name="output_format" select="''"/>
			<out:param name="isDangling" select="false()"/>
			
			<out:param name="reportVersion-path" select="''"/>
			<out:param name="runHistoryRequestedTime" select="''"/>
			<out:param name="agsEventList-path" select="''"/>
			<out:param name="position" select="''"/>
			<out:param name="eventID" select="''"/>
			<out:param name="effectiveUserCapabilities" select="''"/>
			
			<!-- supported actions - host morphlet can list which actions it wants to show when listing CM entries. -->
			<out:param name="supportDeploymentRecordAction" select="false()"/>
			<out:param name="supportScheduleAction" select="false()"/>
			<out:param name="supportRunOnce" select="false()"/>
			<out:param name="supportRunOptionsAction" select="false()"/>
			<out:param name="supportHistoryAction" select="false()"/>
			<out:param name="supportJobPropertiesAction" select="false()"/>
			<out:param name="supportViewOutputsAction" select="false()"/>
			<out:param name="supportViewHotListAction" select="false()"/>
			<out:param name="supportPropertiesAction" select="false()"/>
			<out:param name="supportAllActionsAction" select="false()"/>
			<out:param name="supportTestConnection" select="false()"/>
			<out:param name="supportViewRunHistory" select="false()"/>
			<out:param name="supportViewRunHistoryDetails" select="false()"/>
			<out:param name="supportPortletControlAction" select="false()"/>
			<out:param name="supportDeleteAction" select="false()"/>
			<out:param name="supportActivateAction" select="false()"/>
			<out:param name="supportPreviewPortlet" select="false"/>
			<out:param name="supportCreateProfileAction" select="false"/>
			
			<!-- Effective object name -->
			<out:variable name="name">
				<out:choose>
					<out:when test="$obj-class = 'shortcut'"><out:value-of select="cm:target/*/cm:defaultName"/></out:when>
					<out:otherwise><out:value-of select="$obj-name"/></out:otherwise>
				</out:choose>
			</out:variable>
			
			<out:variable name="objID">
				<out:choose>
					<out:when test="$obj-class = 'shortcut'"><out:value-of select="cm:target/*/cm:storeID"/></out:when>
					<out:otherwise><out:value-of select="$obj-id"/></out:otherwise>
				</out:choose>
			</out:variable>			
			<out:variable name="toolTipName"><out:value-of select="$obj-name"/></out:variable>

			<out:variable name="js-encoded-name" select="xtsext:javascriptencode(string($name))"/>
			
			<!-- Versions target -->
			<out:variable name="versions_target"> 
				<out:choose>
					<out:when test="key('system-param', 'versions')/target"><out:value-of select="key('system-param', 'versions')/target"/></out:when>
					<out:otherwise>outputs.xts</out:otherwise>
				</out:choose>
			</out:variable>	

			<!-- Effective object path -->
			<out:variable name="js-encoded-path"> 
				<out:choose>
					<out:when test="$obj-class = 'shortcut'"><out:value-of select="xtsext:javascriptencode(string(cm:target/*/cm:searchPath))"/></out:when>
					<out:otherwise><out:value-of select="xtsext:javascriptencode(string($obj-path))"/></out:otherwise>
				</out:choose>
			</out:variable>

			<out:variable name="ppgateway">
				<out:choose>
					<out:when test="$obj-class = 'shortcut' and starts-with( string(cm:target/*/cm:objectClass),'powerPlay' )"><out:value-of select="cm:target/*/cm:gateway"/></out:when>
					<out:when test="starts-with( string($obj-class),'powerPlay' )"><out:value-of select="cm:gateway"/></out:when>
				</out:choose>
			</out:variable>
			
			<!-- Effective event list path for agentDefinition/agentDefinitionView -->
			<out:variable name="event_list"> 
				<out:choose>
					<out:when test="$obj-class = 'shortcut' and starts-with( string(cm:target/*/cm:objectClass),'agentDefinition' )">
						<out:value-of select="cm:target/*/cm:mostRecentEventList"/>
					</out:when>
					<out:when test="starts-with( $obj-class,'agentDefinition' )">
						<out:value-of select="cm:mostRecentEventList"/>
					</out:when>
				</out:choose>
			</out:variable>
			
			<out:variable name="rv-lang">
				<out:if test="key('system-param', 'useReportLocaleInRVUI') = 'true'">
					<xsl:text/>&amp;lang=<out:value-of select="$contentLocale"/>
				</out:if>
			</out:variable>

			<!-- Ref to UI object actions -->	
			<out:variable name="ui-object" select="key( 'ui-object-actions', string($class) )"/>
			<table border="0" cellpadding="2" cellspacing="0">
				<tr>
					<xsl:if test="@mode and (@mode = 'main' or @mode='mysub')">
						<!-- Properties ============= -->
						<!-- We do not apply any security on this since it could be used for shortcuts.  The canRead, canWrite flags refer to the target in case of shortcut objects. -->
						<out:variable name="upfShortCut"><out:if test="cm:upfShortCut = 'true'">s</out:if></out:variable>
						<out:choose>
							<!-- Series 7 object -->
							<out:when test="cm:nid or cm:nbid">
								<out:variable name="daurl">
									<out:value-of select="$s7gateway"/>
									<out:choose>
										<!-- NewsItem of type URL (other) -->
										<out:when test="cm:nid and cm:objectClass = 'URL'">
											<out:choose>
												<out:when test="$upfShortCut != ''">
													<out:text/>?xmlcmd=&lt;GetPage>&lt;Template>ni<out:value-of select="$upfShortCut"/>_properties_general.utml&lt;/Template>&lt;/GetPage>&amp;id=<out:value-of select="cm:nid"/>
												</out:when>
												<out:otherwise>
													<out:text/>?xmlcmd=&lt;GetPage>&lt;Template>other<out:value-of select="$upfShortCut"/>_properties_general.utml&lt;/Template>&lt;/GetPage>&amp;id=<out:value-of select="cm:nid"/>
												</out:otherwise>
											</out:choose>
										</out:when>
										
										<!-- NewsItem of known type (IWR, PP, VIZ .. etc)-->
										<out:when test="cm:nid and cm:objectClass != 'URL'">		
											<out:text/>?xmlcmd=&lt;GetPage>&lt;Template>ni<out:value-of select="$upfShortCut"/>_properties_general.utml&lt;/Template>&lt;/GetPage>&amp;id=<out:value-of select="cm:nid"/>
										</out:when>
										
										<!-- NewsBox -->
										<out:otherwise>										
											<out:text/>?xmlcmd=&lt;GetPage>&lt;Template>nb<out:value-of select="$upfShortCut"/>_properties_general.utml&lt;/Template>&lt;/GetPage>&amp;isnewsbox=Y&amp;id=<out:value-of select="cm:nbsid"/>
										</out:otherwise>
									</out:choose>
									<out:text/>&amp;LO=<out:value-of select="$contentLocale"/>
									<out:text/>&amp;LA=<out:value-of select="$productLocale"/>
									<out:text/>&amp;back=<out:value-of select="$encoded-s7-back-url"/>
								</out:variable>

								<xsl:call-template name="renderAction">
									<xsl:with-param name="href">{xtsext:protect(string($daurl),'none','s7url','s7url')}</xsl:with-param>
									<xsl:with-param name="onclick" select="'none'"/>
									<xsl:with-param name="icon" select="'action_properties.gif'"/>
									<xsl:with-param name="tooltip" select="'IDS_PROPERTIES'"/>
								</xsl:call-template>							
							</out:when>
							
							<!-- CRN Object -->
							<out:otherwise>
								<xsl:call-template name="renderAction">
									<xsl:with-param name="onclick">actions('{xtsext:javascriptencode(string($obj-name))}', '{$obj-class}', '{xtsext:javascriptencode(string($obj-path))}','properties_general.xts')</xsl:with-param>
									<xsl:with-param name="icon" select="'action_properties.gif'"/>
									<xsl:with-param name="tooltip" select="'IDS_PROPERTIES'"/>
								</xsl:call-template>
				
								<out:if test="($obj-class='pagelet' or ( $obj-class='shortcut' and cm:target/*/cm:objectClass = 'pagelet')) and $canExecute and key('session-param', 'write') = 'true'">	
									<xsl:call-template name="renderAction">
										<xsl:with-param name="onclick">pageCmd('addToMyPages', '{$objID)}')</xsl:with-param>
										<xsl:with-param name="icon" select="'action_add_page_to_portal.gif'"/>
										<xsl:with-param name="tooltip" select="'IDS_ACT_ADD_PAGE_TO_PORTAL_VIEW'"/>
										<xsl:with-param name="onclick" select="'none'"/>
									</xsl:call-template>
								</out:if>

								<out:if test="($obj-class = 'package' and $userInterfaces='metricStudio')">
									<out:if test="not($isDangling) and $ui-object/userInterface[@name='metricStudio']/action[@name = 'traverse'] and $canTraverse">
										<out:variable name="m"><out:value-of select="key('env-param','m')"/></out:variable>
										<xsl:call-template name="renderAction">
											<xsl:with-param name="href">{$gateway}?b_action=xts.run&amp;m={$m}&amp;m_folder={$objID}</xsl:with-param>
											<xsl:with-param name="icon" select="'action_view_metrics_package.gif'"/>
											<xsl:with-param name="tooltip" select="'IDS_ACT_VIEW_METRICSPACKAGE_CONTENT'"/>
											<xsl:with-param name="onclick" select="'none'"/>
										</xsl:call-template>
									</out:if>

									<out:if test="contains($effectiveUserCapabilities, ' userCanUseMetricsManager ') and not($isDangling) and $canRead and $canExecute and $canTraverse and $ui-object/userInterface[@name='metricStudio']/action[@name = 'launchcmm']">
										<out:variable name="target-path">
											<out:choose>
												<out:when test="string($obj-class) = 'shortcut'"><out:value-of select="cm:target/*/cm:searchPath"/></out:when>
												<out:otherwise><out:value-of select="$obj-path"/></out:otherwise>
											</out:choose>
										</out:variable>
										<xsl:call-template name="renderAction">
											<xsl:with-param name="onclick">cognosLaunch('ui.gateway', sGateway, 'ui.tool', 'MetricStudio', 'ui.backURL', sBackURL, 'ui.object', '{xtsext:javascriptencode(string($target-path))}', 'ui.folder', '{xtsext:javascriptencode(string($location))}', 'ui.action', 'edit');</xsl:with-param>
											<xsl:with-param name="icon" select="'action_edit_with_cmm.gif'"/>
											<xsl:with-param name="tooltip" select="'IDS_ACT_OPEN_METRICS_MANAGER'"/>
										</xsl:call-template>
									</out:if>
								</out:if>
								
								<out:if test="($obj-class = 'package' and $userInterfaces='planningContributor')">
									<out:if test="not($isDangling) and $ui-object/userInterface[@name='planningContributor']/action[@name = 'traverse'] and $canRead and $canTraverse">
										<out:variable name="m"><out:value-of select="key('env-param','m')"/></out:variable>
										<xsl:call-template name="renderAction">
											<xsl:with-param name="href">{$gateway}?b_action=xts.run&amp;m={$m}&amp;m_folder={$objID}</xsl:with-param>
											<xsl:with-param name="icon" select="'action_view_planning_package.gif'"/>
											<xsl:with-param name="tooltip" select="'IDS_ACT_VIEW_PLANNINGPACKAGE_CONTENT'"/>
											<xsl:with-param name="onclick" select="'none'"/>
										</xsl:call-template>
									</out:if>

									<out:if test="contains($effectiveUserCapabilities, ' userCanUsePlanningContributor ') and not($isDangling) and $ui-object/userInterface[@name='planningContributor']/action[@name = 'launchContributor'] and $canExecute">
										<out:variable name="target-path">
											<out:choose>
												<out:when test="string($obj-class) = 'shortcut'"><out:value-of select="cm:target/*/cm:searchPath"/></out:when>
												<out:otherwise><out:value-of select="$obj-path"/></out:otherwise>
											</out:choose>
										</out:variable>
										<xsl:call-template name="renderAction">
											<xsl:with-param name="onclick">cognosLaunch('ui.gateway', sGateway, 'ui.tool', 'Contributor', 'ui.backURL', sBackURL, 'ui.object', '{xtsext:javascriptencode(string($target-path))}', 'ui.folder', '{xtsext:javascriptencode(string($location))}', 'ui.action', 'new');</xsl:with-param>
											<xsl:with-param name="icon" select="'action_edit_with_contributor.gif'"/>
											<xsl:with-param name="tooltip" select="'IDS_ACT_OPEN_CONTRIBUTOR'"/>
										</xsl:call-template>
									</out:if>
								</out:if>
							</out:otherwise>
						</out:choose>
						<!-- Previous versions ============= -->
						<out:if test="(string(cm:target/*/cm:defaultOutputFormat) !='' or string(cm:defaultOutputFormat) != '' or $class='document') and ($canRead and $canTraverse) and $ui-object/action[@name = 'previous_versions']">						
						   <out:choose>
							   <out:when test="$class='document'">
								   <xsl:call-template name="renderAction">
										<xsl:with-param name="icon" select="'action_view_report_output.gif'"/>
										<xsl:with-param name="tooltip" select="'IDS_IMG_VIEW_DOCUMENT_ALT'"/>
										<xsl:with-param name="morphlet">{$versions_target}</xsl:with-param>
									</xsl:call-template>
							   </out:when>
							   <out:otherwise>
									<xsl:call-template name="renderAction">
										<xsl:with-param name="icon" select="'action_view_report_output.gif'"/>
										<xsl:with-param name="tooltip" select="'IDS_IMG_VIEW_RPT_ALT'"/>
										<xsl:with-param name="morphlet">{$versions_target}</xsl:with-param>
									</xsl:call-template>
								 </out:otherwise>
						   </out:choose>
						</out:if>
						
						<!-- View agentHotList when exists for agents-->
						 <out:if test="(starts-with( $obj-class,'agentDefinition' ) or $obj-class='shortcut' and starts-with( string(cm:target/*/cm:objectClass),'agentDefinition' )) and $canRead and $canTraverse and $event_list !='' ">
							<xsl:call-template name="renderAction">
								<xsl:with-param name="icon" select="'action_view_AS_hotlist.gif'"/>
								<xsl:with-param name="tooltip" select="'IDS_VIEW_AGS_HOTLIST_TIP'"/>
								<xsl:with-param name="href">
									<xsl:text/>{$gateway}?b_action=cognosViewer&amp;ui.action=view<xsl:text/>
									<xsl:text/>&amp;ui.object={xtsext:protect(xtsext:urlencode(string($event_list)), 'url','searchPath','getdata')}<xsl:text/>
									<xsl:text/>&amp;cv.toolbar=false<xsl:text/>
									<xsl:text/>&amp;ui.name={xtsext:protect(xtsext:urlencode(string($name)),'url','userData','getdata')}<xsl:text/>
									<xsl:text/>{$rv-lang}&amp;ui.cafcontextid={$cafContextIDAGS}&amp;ui.backURL={xtsext:protect(xtsext:urlencode(string($back-url)),'url','url','getdata')}<xsl:text/>
								</xsl:with-param> 
							</xsl:call-template>
						 </out:if>
						 
						<!-- run powerPlay 7 -->
						 <out:if test="not($isDangling) and $class='powerPlayReport' and $canExecute and $canRead and $ui-object/action[@name = 'run_options']">
							<out:variable name="reportPath">
								<out:choose>
									<out:when test="$obj-class = 'shortcut'"><out:value-of select="cm:target/*/cm:searchPath"/></out:when>
									<out:otherwise><out:value-of select="$obj-path"/></out:otherwise>
								</out:choose>									
							</out:variable>
							<out:if test="$class='powerPlayReport'">
								<out:variable name="ppreportprompt">
									<out:choose>
										<out:when test="$obj-class = 'shortcut'">
											<out:if test="string(cm:target/*/cm:hasPrompts)='true'">
												<out:text/><out:value-of select="cm:target/*/cm:options/cm:powerPlayOptionBoolean[cm:name='prompt']/cm:value"/><out:text/>
											</out:if>
										</out:when>
										<out:when test="string(cm:hasPrompts)='true'"><out:value-of select="cm:options/cm:powerPlayOptionBoolean[cm:name='prompt']/cm:value"/></out:when>
									 </out:choose>
								</out:variable>
								<out:variable name="ppcubecontentname">
									<out:choose>
										<out:when test="$obj-class = 'shortcut' and starts-with( string(cm:target/*/cm:objectClass),'powerPlay' )"><out:value-of select="cm:target/*/cm:cubeContentName"/></out:when>
										<out:when test="starts-with( string($obj-class),'powerPlay' )"><out:value-of select="cm:cubeContentName"/></out:when>
									</out:choose>
								</out:variable>
								<out:choose>
								<out:when test="string($ppreportprompt)!=''">
									<out:variable name="ppURL">
										<out:value-of select="$ppgateway"/><out:text/>?crnobj=<out:text/>
										<out:value-of select="xtsext:urlencode(string($reportPath))"/><out:text/>&amp;crnccn=<out:value-of select="$ppcubecontentname"/>
										<out:text/>&amp;crnfrm=PDF&amp;crnp=<out:value-of select="$ppreportprompt"/>
										<out:text/>&amp;LA=<out:value-of select="$productLocale"/>
										<out:text/>&amp;LO=<out:value-of select="$contentLocale"/>
										<out:text/>&amp;BACK=<out:value-of select="$encodedPPBack"/><out:text/>
									</out:variable>
									<xsl:call-template name="renderAction">
										<xsl:with-param name="href">{xtsext:protect(string($ppURL),'none','s7url','s7url')}</xsl:with-param>
										<xsl:with-param name="icon" select="'action_run_16.gif'"/>
										<xsl:with-param name="tooltip" select="'IDS_ACT_RUN_PDF'"/>
										<xsl:with-param name="onclick" select="'none'"/>
									</xsl:call-template>
								</out:when>
								<out:otherwise>
									<out:variable name="ppURL">
										<out:value-of select="$ppgateway"/><out:text/>?crnobj=<out:text/>
										<out:value-of select="xtsext:urlencode(string($reportPath))"/><out:text/>&amp;crnccn=<out:value-of select="$ppcubecontentname"/>
										<out:text/>&amp;crnfrm=PDF&amp;LA=<out:value-of select="$productLocale"/>
										<out:text/>&amp;LO=<out:value-of select="$contentLocale"/>
										<out:text/>&amp;BACK=<out:value-of select="$encodedPPBack"/><out:text/>
									</out:variable>
									<xsl:call-template name="renderAction">
										<xsl:with-param name="href">{xtsext:protect(string($ppURL),'none','s7url','s7url')}</xsl:with-param>
										<xsl:with-param name="icon" select="'action_run_16.gif'"/>
										<xsl:with-param name="tooltip" select="'IDS_ACT_RUN_PDF'"/>
										<xsl:with-param name="onclick" select="'none'"/>
									</xsl:call-template>
								</out:otherwise>
								</out:choose>
							</out:if>
						</out:if>
		
						<xsl:if test="@mode and @mode='main'">
							<!-- Run options ============= -->
							<out:if test="not(contains($class,'powerPlayReport')) and ($userCanUseRWO or not(contains(' report query reportView analysis powerPlay8Report powerPlay8ReportView ', concat(' ', $class, ' ')))) and $supportRunOptionsAction and not($isDangling) and $canExecute and $ui-object/action[@name = 'run_options'] and ((not(contains(' jobDefinition agentDefinition agentDefinitionView ', concat(' ', $class, ' ')))) or ($canRead and $canTraverse ))">
								<out:variable name="run_target">
									<out:choose>
										<out:when test="contains(' report query reportView analysis powerPlay8Report powerPlay8ReportView ', concat(' ', $class, ' '))">
											<out:value-of select="'runWithOptions/report.xts'"/>
										</out:when>
										<out:when test="$class = 'agentDefinitionView'">
											<out:value-of select="'runWithOptions/agentDefinition.xts'"/>
										</out:when>
										<out:otherwise>
											<out:value-of select="concat('runWithOptions/', $class, '.xts')"/>
										</out:otherwise>
									</out:choose>
								</out:variable>
								<xsl:call-template name="renderAction">
									<xsl:with-param name="icon" select="'action_run_16.gif'"/>
									<xsl:with-param name="tooltip" select="'IDS_ACT_RUN'"/>
									<xsl:with-param name="morphlet" select="'{$run_target}'"/>
								</xsl:call-template>
							</out:if>
  						</xsl:if>

						<!-- Edit - with Studios ============= -->
						<out:if test="not($isDangling) and $canRead and $ui-object/action[@name = 'edit']">		
							<out:variable name="reportPath">
								<out:choose>
									<out:when test="$obj-class = 'shortcut'"><out:value-of select="cm:target/*/cm:searchPath"/></out:when>
									<out:otherwise><out:value-of select="$obj-path"/></out:otherwise>
								</out:choose>									
							</out:variable>
							<out:choose>
								<out:when test="$class='powerPlay8Report' and contains($effectiveUserCapabilities, ' userCanUsePPS ') and $canExecute">
									<out:variable name="ppdesignmode">
										<out:choose>
											<out:when test="$obj-class = 'shortcut'"><out:value-of select="cm:target/*/cm:options/cm:powerPlay8OptionData[cm:name='data']/cm:value"/></out:when>
											<out:otherwise><out:value-of select="cm:options/cm:powerPlay8OptionData[cm:name='data']/cm:value"/></out:otherwise>
										</out:choose>
									</out:variable>
									<out:choose>									
										<out:when test="string($ppdesignmode)!='previewWithNoData'">
											<xsl:call-template name="renderAction">
												<xsl:with-param name="icon" select="'action_edit_with_pp8.gif'"/>
												<xsl:with-param name="tooltip" select="'IDS_ACT_EDIT_WPPWX8'"/>
												<xsl:with-param name="onclick">cognosLaunch('ui.gateway', sGateway, 'ui.tool', 'PowerplayStudio', 'ui.object', '{xtsext:javascriptencode(string($reportPath))}', 'ui.action', 'edit', 'ui.crnfrm', 'HTML', 'ui.crngnd', 'false', 'ui.backURL', '{$encodedPP8Back}');
												</xsl:with-param>		
											</xsl:call-template>
										</out:when>
										<out:otherwise>
											<xsl:call-template name="renderAction">
												<xsl:with-param name="icon" select="'action_edit_with_pp8.gif'"/>
												<xsl:with-param name="tooltip" select="'IDS_ACT_EDIT_WPPWX8'"/>
												<xsl:with-param name="onclick">cognosLaunch('ui.gateway', sGateway, 'ui.tool', 'PowerplayStudio', 'ui.object', '{xtsext:javascriptencode(string($reportPath))}', 'ui.action', 'edit', 'ui.crnfrm', 'HTML', 'ui.crngnd', 'true', 'ui.backURL', '{$encodedPP8Back}');
												</xsl:with-param>		
											</xsl:call-template>
										</out:otherwise>
									</out:choose>
								</out:when>
								<out:when test="($class='powerPlayReport' or $class='powerPlayCube') and $canExecute">
									<out:variable name="ppdesignmode">
										<out:choose>
											<out:when test="$obj-class = 'shortcut'"><out:value-of select="cm:target/*/cm:options/cm:powerPlayOptionData[cm:name='data']/cm:value"/></out:when>
											<out:otherwise><out:value-of select="cm:options/cm:powerPlayOptionData[cm:name='data']/cm:value"/></out:otherwise>
										</out:choose>
									</out:variable>									
									<out:variable name="ppcubecontentname">
										<out:choose>
											<out:when test="$obj-class = 'shortcut'"><out:value-of select="cm:target/*/cm:cubeContentName"/></out:when>
											<out:otherwise><out:value-of select="cm:cubeContentName"/></out:otherwise>
										</out:choose>
									</out:variable>
									<out:choose>
										<out:when test="string($class)='powerPlayCube'">
											<out:variable name="ppURL">
												<out:value-of select="$ppgateway"/><out:text/>?crnobj=<out:text/>
												<out:value-of select="xtsext:urlencode(string($reportPath))"/><out:text/>&amp;crnccn=<out:value-of select="$ppcubecontentname"/>
												<out:text/>&amp;LA=<out:value-of select="$productLocale"/>
												<out:text/>&amp;LO=<out:value-of select="$contentLocale"/>
												<out:text/>&amp;BACK=<out:value-of select="$encodedPPBack"/><out:text/>
											</out:variable>
											<xsl:call-template name="renderAction">
												<xsl:with-param name="href">{xtsext:protect(string($ppURL),'none','s7url','s7url')}</xsl:with-param>
												<xsl:with-param name="icon" select="'action_edit_with_PP.gif'"/>
												<xsl:with-param name="tooltip" select="'IDS_ACT_EDIT_WPPWX'"/>
												<xsl:with-param name="onclick" select="'none'"/>
											</xsl:call-template>
										</out:when>
										<out:when test="string($ppdesignmode)!='previewWithNoData'">
											<out:variable name="ppURL">
												<out:value-of select="$ppgateway"/><out:text/>?crnobj=<out:text/>
												<out:value-of select="xtsext:urlencode(string($reportPath))"/><out:text/>&amp;crnccn=<out:value-of select="$ppcubecontentname"/>
												<out:text/>&amp;crnfrm=HTML&amp;crngnd=false&amp;LA=<out:value-of select="$productLocale"/>
												<out:text/>&amp;LO=<out:value-of select="$contentLocale"/>
												<out:text/>&amp;BACK=<out:value-of select="$encodedPPBack"/><out:text/>
											</out:variable>
											<xsl:call-template name="renderAction">
												<xsl:with-param name="href">{xtsext:protect(string($ppURL),'none','s7url','s7url')}</xsl:with-param>
												<xsl:with-param name="icon" select="'action_edit_with_PP.gif'"/>
												<xsl:with-param name="tooltip" select="'IDS_ACT_EDIT_WPPWX'"/>
												<xsl:with-param name="onclick" select="'none'"/>
											</xsl:call-template>
										</out:when>
										<out:otherwise>
											<out:variable name="ppURL">
												<out:value-of select="$ppgateway"/><out:text/>?crnobj=<out:text/>
												<out:value-of select="xtsext:urlencode(string($reportPath))"/><out:text/>&amp;crnccn=<out:value-of select="$ppcubecontentname"/>
												<out:text/>&amp;crnfrm=HTML&amp;crngnd=true&amp;LA=<out:value-of select="$productLocale"/>
												<out:text/>&amp;LO=<out:value-of select="$contentLocale"/>
												<out:text/>&amp;BACK=<out:value-of select="$encodedPPBack"/><out:text/>
											</out:variable>
											<xsl:call-template name="renderAction">
												<xsl:with-param name="href">{xtsext:protect(string($ppURL),'none','s7url','s7url')}</xsl:with-param>
												<xsl:with-param name="icon" select="'action_edit_with_PP_design.gif'"/>
												<xsl:with-param name="tooltip" select="'IDS_ACT_EDIT_WPPWX'"/>
												<xsl:with-param name="onclick" select="'none'"/>
											</xsl:call-template>
										</out:otherwise>
									</out:choose>
								</out:when>
								<out:when test="contains($effectiveUserCapabilities, ' userCanUseANS ') and $class = 'analysis' and $canExecute">
									<xsl:call-template name="renderAction">
										<xsl:with-param name="onclick">cognosLaunchInWindow('_blank', 'menubar=no,toolbar=no,status=yes,location=no,resizable=yes,width=650,height=480', 'ui.gateway', sGateway, 'ui.tool', 'AnalysisStudio', 'ui.object', '{xtsext:javascriptencode(string($reportPath))}', 'ui.action', 'edit');</xsl:with-param>
										<xsl:with-param name="icon" select="'action_edit_with_PS.gif'"/>
										<xsl:with-param name="tooltip" select="'IDS_ACT_EDIT_WPS'"/>
									</xsl:call-template>
								</out:when>								
								<out:when test="$userCanUseAGS and $class = 'agentDefinition' and $canTraverse and $canRead">
									<xsl:call-template name="renderAction">
										<xsl:with-param name="onclick">cognosLaunchInWindow('_blank', 'menubar=no,toolbar=no,status=yes,location=no,resizable=yes,width=650,height=480', 'ui.gateway', sGateway, 'ui.tool', 'EventStudio', 'ui.backURL', sBackURL, 'ui.object', '{xtsext:javascriptencode( string( $reportPath ) )}', 'ui.action', 'edit');</xsl:with-param>
										<xsl:with-param name="icon" select="'action_edit_with_AS.gif'"/>
										<xsl:with-param name="tooltip" select="'IDS_ACT_EDIT_WAG'"/>
									</xsl:call-template>
								</out:when>																
								<out:when test="contains($effectiveUserCapabilities, ' userCanUseRS ') and $class = 'report'">
									<xsl:call-template name="renderAction">
										<xsl:with-param name="onclick">cognosLaunchInWindow('_blank', 'menubar=no,toolbar=no,status=no,location=no,resizable=yes,width=700,height=500', 'ui.gateway', sGateway, 'ui.tool', 'ReportStudio', 'ui.object', '{xtsext:javascriptencode(string($reportPath))}', 'ui.action', 'edit');</xsl:with-param>
										<xsl:with-param name="icon" select="'action_edit_with_RS.gif'"/>
										<xsl:with-param name="tooltip" select="'IDS_ACT_EDIT_WRS'"/>
									</xsl:call-template>
								</out:when>								
								<out:when test="contains($effectiveUserCapabilities, ' userCanUseRS ') and $class = 'powerPlay8Report' and $userCanOpenPPInReportStudio">
									<xsl:call-template name="renderAction">
										<xsl:with-param name="onclick">cognosLaunchInWindow('_blank', 'menubar=no,toolbar=no,status=no,location=no,resizable=yes,width=700,height=500', 'ui.gateway', sGateway, 'ui.tool', 'ReportStudio', 'ui.object', '{xtsext:javascriptencode(string($reportPath))}', 'ui.action', 'edit');</xsl:with-param>
										<xsl:with-param name="icon" select="'action_edit_with_RS.gif'"/>
										<xsl:with-param name="tooltip" select="'IDS_ACT_EDIT_WRS'"/>
									</xsl:call-template>
								</out:when>																
								<out:when test="contains($effectiveUserCapabilities, ' userCanUseRS ') and $class = 'reportTemplate'">		
									<xsl:call-template name="renderAction">
										<xsl:with-param name="onclick">cognosLaunchInWindow('_blank', 'menubar=no,toolbar=no,status=no,location=no,resizable=yes,width=700,height=500', 'ui.gateway', sGateway, 'ui.tool', 'ReportStudio', 'ui.object', '{xtsext:javascriptencode(string($reportPath))}', 'ui.action', 'edit');</xsl:with-param>
										<xsl:with-param name="icon" select="'action_edit_with_RS.gif'"/>
										<xsl:with-param name="tooltip" select="'IDS_ACT_EDIT_WRS'"/>
									</xsl:call-template>
								</out:when>
								<out:when test="contains($effectiveUserCapabilities, ' userCanUseQS ') and $class = 'query' and $canExecute">
									<xsl:call-template name="renderAction">
										<xsl:with-param name="onclick">cognosLaunch('ui.gateway', sGateway, 'ui.tool', 'QueryStudio', 'ui.backURL', sBackURL, 'ui.object', '{xtsext:javascriptencode(string($reportPath))}', 'ui.action', 'edit');</xsl:with-param>
										<xsl:with-param name="icon" select="'action_edit_with_QS.gif'"/>
										<xsl:with-param name="tooltip" select="'IDS_ACT_EDIT_WQS'"/>
									</xsl:call-template>
								</out:when>
							</out:choose>							
						</out:if>
						
						<!-- Custom View ============= -->
						<out:if test="not($isDangling) and $ui-object/action[@name = 'customview'] and not(cm:nid)">
							<out:choose>								
								<out:when test="$class = 'powerPlay8Report' and ($canRead or $canExecute) ">
									<xsl:call-template name="renderAction">
										<xsl:with-param name="icon" select="'action_new_custom_view.gif'"/>
										<xsl:with-param name="tooltip" select="'IDS_ACT_CUSTOM_PP8'"/>
										<xsl:with-param name="morphlet" select="'new_general.xts'"/>
										<xsl:with-param name="newclass" select="'powerPlay8ReportView'"/>
									</xsl:call-template>
								</out:when>
								<out:when test="$class != 'agentDefinition' and ($canRead or $canExecute) ">
									<xsl:call-template name="renderAction">
										<xsl:with-param name="icon" select="'action_new_custom_view.gif'"/>
										<xsl:with-param name="tooltip" select="'IDS_ACT_CUSTOM'"/>
										<xsl:with-param name="morphlet" select="'new_general.xts'"/>
										<xsl:with-param name="newclass" select="'reportView'"/>
									</xsl:call-template>
								</out:when>
								<out:when test="$class = 'agentDefinition' and $canRead and $canTraverse">
									<xsl:call-template name="renderAction">
										<xsl:with-param name="icon" select="'action_new_custom_view.gif'"/>
										<xsl:with-param name="tooltip" select="'IDS_ACT_CUSTOM_AGENT'"/>
										<xsl:with-param name="morphlet" select="'new_general.xts'"/>
										<xsl:with-param name="newclass" select="'agentDefinitionView'"/>
									</xsl:call-template>
								</out:when>
							</out:choose>
						</out:if>
					</xsl:if>
					
					<xsl:if test="not(@mode and @mode = 'main')">
						<xsl:variable name="usePropertiesGeneral">properties_general.xts</xsl:variable>
						<!-- Properties ============= -->
						<out:if test="$supportPropertiesAction">
							<xsl:call-template name="renderAction">
								<xsl:with-param name="onclick">actions('{xtsext:javascriptencode(string($obj-name))}', '{$obj-class}', '{xtsext:javascriptencode(string($obj-path))}','<xsl:value-of select="$usePropertiesGeneral"/>')</xsl:with-param>
								<xsl:with-param name="icon" select="'action_properties.gif'"/>
								<xsl:with-param name="tooltip" select="'IDS_PROPERTIES'"/>							
							</xsl:call-template>
						</out:if>
						<out:if test="$supportDeleteAction">
							<out:variable name="msg">
								<xts:string id="IDS_TOOLS_DIRECTORY_DELETE_NAMESPACE"><xts:param name="defaultName"><out:value-of select="$obj-name"/></xts:param></xts:string>
							</out:variable>
							
							<xsl:call-template name="renderAction">
								<xsl:with-param name="onclick">doDeleteOne('{xtsext:javascriptencode(string($obj-path))}','{xtsext:javascriptencode(string($msg))}')</xsl:with-param>
								<xsl:with-param name="icon" select="'action_delete.gif'"/>
								<xsl:with-param name="tooltip" select="'IDS_DELETE'"/>					
							</xsl:call-template>
						</out:if>
						<out:if test="$supportActivateAction and $class='contentManagerService'">
							<xsl:call-template name="renderAction">
								<xsl:with-param name="onclick">doActivate('{xtsext:javascriptencode(string($obj-path))}')</xsl:with-param>
								<xsl:with-param name="icon" select="'action_activate.gif'"/>
								<xsl:with-param name="tooltip" select="'IDS_ACTION_ACTIVATE'"/>					
							</xsl:call-template>
						</out:if>

					</xsl:if>
					
					<xsl:if test="@mode and @mode = 'tools'">
						<!-- Job action properties -->
						<out:if test="$supportJobPropertiesAction and $canExecute and $ui-object/action[@name = 'job']">
							<xsl:call-template name="renderAction">
								<xsl:with-param name="icon" select="'action_properties.gif'"/>
								<xsl:with-param name="tooltip" select="'IDS_PROPERTIES'"/>
								<xsl:with-param name="morphlet" select="'properties_job.xts'"/>					
							</xsl:call-template>
						</out:if>
						
						<out:if test="$supportCreateProfileAction and $class='account' and $canWrite">
							<xsl:call-template name="renderAction">
								<xsl:with-param name="icon" select="'action_create_user_profile.gif'"/>
								<xsl:with-param name="tooltip" select="'IDS_ACTION_CREATE_PROFILE'"/>
								<xsl:with-param name="onclick">
									var form = document.cfrmEntryAdmin;<xsl:text/>
											form.ifrmcmd.value='createUserProfile';<xsl:text/>
											form.m_class.value='account';<xsl:text/>
											form.m_obj.value='{$js-encoded-path}';<xsl:text/>
											form.backURL.value="{$back-url}";<xsl:text/>
											form.m.value = 'portal/submit.xts';<xsl:text/>
											form.submit();<xsl:text/>
								</xsl:with-param>
							</xsl:call-template>
						</out:if>
						
					</xsl:if>

					<xsl:if test="@mode and (@mode = 'tools' or @mode='main')">
						<xsl:if test="@mode != 'main'">
							<!-- Run options ============= -->
							<out:if test="not(contains($class,'powerPlayReport')) and ($userCanUseRWO or not(contains(' report query reportView analysis powerPlay8Report powerPlay8ReportView ', concat(' ', $class, ' ')))) and $supportRunOptionsAction and not($isDangling) and $canExecute and $ui-object/action[@name = 'run_options'] and ((not(contains(' jobDefinition agentDefinition agentDefinitionView ', concat(' ', $class, ' ')))) or ($canRead and $canTraverse ))">
								<out:variable name="run_target">
									<out:choose>
										<out:when test="contains(' report query reportView analysis powerPlay8Report powerPlay8ReportView ', concat(' ', $class, ' '))">
											<out:value-of select="'runWithOptions/report.xts'"/>
										</out:when>
										<out:when test="$class = 'agentDefinitionView'">
											<out:value-of select="'runWithOptions/agentDefinition.xts'"/>
										</out:when>
										<out:when test="$class = 'exportDeployment' or $class = 'importDeployment'">
											<out:value-of select="'runWithOptions/deployment.xts'"/>
										</out:when>
										<out:otherwise>
											<out:value-of select="concat('runWithOptions/', $class, '.xts')"/>
										</out:otherwise>
									</out:choose>
								</out:variable>
								<xsl:call-template name="renderAction">
									<xsl:with-param name="icon" select="'action_run_16.gif'"/>
									<xsl:with-param name="tooltip" select="'IDS_ACT_RUN'"/>
									<xsl:with-param name="morphlet" select="'{$run_target}'"/>
								</xsl:call-template>
							</out:if>
						</xsl:if>	
						<!-- Schedule -->
						<out:if test="$userCanUseSched and $supportScheduleAction = 'true' and not($isDangling) and $canRead and $canTraverse and $canExecute and $ui-object/action[@name = 'schedule'] and not(cm:nid)">
								<out:variable name="run_target">
									<out:choose>
										<out:when test="contains(' report query reportView analysis powerPlay8Report powerPlay8ReportView ', $class)">
											<out:value-of select="'schedule/report.xts'"/>
										</out:when>
										<out:when test="contains(' exportDeployment importDeployment ', $class)">
											<out:value-of select="'schedule/deployment.xts'"/>
										</out:when>
										<out:when test="contains(' agentDefinition agentDefinitionView ', $class)">
											<out:value-of select="'schedule/agentDefinition.xts'"/>
										</out:when>
										<out:otherwise>
											<out:value-of select="concat('schedule/', $class, '.xts')"/>
										</out:otherwise>
									</out:choose>
								</out:variable>
								<xsl:call-template name="renderAction">
									<xsl:with-param name="icon" select="'action_schedule.gif'"/>
									<xsl:with-param name="tooltip" select="'IDS_ACT_SCHEDULE'"/>
									<xsl:with-param name="morphlet" select="'{$run_target}'"/>
								</xsl:call-template>
						</out:if>	
						
						<out:if test="$ui-object/action[@name = 'shortcut' and @visible = 'main'] and not(cm:nid) and not($obj-class = 'shortcut')">
 							<xsl:call-template name="renderAction">
 								<xsl:with-param name="icon" select="'action_new_ref.gif'"/>
 								<xsl:with-param name="tooltip" select="'IDS_ACT_SHORTCUT_TIP'"/>
 								<xsl:with-param name="morphlet" select="'new_general.xts'"/>		
 								<xsl:with-param name="newclass" select="'shortcut'"/>
 							</xsl:call-template>
 						</out:if>
					</xsl:if>					

					<xsl:if test="@mode and @mode = 'tools'">
						<!-- Test connection -->
						<out:if test="$supportTestConnection = 'true' and ($canRead) and $canTraverse and $ui-object/action[@name = 'test']">
							<xsl:call-template name="renderAction">
								<xsl:with-param name="icon" select="'action_test_connection.gif'"/>
								<xsl:with-param name="tooltip" select="'IDS_ACTION_TEST_CONNECTION_TIP'"/>
								<xsl:with-param name="morphlet" select="'test_connection.xts'"/>					
							</xsl:call-template>
						</out:if>						
						<!-- runOnce -->
						<out:if test="$supportRunOnce = 'true' and not($isDangling) and ($userCanUseRWO or not(contains(' report query reportView analysis powerPlay8Report powerPlay8ReportView ', concat(' ', $class, ' ')))) and $canExecute and ((not(contains(' jobDefinition agentDefinition agentDefinitionView ', concat(' ', $class, ' ')))) or ($canRead and $canTraverse )) and $ui-object/action[@name = 'run_once']">
							<out:variable name="run_target">
								<out:choose>
									<out:when test=" $class = 'importDeployment' or $class = 'exportDeployment' ">runWithOptions/deployment.xts</out:when>
									<out:when test="contains(' report query reportView analysis powerPlay8Report powerPlay8ReportView ', concat(' ', $class, ' '))">
										<out:value-of select="'runWithOptions/report_advanced.xts'"/>
									</out:when>
									<out:otherwise>
										<out:value-of select="concat('runWithOptions/', $class, '.xts')"/>
									</out:otherwise>
								</out:choose>
							</out:variable>
							<xsl:call-template name="renderAction">
								<xsl:with-param name="icon" select="'action_run_once.gif'"/>
								<xsl:with-param name="tooltip" select="'IDS_ACT_RUN_ONCE'"/>
								<xsl:with-param name="morphlet" select="'{$run_target}'"/>				
							</xsl:call-template>
						</out:if>	
						<!-- View Run History -->
						<out:if test="$supportViewRunHistory = 'true' and $canRead and $canTraverse and $ui-object/action[@name = 'run_history']">
							
							<xsl:call-template name="renderAction">
								<xsl:with-param name="icon" select="'action_view_run_history.gif'"/>
								<xsl:with-param name="tooltip" select="'IDS_IMG_VIEW_HISTORY_ALT'"/>
								<xsl:with-param name="morphlet" select="'history/view.xts'"/>					
							</xsl:call-template>
						</out:if>	
						
						<!-- view history details -->
						<out:if test="$supportViewRunHistoryDetails = 'true'">
							<out:variable name="js-encoded-history-path"> 
								<out:value-of select="xtsext:javascriptencode(string($history-path))"/>
							</out:variable>
							<out:variable name="runHistoryDetail">
								<xsl:choose>
									<xsl:when test="@monitorServiceResponse = 'true'">
										<xsl:value-of select="'history/view_executing_details.xts'"/>
									</xsl:when>
									<xsl:otherwise>
										<out:choose>
											<out:when test="$class = 'exportDeployment' or $class = 'importDeployment'">
												<xsl:value-of select="'history/deployment_details.xts'"/>
											</out:when>
											<out:when test="$class = 'dataMovementTask'">
												<xsl:value-of select="'history/dataMovement_details.xts'"/>
											</out:when>
											<out:otherwise>
												<out:value-of select="'history/view_details.xts'"/>
											</out:otherwise>
										</out:choose>
									</xsl:otherwise>
								</xsl:choose>
							</out:variable>
							<out:variable name="tooltip">
								<out:choose>
									<out:when test="$class = 'exportDeployment' or $class = 'importDeployment'"><xts:string id="IDS_VRH_ACT_VIEW_DETAILS_DEPLOYMENT"/></out:when>
									<out:otherwise><xts:string id="IDS_VRH_ACT_VIEW_DETAILS"/></out:otherwise>
								</out:choose>
							</out:variable>
							<xsl:call-template name="renderAction">
								<xsl:with-param name="icon" select="'action_view_run_history_details.gif'"/>
								<xsl:with-param name="customTooltip" select="'$tooltip'"/>
								<xsl:with-param name="onclick">
									var form = document.<xsl:value-of select="@viewOutputForm"/>;<xsl:text/>
									<xsl:choose>
										<xsl:when test="@maintain = 'true'">
											form.ps_nav_op.value = 'maintain';<xsl:text/>								
											form.m_obj.value = '{$js-encoded-history-path}';<xsl:text/>
											form.m_name.value = '{$js-encoded-name}';<xsl:text/>
											form.m_class.value = '{$class}';<xsl:text/>
											form.m.value = 'portal/{$runHistoryDetail}';<xsl:text/>
											<xsl:if test="@monitorServiceResponse = 'true'">
												form.eventID.value = '{xtsext:javascriptencode(string($eventID))}';<xsl:text/>
											</xsl:if>
											form.submit();<xsl:text/>
										</xsl:when>
										<xsl:otherwise>
											actions('{$js-encoded-name}', '{$class}', '{$js-encoded-history-path}', '{$runHistoryDetail}')
										</xsl:otherwise>
									</xsl:choose>
								</xsl:with-param>
							</xsl:call-template>
						</out:if>					
					</xsl:if>		
					<xsl:if test="@mode and @mode = 'portlets'">
						<!-- Preview Portlet -->
						<out:if test="$supportPreviewPortlet = 'true' and $canRead">
							
							<xsl:call-template name="renderAction">
								<xsl:with-param name="icon" select="'action_preview_portlet.gif'"/>
								<xsl:with-param name="tooltip" select="'IDS_ACT_VIEW_PORTLET'"/>
								<xsl:with-param name="onclick">
									<out:text/>window.open('{$gateway}?b_action=xts.run&amp;m={$app}/cc.xts&amp;<out:text/>
									<out:text/>m_portlet=/connection/portlet:path:{xtsext:protect(concat('storeID(%22', $obj-id, '%22)'),'url','storeID','getdata')}<out:text/>
									<out:text/>&amp;rui=hh&amp;m_pagemode=preview','','');<out:text/>
								</xsl:with-param>			
							</xsl:call-template>
						</out:if>						
					</xsl:if>
					<xsl:if test="@mode and (@mode = 'tools' or @mode = 'view_versions')">						
						<!-- Output versions -->
						<out:if test="$supportViewOutputsAction = 'true' and $canRead and $canTraverse and $ui-object/action[@name = 'previous_versions']">
							<out:variable name="js-encoded-reportVersion-path"> 
								<out:value-of select="xtsext:javascriptencode(string($reportVersion-path))"/>
							</out:variable>
							<out:variable name="js-encoded-runHistoryRequestedTime"> 
								<out:value-of select="xtsext:javascriptencode(string($runHistoryRequestedTime))"/>
							</out:variable>							
							<xsl:call-template name="renderAction">
								<xsl:with-param name="onclick">
									var form = document.<xsl:value-of select="@viewOutputForm"/>;<xsl:text/>
									form.reportVersionPath.value = '{$js-encoded-reportVersion-path}';<xsl:text/>
									form.runHistoryRequestedTime.value = '{$js-encoded-runHistoryRequestedTime}';<xsl:text/>

									<xsl:choose>
										<xsl:when test="@stackUp = 'true'">
											form.ps_nav_op.value = 'push';<xsl:text/>								
											form.m_obj.value = '{$js-encoded-path}';<xsl:text/>
											form.m_name.value = '{$js-encoded-name}';<xsl:text/>
											form.m.value = 'portal/{$versions_target}';<xsl:text/>
											form.submit();<xsl:text/>
										</xsl:when>
										<xsl:otherwise>
											actions('{$js-encoded-name}', '{$class}', '{$js-encoded-path}', '{$versions_target}')
										</xsl:otherwise>
									</xsl:choose>
								</xsl:with-param>
								<xsl:with-param name="icon" select="'action_view_report_output.gif'"/>
								<xsl:with-param name="tooltip" select="'IDS_VIEW_OUTPUTS'"/>
							</xsl:call-template>
						</out:if>
					</xsl:if>	
									
					<out:if test="$supportViewHotListAction = 'true' and $canTraverse">
						<xsl:call-template name="renderAction">
							<xsl:with-param name="icon" select="'action_view_AS_hotlist.gif'"/>
							<xsl:with-param name="tooltip" select="'IDS_VIEW_AGS_HOTLIST_TIP'"/>
							<xsl:with-param name="onclick">
								<xsl:text>javascript:window.open(</xsl:text>
								<xsl:text>"{$gateway}?b_action=cognosViewer&amp;ui.action=view&amp;ui.object={xtsext:javascriptencode( xtsext:protect( xtsext:urlencode(string($agsEventList-path)), 'url','searchPath','getdata'))}&amp;cv.header=false&amp;cv.toolbar=false&amp;ui.name={xtsext:javascriptencode(xtsext:protect(xtsext:urlencode(string(cm:parent/*/cm:defaultName)),'url','userData','getdata'))}&amp;ui.format={$output_format}{$rv-lang}&amp;ui.cafcontextid={$cafContextIDAGS}&amp;ui.backURL=" + sEncodedBackURL</xsl:text>
								<xsl:text>, "", "menubar=no,toolbar=no,status=yes,location=no,resizable=yes,width=650,height=480");</xsl:text>
							</xsl:with-param>
						</xsl:call-template>
					</out:if>								

					<xsl:if test="@mode and @mode = 'tools'">		
						<out:if test="$supportPortletControlAction = 'true' and $class='portlet' and $canWrite and $canRead">
							<!-- toggle the canCustomize property of the portlet -->
							<out:variable name="canCustomize">
								<out:choose>
									<out:when test="cm:canCustomize='false'"><out:value-of select="'true'"/></out:when>
									<out:otherwise><out:value-of select="'false'"/></out:otherwise>
								</out:choose>
							</out:variable>
							<out:variable name="action_icon">
								<out:choose>
									<out:when test="cm:canCustomize='false'"><out:value-of select="'locked.gif'"/></out:when>
									<out:otherwise><out:value-of select="'unlocked.gif'"/></out:otherwise>
								</out:choose>
							</out:variable>	
							<out:variable name="tooltip">
								<out:choose>
									<out:when test="cm:canCustomize = 'false'"><xts:string id="IDS_ACT_PORTLET_CONTROL_CUSTOMIZATION_UNLOCK"/></out:when>
									<out:otherwise><xts:string id="IDS_ACT_PORTLET_CONTROL_CUSTOMIZATION_LOCK"/></out:otherwise>
								</out:choose>
							</out:variable>				
							<xsl:call-template name="renderAction">
								<xsl:with-param name="icon" select="'{$action_icon}'"/>
								<xsl:with-param name="customTooltip" select="'$tooltip'"/>
								<xsl:with-param name="onclick">
									var form = document.cfrmEntryAdmin;<xsl:text/>
											form.ifrmcmd.value='save';<xsl:text/>
											form.m_class.value='portlet';<xsl:text/>
											form.m_obj.value="{$js-encoded-path}";<xsl:text/>
											form.backURL.value="{$back-url}";<xsl:text/>
											form.m_p_canCustomize.value='{$canCustomize}';<xsl:text/>
											form.m.value = 'portal/submit.xts';<xsl:text/>
											form.submit();<xsl:text/>
								</xsl:with-param>
							</xsl:call-template>
						</out:if>												
					</xsl:if>
					
					<!-- Render custom actions for the object currently in context if there are any -->
					
					<!-- Define references to the context object that we care about -->
					<out:variable name="obj" select="."/>
					<out:variable name="target" select="./cm:target/*/*"/>
					
					<out:for-each select="$ui-object/action[@type = 'custom']">							
						<!-- if there is at least one property to pass on the custom action then build a query string to tack on to the end of the custom action command -->		
						<out:variable name="qs">
							<out:if test="objProperties/property">
								<!-- Make an attempt to generate a well-formed http GET request given the specified url which may or may not be a cgi command -->
								<out:choose>
									<out:when test="contains(string(url), '=')">&amp;</out:when>	<!-- cgi command with some existing query values -->								
									<out:when test="contains(string(url), '?')"></out:when>				<!-- cgi command without query values -->	
									<out:otherwise>?</out:otherwise>															<!-- some url! make sure there is a ? at the end before adding our query values -->	
								</out:choose>
								<out:variable name="encoding">
									<out:choose>
										<out:when test="objProperties/@encode"><out:value-of select="objProperties/@encode"/></out:when>
										<out:otherwise>utf-8</out:otherwise>
									</out:choose>
								</out:variable>
								<!-- Build the query values -->
								<out:for-each select="objProperties/property">
									<out:if test="position() != 1">&amp;</out:if>
									<out:value-of select="."/>=<xsl:text/>
									<out:choose>
										<!-- If this is a shortcut then use the properties of the object it points to -->
										<out:when test="$obj-class = 'shortcut'">		
											<out:value-of select="xtsext:protect(xtsext:urlencode(string($target[local-name()= string(current())]), string($encoding)),'url',concat('NAME',string(.)),'getdata')"/>											
										</out:when>
										<out:otherwise>	
											<out:value-of select="xtsext:protect(xtsext:urlencode(string($obj/*[local-name()= string(current())]), string($encoding)),'url',concat('NAME',string(.)),'getdata')"/>
										</out:otherwise>
									</out:choose>										
								</out:for-each>							
							</out:if>						
						</out:variable>
						<xsl:call-template name="renderAction">
							<xsl:with-param name="icon">{icon}</xsl:with-param>
							<xsl:with-param name="customTooltip">tooltip[lang($productLocale)]</xsl:with-param>
							<xsl:with-param name="onclick">none</xsl:with-param>
							<xsl:with-param name="href">{url}{$qs}</xsl:with-param>				
						</xsl:call-template>
					</out:for-each>

					<xsl:choose>
						<xsl:when test="@mode and (@mode = 'main' or @mode='mysub')">
							<!--  Actions -->
							<td class="objectOptions" nowrap="nowrap">
								<out:choose>									
									<out:when test="cm:nid or cm:nbid">																
										<out:choose>												
											<!-- NewsItem -->
											<out:when test="cm:nid">
												<out:choose>
													<out:when test="$upfShortCut != '' or cm:upfProviderType = ''">					
														<!-- build the url -->
														<out:variable name="daurl">									
															<out:value-of select="$s7gateway"/>?xmlcmd=&lt;GetPage>&lt;Template>ni<out:value-of select="$upfShortCut"/>_actions.utml&lt;/Template>&lt;/GetPage><out:text/>
															<out:text/>&amp;id=<out:value-of select="cm:nid"/>
															<out:text/>&amp;LO=<out:value-of select="$contentLocale"/>
															<out:text/>&amp;LA=<out:value-of select="$productLocale"/>
															<out:text/>&amp;back=<out:value-of select="$encoded-s7-back-url"/>
														</out:variable>
														<a href="{'{xtsext:protect(string($daurl),&quot;none&quot;,&quot;s7url&quot;,&quot;s7url&quot;)}'}"><xts:string id="IDS_ACT_MORE"/></a>		
													</out:when>										
													<out:otherwise>
														<!-- build the url -->
														<out:variable name="daurl">	
															<out:value-of select="$gateway"/>?b_action=xts.run&amp;m=<out:value-of select="$app"/><out:value-of select="'/upf_actions.xts'"/>
															<out:text/>&amp;id=<out:value-of select="cm:nid"/>&amp;provider=<out:value-of select="cm:upfProviderType"/>
															<out:text/>&amp;LO=<out:value-of select="$contentLocale"/>
															<out:text/>&amp;LA=<out:value-of select="$productLocale"/>
															<out:text/>&amp;back=<out:value-of select="xtsext:protect(string($encoded-s7-back-url),'none','s7url','s7url')"/>
														</out:variable>
														<a href="{'{$daurl}'}"><xts:string id="IDS_ACT_MORE"/></a>		
													</out:otherwise>
												</out:choose>		
											</out:when>
											
											<!-- NewsBox -->
											<out:otherwise>
												<!-- build the url -->
												<out:variable name="daurl">	
													<out:value-of select="$s7gateway"/>?xmlcmd=&lt;GetPage>&lt;Template>nb<out:value-of select="$upfShortCut"/>_actions.utml&lt;/Template>&lt;/GetPage><out:text/>
													<out:text/>&amp;isnewsbox=Y&amp;id=<out:value-of select="cm:nbsid"/>
													<out:text/>&amp;LO=<out:value-of select="$contentLocale"/>
													<out:text/>&amp;LA=<out:value-of select="$productLocale"/>
													<out:text/>&amp;back=<out:value-of select="$encoded-s7-back-url"/>
												</out:variable>
												<a href="{'{xtsext:protect(string($daurl),&quot;none&quot;,&quot;s7url&quot;,&quot;s7url&quot;)}'}"><xts:string id="IDS_ACT_MORE"/></a>		
											</out:otherwise>
										</out:choose>															
									</out:when>	
									<out:when test="starts-with(string($class),'powerPlay')">
										<out:variable name="ppurl">	
											<out:value-of select="$gateway"/>?b_action=xts.run&amp;m=<out:value-of select="$app"/><out:value-of select="'/actions.xts'"/>
											<out:text/>&amp;m_name=<out:value-of select="xtsext:protect(xtsext:urlencode(string($obj-name)),'url','userData','getdata')"/>
											<out:text/>&amp;m_class=<out:value-of select="$obj-class"/>
											<out:text/>&amp;ppBACK=<out:value-of select="xtsext:protect(string($encodedPPBack),'url','url','getdata')"/>
											<out:text/>&amp;backURL=<out:value-of select="$encoded-back-url"/>
											<out:text/>&amp;m_obj=<out:value-of select="xtsext:protect(xtsext:urlencode(string($obj-path)),'url','searchPath','getdata')"/>
											<out:text/>&amp;m_path=<out:value-of select="xtsext:protect(xtsext:urlencode(string($m_path)),'url','searchPath','getdata')"/>
										</out:variable>
										<a href="{'{$ppurl}'}"><xts:string id="IDS_ACT_MORE"/></a>
									</out:when>																			
									<!-- CRN object -->
									<out:otherwise>
										<a href="#">
											<!--  For shortcuts we always use the current object's class, name, and path to launch the "Actions" dialog -->
											<out:attribute name="onClick">actions('<out:value-of select="xtsext:javascriptencode(string($obj-name))"/>', '<out:value-of select="$obj-class"/>','<out:value-of select="xtsext:javascriptencode(string($obj-path))"/>','actions.xts', null, '<out:value-of select="xtsext:javascriptencode(string($location))"/>');</out:attribute>
											<xts:string id="IDS_ACT_MORE"/>
										</a>
									</out:otherwise>
								</out:choose>					
							</td>
						</xsl:when>
						<xsl:otherwise>
							<xsl:variable name="useActions">actions.xts</xsl:variable>
							<!--  Actions -->
							<out:if test="$supportAllActionsAction">
								<td class="objectOptions" nowrap="nowrap">					
									<a href="#">
										<!--  For shortcuts we always use the current object's class, name, and path to launch the "Actions" dialog -->
										<out:attribute name="onClick">actions('<out:value-of select="xtsext:javascriptencode(string($obj-name))"/>', '<out:value-of select="$obj-class"/>','<out:value-of select="xtsext:javascriptencode(string($obj-path))"/>','<xsl:value-of select="$useActions"/>');</out:attribute>
										<xts:string id="IDS_ACT_MORE"/>
									</a>
								</td>
							</out:if>
						</xsl:otherwise>
					</xsl:choose>
				</tr>	
			</table>					
		</out:template>
	</xsl:template>

	<!-- 
	Template - mt:renderAction:
		This template renders the hyperlinked action images for an  individual entry.
		Operation:
			Outputs the hyperlinked action images for an entry.
	-->
	<xsl:template name="renderAction">
		<xsl:param name="onclick" select="''"/>
		<xsl:param name="href" select="''"/>
		<xsl:param name="icon"/>
		<xsl:param name="tooltip"/>
		<xsl:param name="customTooltip"/>
		<xsl:param name="morphlet" select="''"/>
		<xsl:param name="newclass" select="''"/>
		<td>
			<a>
				<xsl:attribute name="href">
					<xsl:choose>
						<xsl:when test="$href != ''"><xsl:value-of select="$href"/></xsl:when>		
						<xsl:otherwise>#</xsl:otherwise>
					</xsl:choose>			
				</xsl:attribute>
				<xsl:if test="$onclick != 'none'">
					<xsl:attribute name="onclick">
						<xsl:choose>
							<xsl:when test="$onclick != ''"><xsl:value-of select="$onclick"/></xsl:when>		
							<xsl:otherwise>actions('{$js-encoded-name}', '{$class}', '{$js-encoded-path}', '<xsl:value-of select="$morphlet"/>', '<xsl:value-of select="$newclass"/>')</xsl:otherwise>
						</xsl:choose>			
					</xsl:attribute>
				</xsl:if>
				
				<img height="16" width="16" border="0">
					<xsl:attribute name="src">{$image_root}<xsl:value-of select="$icon"/></xsl:attribute>					
						<out:attribute name="alt">
							<!-- It is unlikely that we would want to show a tooltip AND a custom tooltip together, but heck it can be done! -->
							<xsl:if test="$tooltip != ''">
								<xts:string id="{$tooltip}"/>
							</xsl:if>
							<xsl:if test="$customTooltip != ''">
								<out:value-of select="{$customTooltip}"/>
							</xsl:if>							
							<out:value-of select="' - '"/><out:value-of select="$toolTipName"/>
						</out:attribute>					
				</img>
			</a>
		</td>	
	</xsl:template>

	
	
	

	<!--
		Define contexts to be used when copying/moving data. This allows you to copy/move data between tools with compatable contexts.
		Context is determined by the objectClass of the container object.
		
		Note: A context _MUST_ be defined for the copy/cut/paste operations to function. If a context is not defined for an area you will
		not be able to paste any objects there.
	-->
	<xsl:template name="mt:contentcontext">
		
		<out:variable name="containerobjcls">
			<out:choose>
				<out:when test="/root/cmContent/cm:queryResponse/cm:queryReply[2]/*/cm:objectClass">
					<out:value-of select="/root/cmContent/cm:queryResponse/cm:queryReply[2]/*/cm:objectClass"/>
				</out:when>
				<out:when test="/root/path/cm:queryResponse/*/cm:objectClass">
					<out:value-of select="/root/path/cm:queryResponse/*/cm:objectClass"/>
				</out:when>
				<out:when test="/root/content/cm:queryResponse/cm:queryReply[1]/*/cm:objectClass">
					<out:value-of select="/root/content/cm:queryResponse/cm:queryReply[1]/*/cm:objectClass"/>
				</out:when>
				<out:when test="/root/navContent/*[local-name()='searchResponse']/*[local-name()='scopeInfo']/*[local-name()='type']">
					<out:value-of select="/root/navContent/*[local-name()='searchResponse']/*[local-name()='scopeInfo']/*[local-name()='type']"/>
				</out:when>
				<out:otherwise>
					<out:text>unknown</out:text>
				</out:otherwise>
			</out:choose>
		</out:variable>

		<out:choose>
			<out:when test="$containerobjcls = 'content' or $containerobjcls = 'package' or $containerobjcls = 'folder'">
				<out:text>content</out:text>
			</out:when>
			<out:when test="$containerobjcls = 'dataSourceConnection'">
				<out:text>datasrccon</out:text>
			</out:when>
			<out:when test="$containerobjcls = 'dataSource'">
				<out:text>datasrc</out:text>
			</out:when>
			<out:when test="$containerobjcls = 'namespace' or $containerobjcls = 'namespaceFolder'">
				<out:text>directory</out:text>	
			</out:when>
			<out:when test="$containerobjcls = 'account'">
				<out:text>user</out:text>
			</out:when>
			<out:when test="$containerobjcls = 'adminFolder'">
				<out:text>admin</out:text>
			</out:when>
			<out:when test="$containerobjcls = 'portletFolder'">
				<out:text>portletprods</out:text>
			</out:when>
			<out:when test="$containerobjcls = 'portletProducer'">
				<out:text>portlets</out:text>
			</out:when>
			<out:when test="$containerobjcls = 'portalSkinFolder'">
				<out:text>styles</out:text>
			</out:when>
			<out:when test="$containerobjcls = 'configuration' or $containerobjcls = 'configurationFolder'">
				<out:text>configObj</out:text>
			</out:when>	
			<out:when test="$containerobjcls = 'subscriptionFolder'">
				<out:text>subscription</out:text>
			</out:when>
			<out:otherwise>
				<!-- Unknown context - Copy/Cut/Paste buttons will be disabled. -->
				<out:text>unknown</out:text>
			</out:otherwise>
		</out:choose>
	</xsl:template>
	
	<xsl:template match="*">
		<xsl:copy>
			<xsl:copy-of select="@*"/>
			<xsl:apply-templates/>
		</xsl:copy>
	</xsl:template>	
</xsl:stylesheet>